@@ -15,7 +15,7 @@
 #   along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 # 
-#   Copyright (C) 2014-2016  	Xavier de Blas <xaviblas@gmail.com> 
+#   Copyright (C) 2014-2017  	Xavier de Blas <xaviblas@gmail.com> 
 # 
 
 
@@ -49,7 +49,7 @@ neuromuscularProfileJump <- function(l.context, e1, c, mass, smoothingC)
 	#from max(abs(speed$y)) at e1, to end of e1
 	e1.speed <- getSpeedSafe(e1, smoothingC)
 	e1.maxspeed.pos <- mean(which(abs(e1.speed$y) == max(abs(e1.speed$y))))
-	e1f <- e1[e1.maxspeed.pos:length(e1)] #TODO: check if has to be determined by minimum acceleration instead of maxspeed
+	e1f <- e1[e1.maxspeed.pos:length(e1)] #TODO: check if has to be determined by force > 0 or a > -9.81 instead of maxspeed
 
 	print(c("e max speed.t",e1.maxspeed.pos))
 	print(c("length e1",length(e1)))
@@ -69,9 +69,10 @@ neuromuscularProfileJump <- function(l.context, e1, c, mass, smoothingC)
 
 	#e1f.rdf.avg
 	#average force on e1f / e1f.t (s)
+	#TODO: Fix this calculation. It is not the same mean(force)/totalTime than mean(force/time)
 	e1f.rfd.avg <- mean(e1f.force) / (e1f.t / 1000)  #bars LOAD
 
-	#e1f.i (Impulse)
+	#e1f.i (relative Impulse)
 	#average force on e1f * e1f.t (s) / mass (Kg)
 	e1f.i <- mean(e1f.force) * (e1f.t / 1000) / mass 
 
@@ -120,7 +121,7 @@ neuromuscularProfileJump <- function(l.context, e1, c, mass, smoothingC)
 	
 	#cl.rfd.avg = average force on cl / cl.t (s) / mass (Kg) #bars EXPLODE
 	cl.speed <- getSpeedSafe(cl, smoothingC)
-	cl.accel = getAccelerationSafe(cl.speed) 
+	cl.accel = getAccelerationSafe(cl.speed)
 	#speed comes in mm/ms when derivate to accel its mm/ms^2 to convert it to m/s^2 need to *1000 because it's quadratic
 	cl.accel$y <- cl.accel$y * 1000
 	cl.force <- mass * (cl.accel$y + g)
@@ -128,9 +129,12 @@ neuromuscularProfileJump <- function(l.context, e1, c, mass, smoothingC)
 	print(c("cl.t",cl.t))
 	print(c("mean clforce",mean(cl.force)))
 
+	
+	#TODO: Fix this calculation. It is not the same mean(force)/totalTime than mean(force/time) or finalForce/totalTime
 	cl.rfd.avg <- mean(cl.force) / (cl.t / 1000) / mass
 	
 	#cl.i = average force on cl * cl.t (s) / mass (Kg) #impulse #bars DRIVE
+	#It is the same as the take-off speed F*t/m = m*a*t/m = a*t = finalVelocity
 	cl.i <- mean(cl.force) * (cl.t / 1000) / mass
 
 	#cl.f.avg = average force on cl / mass (N/Kg)
@@ -282,49 +286,33 @@ neuromuscularProfileGetData <- function(singleFile, displacement, curves, mass,
 	return (npj)
 }
 
-#implement the Excel Forecast in R
-cutreForecastInRDo <- function(table.points, table.values, value)
-{
-	if(value > table.values[11])
-		return (table.points[11])
-	else if(value < table.values[1])
-		return (table.points[1])
-	else {
-		for(i in 1:10) {
-			if(value >= table.values[i] && value < table.values[(i+1)]) {
-				range.values = table.values[(i+1)] - table.values[i]
-				distanceFromLow = value - table.values[i]
-				percentFromLow = distanceFromLow / range.values
-				range.points = table.points[(i+1)] - table.points[i]
-				return (table.points[i] + (range.points * percentFromLow))
-			}
-		}
-	}
+#Linear interpolation of the values
+interpolation <- function(variable, value){
+        if(variable == "load")
+                percent <- 100 * value / 20000 #Linear between 0..20000
+        else if(variable == "explode")
+                percent <- 100 * value / 250 #Linear between 0..250
+        else if(variable == "drive")
+                percent = 100 * (value - 3) / (8-3) #Linear between 3..8
+        else
+                print("Wrong variable name")
+
+        #Let's correct when negative or >100
+        if(percent < 0)
+                percent <- 0
+        else if(percent > 100)
+                percent <- 100
+
+        return(percent)
 }
 
-cutreForecastInRPrepare <- function(variable, value)
-{
-	table.points <- seq(0,100,length.out=11)
-	table.load <- seq(0,20000,length.out=11)
-	table.explode <- seq(0,250,length.out=11)
-	table.drive <- seq(3,8,length.out=11)
-
-	if(variable == "load")
-		return (cutreForecastInRDo(table.points, table.load, value))
-	else if(variable == "explode")
-		return (cutreForecastInRDo(table.points, table.explode, value))
-	else #(variable == "drive")
-		return (cutreForecastInRDo(table.points, table.drive, value))
-}
-
-
 neuromuscularProfilePlotBars <- function(title, load, explode, drive)
 {
 	#print(c("load, explode, drive", load, explode, drive))
 
-	load100 = cutreForecastInRPrepare("load",load)
-	explode100 = cutreForecastInRPrepare("explode",explode)
-	drive100 = cutreForecastInRPrepare("drive",drive)
+	load100 = interpolation("load",load)
+	explode100 = interpolation("explode",explode)
+	drive100 = interpolation("drive",drive)
 	#print(c("load100, explode100, drive100", load100, explode100, drive100))
 
 	barplot(main=title, c(load100,explode100,drive100),col=topo.colors(3),ylim=c(0,100),
