@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 
@@ -39,8 +39,6 @@ public class ChronoJump
 	private static string progVersion = ""; //now in "version" file
 	private static string progName = "Chronojump";
 	
-	private static string runningFolder;	
-
 	private string runningFileName; //useful for knowing if there are two chronojump instances
 	private string messageToShowOnBoot = "";
 	private string messageCrashedBefore = "";
@@ -73,6 +71,8 @@ public class ChronoJump
 		//1.4.10
 		Log.Start();
 		LogB.Debugging = true; //now LogB.Debug will be shown. Also there will be thread info on Warning, Error, Information
+		if(args.Length > 0 && args[0] == "printAll")
+			LogB.PrintAllThreads = true;
 
 		var envPath = Environment.GetEnvironmentVariable ("PATH");
 		var rBinPath = "";
@@ -88,8 +88,8 @@ public class ChronoJump
 				System.IO.Path.Combine(baseDirectory, x64) : System.IO.Path.Combine(baseDirectory, i386);
 
 			if (Directory.Exists(rPath) == false) {
-				throw new DirectoryNotFoundException(string.Format("Could not found the specified path to the directory containing R.dll: {0}", rPath));
 				LogB.Error("Could not found the specified path to the directory containing R.dll: ", rPath);
+				throw new DirectoryNotFoundException(string.Format("Could not found the specified path to the directory containing R.dll: {0}", rPath));
 			}
 
 			var newPath = string.Format("{0}{1}{2}", rPath, System.IO.Path.PathSeparator, envPath);
@@ -132,8 +132,8 @@ public class ChronoJump
 		LogB.Information("baseDir0:", System.AppDomain.CurrentDomain.BaseDirectory);
 		LogB.Information("baseDir1:", baseDirectory);
 		LogB.Information("envPath+rBinPath:", envPath + Path.PathSeparator + rBinPath);
-		
-	
+
+
 		//UtilCSV.ReadValues("/tmp/chronojump-encoder-graph-input-multi.csv");	
 		
 		if(UtilAll.IsWindows())
@@ -223,7 +223,6 @@ public class ChronoJump
 	string versionAvailable;
 	//bool pingStart;
 	//bool pingEnd;
-	bool pulseGTKPingShouldEnd;
 	bool allSQLCallsDoneOnSqliteThingsThread;
 
 	//used when Chronojump is being running two or more times (quadriple-click on start)
@@ -243,7 +242,7 @@ public class ChronoJump
 		}
 
 		//print version of chronojump
-		progVersion = UtilAll.ReadVersion();
+		progVersion = BuildInfo.chronojumpVersion;
 
 		LogB.Information("Chronojump version: {0}", progVersion);
 
@@ -474,7 +473,11 @@ public class ChronoJump
 		SqlitePreferences.Update("simulated", "True", true); //dbcon opened
 
 		Sqlite.Close();
-		
+
+		// Chronojump sqlite is in an initialized state, let's keep the Sqlite state here
+		// to be re-used
+		Sqlite.saveClassState ();
+
 		allSQLCallsDoneOnSqliteThingsThread = true;
 		LogB.SQL("all SQL calls done on sqliteThings thread");
 		
@@ -489,9 +492,7 @@ public class ChronoJump
 	private void findVersion() {
 		LogB.Debug("--1--");
 		//pingStart = true;
-		pulseGTKPingShouldEnd = false;
-		splashShowButton = true;
-		
+
 		LogB.Debug("--2--");
 		//maybe other thread doesn't create at time the splash win
 		//then just wait
@@ -516,7 +517,6 @@ public class ChronoJump
 		versionAvailable = Server.Ping(true, progName, UtilAll.ReadVersion()); //doInsertion
 		
 		LogB.Debug("--4--");
-		splashShowButton = false;
 		LogB.Information(" version:  ", versionAvailable);
 		LogB.Debug("\n--5--");
 		//pingEnd = true;
@@ -524,8 +524,6 @@ public class ChronoJump
 	}
 		
 	private void on_find_version_cancelled(object o, EventArgs args) {
-		splashShowButton = false;
-		pulseGTKPingShouldEnd = true;
 		versionAvailable = Constants.ServerOffline;
 		//pingEnd = true;
 	}
@@ -607,8 +605,6 @@ public class ChronoJump
 	/* splash window things 
 	 * --------------------*/
 
-	private bool splashShowButton = false;
-
 	private void splashMessageChange(int messageInt) {
 	       splashMessage = Catalog.GetString(Constants.SplashMessages[messageInt]);
 		needUpdateSplashMessage = true;
