@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 
@@ -30,7 +30,6 @@ public class ChronopicDetect
 	
 	Gtk.ProgressBar progressbar;
 	Gtk.Button button_cancel;
-	Gtk.Button button_info;
 	
 	private static bool cancel;
 	private static bool needToChangeProgressbarText;
@@ -50,7 +49,6 @@ public class ChronopicDetect
 		this.sp = sp;
 		this.progressbar = progressbar;
 		this.button_cancel = button_cancel;
-		this.button_info = button_info;
 		this.configAutoDetect = configAutoDetect;
 
 		button_cancel.Clicked += new EventHandler(on_button_cancel_clicked);
@@ -220,9 +218,9 @@ public class ChronopicAutoDetect
 		 *
 		 * So the solution is:
 		 * if we are searching encoder, on every port first check if 4MHz connection can be stablished, if it's Found, then normal Chronopic is found
-		 * if is not Fount, then search for the encoder.
+		 * if is not Found, then search for the encoder.
 		 *
-		 * The only problem is in normal Chronopics with old firmware (without the 'J' read/write
+		 * The only problem is in normal Chronopics with old firmware (without the 'J' read/write)
 		 * they will not work after trying to be recognised as an encoder, until reset or disconnect cable
 		 *
 		 */
@@ -230,8 +228,8 @@ public class ChronopicAutoDetect
 		this.configAutoDetect = configAutoDetect;
 		
 		if(configAutoDetect == Config.AutodetectPortEnum.INACTIVE) {
-			return;
 			Detected = "";
+			return;
 		}
 
 		//no matter if we are searching for 4MHz or 20MHz (encoder)
@@ -260,7 +258,10 @@ public class ChronopicAutoDetect
 			SerialPort sp = new SerialPort(port);
 			
 			LogB.Information("searching normal Chronopic at port: ", port);
-			string readed = caNormal.Read(sp);
+
+			// caNormal.Read() returns a string (not used) but also changes caNormal.Found.
+			// So we call it even if we don't use the result directly.
+			caNormal.Read(sp);
 
 			if(caNormal.Found == ChronopicType.NORMAL) //We found a normal Chronopic
 			{
@@ -281,13 +282,16 @@ public class ChronopicAutoDetect
 				/*
 				 * we are searching an encoder
 				 * if we arrived here, we know is not a normal chronopic
-				 * then wecan search safely for an encoder here
+				 * then we can search safely for an encoder here
 				 */
 				ChronopicAuto caEncoder = new ChronopicAutoCheckEncoder();
 				caEncoder.IsEncoder = true;    //for the bauds.
 			
 				LogB.Information("searching encoder Chronopic at port: ", port);
-				readed = caEncoder.Read(sp);
+
+				// caNormal.Read() returns a string (not used) but also changes caNormal.Found.
+				// So we call it even if we don't use the result directly.
+				caEncoder.Read(sp);
 				if(caEncoder.Found == ChronopicType.ENCODER) 
 				{
 					Detected = port;
@@ -318,13 +322,57 @@ public abstract class ChronopicAuto
 
 		if (sp == null) 
 			return false;
+
+		if (sp.IsOpen)
+		{
+			LogB.Information("Port is opened. flushing ... ");
+			byte[] buffer = new byte[256];
+			for (int count = 0; count < 1; count ++) //flush by reading buffer or timeout 1 time
+			{
+				try{
+					sp.Read(buffer,0,256);
+					LogB.Debug(" spReaded ");
+				} catch {
+					LogB.Warning(" catchedTimeOut ");
+				}
+				count ++;
+			}
+
+			LogB.Information("flushed");
+		} else {
+			LogB.Information("Port is closed. Opening ... ");
+			sp.Open();
+		}
+
+		LogB.Information("ready!");
+
+		if(IsEncoder)
+			setEncoderBauds();
+
+		str = "";
+		return true;
+	}
+
+	/*
+	 * this method closes the port to "flush" but this doesn't work always
+	 * is best to use above method that does an explicit flush
+	 *
+	private bool makeOld(SerialPort sp)
+	{
+		this.sp = sp;
+
+		if (sp == null)
+			return false;
 	
-		LogB.Information("opening port... ");
 		try {	
 			if (sp != null) 
-				if (sp.IsOpen)
+				if (sp.IsOpen) {
+					LogB.Information("Port is opened. Closing ... ");
 					sp.Close(); //close to ensure no bytes are comming
+					LogB.Information("closed");
+				}
 
+			LogB.Information("opening port... ");
 			sp.Open();
 		} catch {
 			LogB.Warning("catched!");
@@ -338,6 +386,8 @@ public abstract class ChronopicAuto
 		str = "";
 		return true;
 	}
+	*/
+
 	private void close(SerialPort sp) {
 		LogB.Information("closing port... ");
 		sp.Close();
@@ -366,7 +416,8 @@ public abstract class ChronopicAuto
 			flush();
 			*/
 
-		close(sp);
+		//better don't close it
+		//close(sp);
 		
 		return str;
 	}
@@ -395,7 +446,8 @@ public abstract class ChronopicAuto
 			flush();
 			*/
 		
-		close(sp);
+		//better don't close it
+		//close(sp);
 		
 		return str;
 	}
@@ -476,7 +528,7 @@ public class ChronopicAutoCheckEncoder : ChronopicAuto
 			myByte = (char) sp.ReadByte();
 			
 			LogB.Debug("readed");
-			if(myByte != null && myByte.ToString() != "")
+			if(myByte.ToString() != "")
 				LogB.Information(myByte.ToString());
 			
 			if(myByte == 'J') {
