@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -122,6 +122,8 @@ public class Constants
 	public const string PreferencesTable = "preferences";
 	public const string CountryTable = "country";
 	public const string ConvertTempTable = "convertTemp"; //for conversions
+	public const string ChronopicRegisterTable = "chronopicRegister";
+
 	//tests
 	public const string JumpTable = "jump";
 	public const string JumpRjTable = "jumpRj";
@@ -134,11 +136,31 @@ public class Constants
 	public const string MultiChronopicTable = "multiChronopic";
 	public const string TempMultiChronopicTable = "tempMultiChronopic"; //TODO
 	public const string EncoderTable = "encoder";
+	public const string EncoderConfigurationTable = "encoderConfiguration";
 	public const string EncoderSignalCurveTable = "encoderSignalCurve";
 	public const string EncoderExerciseTable = "encoderExercise";
 	public const string Encoder1RMTable = "encoder1RM";
 	public const string ExecuteAutoTable = "executeAuto";
 
+	// Dummy variables that exists for translating purposes
+	// pragma warning is to avoid warnings of "defined and not used" for these variables.
+#pragma warning disable 0414
+	private static string dumbVariableForTranslatingAny = Catalog.GetString("Any");
+	private static string dumbVariableForTranslatingSportUndefined = Catalog.GetString("--Undefined");
+	private static string dumbVariableForTranslatingSportAny = Catalog.GetString("--Any");
+	private static string dumbVariableForTranslatingSportNone = Catalog.GetString("-None");
+	private static string dumbVariableForTranslatingSpeciallityUndefined = Catalog.GetString("Undefined");
+	private static string dumbVariableForTranslatingLevelUndefined = Catalog.GetString("Undefined");
+	private static string dumbVariableForTranslatingLevelSedentary = Catalog.GetString("Sedentary/Occasional practice");
+	private static string dumbVariableForTranslatingExerciseTranslatedBenchPress = Catalog.GetString("Bench press");
+	private static string dumbVariableForTranslatingExerciseTranslatedSquat = Catalog.GetString("Squat");
+
+	// The next two variables got moved from src/execute/event.cs from EventExecute::runATouchPlatform() and
+	// EventExecute::RunANoStrides() and I'm not sure that are used. Left it here for now to avoid any regressions.
+	private static string dumbVariableForTranslatingWarningMessageTouchAtend = Catalog.GetString("Always remember to touch platform at ending. If you don't do it, Chronojump will crash at next execution.");
+	private static string dumbVariableForTranslatingWarningMessageRunAnalysisNotValid = Catalog.GetString("This Run Analysis is not valid because there are no strides.");
+#pragma warning restore 0414
+
 	//tests types
 	public const string JumpTypeTable = "jumpType";
 	public const string JumpRjTypeTable = "jumpRjType";
@@ -150,7 +172,6 @@ public class Constants
 
 	public const string UndefinedDefault = "Undefined";
 	public const string Any = "Any";
-	private static string dumbVariableForTranslatingAny = Catalog.GetString("Any");
 
 	public const string M = "M";
 	public const string F = "F";
@@ -345,17 +366,18 @@ public class Constants
 	public static string TypeJumpsSimple = Catalog.GetString("Simple");
 	public static string TypeJumpsSimpleWithTC = Catalog.GetString("Simple with TC");
 	public static string TypeJumpsReactive = Catalog.GetString("Jumps: Reactive");
-	public static string TypeRunsSimple = Catalog.GetString("Runs: Simple");
-	public static string TypeRunsIntervallic = Catalog.GetString("Runs: Intervallic");
+	public static string TypeRunsSimple = Catalog.GetString("Races: Simple");
+	public static string TypeRunsIntervallic = Catalog.GetString("Races: Intervallic");
 
 	//strings
 	public static string AllJumpsName = Catalog.GetString("See all jumps");
-	public static string AllRunsName = Catalog.GetString("See all runs");
+	public static string AllRunsName = Catalog.GetString("See all races");
 	public static string AllPulsesName = Catalog.GetString("See all pulses");
 
 	//fileNames
 	//public static string FileNameLogo = "chronojump-boscosystem_white_bg.png";
 	//public static string FileNameLogo320 = "chronojump-boscosystem_320.png";
+	public static string FileNameLogoTransparent = "chronojump-logo-transparent.png";
 	public static string FileNameLogo = "chronojump-logo-2013.png";
 	public static string FileNameLogo320 = "chronojump-logo-2013_320.png";
 	public static string FileNameCSS = "report_web_style.css";
@@ -391,6 +413,9 @@ public class Constants
 	public static string FileNameOpen1 = "gtk-open-1.png";
 	public static string FileNameOpenPlus = "gtk-open-plus.png";
 
+	public static string FileNameImport = "import.png";
+	public static string FileNameExport = "export.png";
+
 	public static string FileNameCSVHeadersIcon = "import-csv-headers.png";
 	public static string FileNameCSVNoHeadersIcon = "import-csv-noheaders.png";
 	public static string FileNameCSVName1Icon = "import-csv-name-1-column.png";
@@ -400,6 +425,8 @@ public class Constants
 	public static string FileNameJumpsRJ = "stock_up_down.png";
 	public static string FileNameRuns = "stock_right.png";
 	public static string FileNameRunsInterval = "stock_right_left.png";
+	public static string FileNameEncoderGravitatory = "stock_down.png";
+	public static string FileNameEncoderInertial = "stock_inertial.png";
 	public static string FileNameReactionTime = "reaction_time_menu.png";
 	public static string FileNamePulse = "pulse_menu.png";
 	public static string FileNameMultiChronopic = "multichronopic_menu.png";
@@ -407,6 +434,7 @@ public class Constants
 	public static string FileNameJumpsFallCalculate = "dj-from-in.png";
 	public static string FileNameJumpsFallPredefined = "dj-from-out.png";
 	
+	public static string FileNameChronopic = "chronopic.png";
 	public static string FileNameChronopic1 = "chronopic1.jpg";
 	public static string FileNameChronopic2 = "chronopic2.jpg";
 	public static string FileNameChronopic3 = "chronopic3.jpg";
@@ -517,16 +545,12 @@ public class Constants
 	public static int SportUndefinedID = 1;
 	public static string SportUndefined = "--Undefined";
 	public static string SportAny = "--Any";
-	private static string dumbVariableForTranslatingSportUndefined = Catalog.GetString("--Undefined");
-	private static string dumbVariableForTranslatingSportAny = Catalog.GetString("--Any");
 	public static int SportNoneID = 2;
 	public static string SportNone = "-None";
-	private static string dumbVariableForTranslatingSportNone = Catalog.GetString("-None");
 
 	public static int SpeciallityUndefinedID = -1;
 	public static string SpeciallityUndefined = "Undefined"; 
-	private static string dumbVariableForTranslatingSpeciallityUndefined = Catalog.GetString("Undefined");
-	
+
 	public static int RaceUndefinedID = -1;
 
 	public static int CountryUndefinedID = 1;
@@ -550,16 +574,15 @@ public class Constants
 	public static string ChronopicOne = Catalog.GetString("All tests available except MultiChronopic.");
 	public static string ChronopicMore = Catalog.GetString("All tests available.");
 
+	public static string DefaultString = Catalog.GetString("Default");
 	
 	//levels of sport practice
 	//int will go into person database
 	//string will be shown in user language
 	public static int LevelUndefinedID = -1;
 	public static string LevelUndefined = "Undefined"; 
-	private static string dumbVariableForTranslatingLevelUndefined = Catalog.GetString("Undefined");
 	public static int LevelSedentaryID = 0; 
 	public static string LevelSedentary = "Sedentary/Occasional practice"; 
-	private static string dumbVariableForTranslatingLevelSedentary = Catalog.GetString("Sedentary/Occasional practice");
 	public static string [] Levels = {
 		LevelUndefinedID.ToString() + ":" + Catalog.GetString(LevelUndefined), 
 		LevelSedentaryID.ToString() + ":" + Catalog.GetString(LevelSedentary), 
@@ -689,7 +712,7 @@ public class Constants
 		JUMPS, RUNS, ENCODER
 	}
 
-	public enum Menuitem_modes { JUMPS, RUNS, POWERGRAVITATORY, POWERINERTIAL, OTHER }
+	public enum Menuitem_modes { JUMPSSIMPLE, JUMPSREACTIVE, RUNSSIMPLE, RUNSINTERVALLIC, POWERGRAVITATORY, POWERINERTIAL, OTHER }
 
 	public static string All = "All";
 	public static string None = "None";
@@ -820,6 +843,46 @@ public class Constants
 	public const string MaxForce = "Max force";
 	public const string MeanPower = "Mean power";
 	public const string PeakPower = "Peak power";
+	public static string [] EncoderVariablesCaptureList = {
+		MeanSpeed, MaxSpeed, MeanForce, MaxForce, MeanPower, PeakPower
+	};
+	public enum EncoderVariablesCapture {
+		MeanSpeed, MaxSpeed, MeanForce, MaxForce, MeanPower, PeakPower
+	}
+	public static string GetEncoderVariablesCapture(EncoderVariablesCapture enumVariable) {
+		switch(enumVariable) {
+			case EncoderVariablesCapture.MeanSpeed:
+				return MeanSpeed;
+			case EncoderVariablesCapture.MaxSpeed:
+				return MaxSpeed;
+			case EncoderVariablesCapture.MeanForce:
+				return MeanForce;
+			case EncoderVariablesCapture.MaxForce:
+				return MaxForce;
+			case EncoderVariablesCapture.MeanPower:
+				return MeanPower;
+			case EncoderVariablesCapture.PeakPower:
+				return PeakPower;
+		}
+		return MeanPower;
+	}
+	public static EncoderVariablesCapture SetEncoderVariablesCapture(string v) {
+		switch(v) {
+			case MeanSpeed:
+				return EncoderVariablesCapture.MeanSpeed;
+			case MaxSpeed:
+				return EncoderVariablesCapture.MaxSpeed;
+			case MeanForce:
+				return EncoderVariablesCapture.MeanForce;
+			case MaxForce:
+				return EncoderVariablesCapture.MaxForce;
+			case MeanPower:
+				return EncoderVariablesCapture.MeanPower;
+			case PeakPower:
+				return EncoderVariablesCapture.PeakPower;
+		}
+		return EncoderVariablesCapture.MeanPower;
+	}
 		
 	public enum Encoder1RMMethod { NONWEIGHTED, WEIGHTED, WEIGHTED2, WEIGHTED3 }
 	public enum ContextMenu { NONE, EDITDELETE, DELETE }
@@ -869,6 +932,7 @@ public class Constants
 		"Encoder is not connected.", 
 		"prediction",
 		"Concentric mean speed on bench press 1RM =",
+		"Concentric mean speed on squat 1RM =",
 		"Estimated percentual load =",
 		"Adapted from",
 		"Mean speed in concentric propulsive phase",
@@ -914,7 +978,8 @@ public class Constants
 		Catalog.GetString("Not enough data."),
 		Catalog.GetString("Encoder is not connected."),
 		Catalog.GetString("prediction"),
-		Catalog.GetString("Concentric mean speed on bench press 1RM is"),
+		Catalog.GetString("Concentric mean speed on bench press 1RM ="),
+		Catalog.GetString("Concentric mean speed on squat 1RM ="),
 		Catalog.GetString("Estimated percentual load ="),
 		Catalog.GetString("Adapted from"),
 		Catalog.GetString("Mean speed in concentric propulsive phase"),
