@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -28,9 +28,6 @@ using Mono.Unix;
 
 public class EncoderParams
 {
-	private int time;
-	private string mass; //to pass always as "." to R
-	
 	//graph.R need both to know displacedMass depending on encoderConfiguration
 	//and plot both as entry data in the table of result data
 	private string massBody; //to pass always as "." to R.
@@ -42,6 +39,8 @@ public class EncoderParams
 	private string analysis;
 	private string analysisVariables;
 	private string analysisOptions;		//p: propulsive
+	private bool captureCheckFullyExtended;
+	private int captureCheckFullyExtendedValue;
 					
 	//encoderConfiguration conversions
 	//in signals and curves, need to do conversions (invert, inertiaMomentum, diameter)
@@ -51,17 +50,6 @@ public class EncoderParams
 	private int curve;
 	private int width;
 	private int height;
-	private double heightHigherCondition;
-	private double heightLowerCondition;
-	private double meanSpeedHigherCondition;
-	private double meanSpeedLowerCondition;
-	private double maxSpeedHigherCondition;
-	private double maxSpeedLowerCondition;
-	private int powerHigherCondition;
-	private int powerLowerCondition;
-	private int peakPowerHigherCondition;
-	private int peakPowerLowerCondition;
-	private string mainVariable;
 	private string decimalSeparator;	//used in export data from R to csv
 	//private bool inverted; //used only in runEncoderCapturePython. In graph.R will be used encoderConfigurationName
 
@@ -73,6 +61,7 @@ public class EncoderParams
 	//to graph.R	
 	public EncoderParams(int minHeight, int exercisePercentBodyWeight, string massBody, string massExtra, 
 			string eccon, string analysis, string analysisVariables, string analysisOptions, 
+			bool captureCheckFullyExtended, int captureCheckFullyExtendedValue,
 			EncoderConfiguration encoderConfiguration,
 			string smoothCon, int curve, int width, int height, string decimalSeparator)
 	{
@@ -84,6 +73,8 @@ public class EncoderParams
 		this.analysis = analysis;
 		this.analysisVariables = analysisVariables;
 		this.analysisOptions = analysisOptions;
+		this.captureCheckFullyExtended = captureCheckFullyExtended;
+		this.captureCheckFullyExtendedValue = captureCheckFullyExtendedValue;
 		this.encoderConfiguration = encoderConfiguration;
 		this.smoothCon = smoothCon;
 		this.curve = curve;
@@ -94,6 +85,10 @@ public class EncoderParams
 	
 	public string ToStringROptions () 
 	{
+		string capFullyExtendedStr = "-1";
+		if(captureCheckFullyExtended)
+			capFullyExtendedStr = captureCheckFullyExtendedValue.ToString(); 
+		
 		return 
 			"#minHeight\n" + 	minHeight + "\n" + 
 			"#exercisePercentBodyWeight\n" + exercisePercentBodyWeight + "\n" + 
@@ -103,6 +98,7 @@ public class EncoderParams
 			"#analysis\n" + 	analysis + "\n" + 
 			"#analysisVariables\n" + analysisVariables + "\n" + 
 			"#analysisOptions\n" + analysisOptions + "\n" + 
+			"#captureCheckFullyExtended\n" + capFullyExtendedStr + "\n" + 
 			encoderConfiguration.ToStringOutput(EncoderConfiguration.Outputs.ROPTIONS) + "\n" +
 			"#smoothCon\n" + 	smoothCon + "\n" + 
 			"#curve\n" + 		curve + "\n" + 
@@ -116,9 +112,6 @@ public class EncoderParams
 		get { return analysis; }
 	}
 	
-	public int Time {
-		get { return time; }
-	}
 
 	~EncoderParams() {}
 }
@@ -339,25 +332,18 @@ public class EncoderCurve
 		switch(parameter) {
 			case Constants.MeanSpeed:
 				return Convert.ToDouble(MeanSpeed);
-				break;
 			case Constants.MaxSpeed:
 				return Convert.ToDouble(MaxSpeed);
-				break;
 			case Constants.MeanForce:
 				return Convert.ToDouble(MeanForce);
-				break;
 			case Constants.MaxForce:
 				return Convert.ToDouble(MaxForce);
-				break;
 			case Constants.MeanPower:
 				return Convert.ToDouble(MeanPower);
-				break;
 			case Constants.PeakPower:
 				return Convert.ToDouble(PeakPower);
-				break;
 			default:
 				return Convert.ToDouble(MeanPower);
-				break;
 		}
 	}
 
@@ -481,7 +467,7 @@ public class EncoderSignalCurve {
 		this.msCentral = msCentral;
 	}
 	
-	public string ToString() {
+	public override string ToString() {
 		return uniqueID.ToString() + ":" + signalID.ToString() + ":" + 
 			curveID.ToString() + ":" + msCentral.ToString();
 	}
@@ -1051,7 +1037,144 @@ public class EncoderBarsData {
 	~EncoderBarsData() {}
 }
 
-public class EncoderConfiguration {
+public class EncoderConfigurationSQLObject
+{
+	public int uniqueID;
+	public Constants.EncoderGI encoderGI;
+	public bool active; //true or false. One true for each encoderGI (GRAVITATORY, INERTIAL)
+	public string name;
+	public EncoderConfiguration encoderConfiguration;
+	public string description;
+
+	public EncoderConfigurationSQLObject()
+	{
+		uniqueID = -1;
+	}
+
+	public EncoderConfigurationSQLObject(int uniqueID,
+			Constants.EncoderGI encoderGI, bool active, string name,
+			EncoderConfiguration encoderConfiguration,
+			string description)
+	{
+		this.uniqueID = uniqueID;
+		this.encoderGI = encoderGI;
+		this.active = active;
+		this.name = name;
+		this.encoderConfiguration = encoderConfiguration;
+		this.description = description;
+	}
+
+	//converts encoderConfiguration string from SQL
+	public EncoderConfigurationSQLObject(int uniqueID,
+			Constants.EncoderGI encoderGI, bool active, string name,
+			string encoderConfigurationString,
+			string description)
+	{
+		string [] strFull = encoderConfigurationString.Split(new char[] {':'});
+		EncoderConfiguration econf = new EncoderConfiguration(
+				(Constants.EncoderConfigurationNames)
+				Enum.Parse(typeof(Constants.EncoderConfigurationNames), strFull[0]) );
+		econf.ReadParamsFromSQL(strFull);
+
+		this.uniqueID = uniqueID;
+		this.encoderGI = encoderGI;
+		this.active = active;
+		this.name = name;
+		this.encoderConfiguration = econf;
+		this.description = description;
+	}
+
+	//imports from file
+	public EncoderConfigurationSQLObject(string contents)
+	{
+		string line;
+		using (StringReader reader = new StringReader (contents)) {
+			do {
+				line = reader.ReadLine ();
+
+				if (line == null)
+					break;
+				if (line == "" || line[0] == '#')
+					continue;
+
+				string [] parts = line.Split(new char[] {'='});
+				if(parts.Length != 2)
+					continue;
+
+				uniqueID = -1;
+				if(parts[0] == "encoderGI")
+				{
+					if(Enum.IsDefined(typeof(Constants.EncoderGI), parts[1]))
+						encoderGI = (Constants.EncoderGI) Enum.Parse(typeof(Constants.EncoderGI), parts[1]);
+				}
+
+				//active is not needed on import, because on import it's always marked as active
+				else if(parts[0] == "active" && parts[1] != "")
+					active = (parts[1] == "True");
+				else if(parts[0] == "name" && parts[1] != "")
+					name = parts[1];
+				else if(parts[0] == "EncoderConfiguration")
+				{
+					string [] ecFull = parts[1].Split(new char[] {':'});
+					if(Enum.IsDefined(typeof(Constants.EncoderConfigurationNames), ecFull[0]))
+					{
+						//create object
+						encoderConfiguration = new EncoderConfiguration(
+								(Constants.EncoderConfigurationNames)
+								Enum.Parse(typeof(Constants.EncoderConfigurationNames), ecFull[0]) );
+						//assign the rest of params
+						encoderConfiguration.ReadParamsFromSQL(ecFull);
+					}
+				}
+				else if(parts[0] == "description" && parts[1] != "")
+					description = parts[1];
+			} while(true);
+		}
+	}
+
+	public string ToSQLInsert()
+	{
+		 string idStr = uniqueID.ToString();
+		 if(idStr == "-1")
+			 idStr = "NULL";
+
+		 return idStr +
+			 ", \"" + encoderGI.ToString() + "\"" +
+			 ", \"" + active.ToString() + "\"" +
+			 ", \"" + name + "\"" +
+			 ", \"" + encoderConfiguration.ToStringOutput(EncoderConfiguration.Outputs.SQL) + "\"" +
+			 ", \"" + description + "\"" +
+			 ", \"\", \"\", \"\""; //future1, future2, future3
+	}
+
+	public string ToFile()
+	{
+		return
+			"#Case sensitive!\n" +
+			"#Comments start with sharp sign\n" +
+			"#Options are key/values with an = separating them\n" +
+			"#DO NOT write comments in the same line than key/value pairs\n" +
+			"#\n" +
+			"#DO NOT WRITE SPACES JUST BEFORE OR AFTER THE '=' SIGN\n" +
+			"#This work:\n" +
+			"#name=My encoder config\n" +
+			"#This doesn't work:\n" +
+			"#name= My encoder config\n" +
+			"#\n" +
+			"#Whitelines are allowed\n" +
+			"\nname=" + name + "\n" +
+			"description=" + description + "\n" +
+			"\n#encoderGI must be GRAVITATORY or INERTIAL\n" +
+			"encoderGI=" + encoderGI.ToString() + "\n" +
+			"\n#EncoderConfiguration if exists, this will be used and cannot be changed\n" +
+"#name:d:D:anglePush:angleWeight:inertiaMachine:gearedDown:inertiaTotal:extraWeightN:extraWeightGrams:extraWeightLenght:list_d\n" +
+"#list_d is list of anchorages in centimeters. each value separated by '_' . Decimal separator is '.'\n" +
+			"EncoderConfiguration=" + encoderConfiguration.ToStringOutput(EncoderConfiguration.Outputs.SQL);
+	}
+}
+
+public class EncoderConfiguration
+{
 	public Constants.EncoderConfigurationNames name;
 	public Constants.EncoderType type;
 	public int position; //used to find values on the EncoderConfigurationList. Numeration changes on every encoder and on not inertial/inertial
@@ -1065,7 +1188,7 @@ public class EncoderConfiguration {
 	public bool has_inertia;
 	public bool has_gearedDown;
 	public bool rotaryFrictionOnAxis;
-	public double d;	//axis
+	public double d;	//axis 		//ATTENTION: this inertial param can be changed on main GUI
 	public double D;	//external disc or pulley
 	public int anglePush;
 	public int angleWeight;
@@ -1076,7 +1199,7 @@ public class EncoderConfiguration {
 	public int gearedDown;	//demultiplication
 	
 	public int inertiaTotal; //this is the inertia used by R
-	public int extraWeightN; //how much extra weights (inertia)
+	public int extraWeightN; //how much extra weights (inertia) //ATTENTION: this param can be changed on main GUI
 	public int extraWeightGrams; //weight of each extra weight (inertia)
 	public double extraWeightLength; //length from center to center (cm) (inertia)
 	
@@ -1453,13 +1576,11 @@ public class EncoderConfiguration {
 		return l;
 	}
 
-	//called on capture, recalculate, load
-	public void SQLUpdate()
-	{
-		SqlitePreferences.Update("encoderConfiguration", this.ToStringOutput(Outputs.SQL), false);
-	}
-
-	public enum Outputs { ROPTIONS, RCSV, SQL} 
+	public enum Outputs { ROPTIONS, RCSV, SQL, SQLECWINCOMPARE}
+	/*
+	 * SQLECWINCOMPARE is to know it two encoderConfigurations on encoderConfigurationWindow are the same
+	 * because two inertial params change outside that window
+	 */
 	
 	public string ToStringOutput(Outputs o) 
 	{
@@ -1494,18 +1615,28 @@ public class EncoderConfiguration {
 				gearedDown.ToString()
 				;
 		}
-		else { //(o == Outputs.SQL) 
+		else { //(o == Outputs.SQL || o == OUTPUTS.SQLECWINCOMPARE)
 			sep = ":";
+
+			string my_str_d = str_d;
+			string my_str_extraWeightN = extraWeightN.ToString();
+
+			if(o == Outputs.SQLECWINCOMPARE)
+			{
+				//this inertial params can be changed on main GUI
+				my_str_d = "%";
+				my_str_extraWeightN  = "%";
+			}
 			return 
 				name + sep + 
-				str_d + sep + 
+				my_str_d + sep +
 				str_D + sep + 
 				anglePush.ToString() + sep + 
 				angleWeight.ToString() + sep +
 				inertiaMachine.ToString() + sep + 
 				gearedDown.ToString() + sep + 
 				inertiaTotal.ToString() + sep + 
-				extraWeightN.ToString() + sep + 
+				my_str_extraWeightN + sep +
 				extraWeightGrams.ToString() + sep +
 				extraWeightLength.ToString() + sep +
 				writeList_d(list_d)
@@ -1567,25 +1698,18 @@ public class EncoderConfiguration {
 		switch(gearedDown) {
 			case -4:
 				return "4";
-				break;
 			case -3:
 				return "3";
-				break;
 			case -2:
 				return "2";
-				break;
 			case 2:
 				return "1/2";
-				break;
 			case 3:
 				return "1/3";
-				break;
 			case 4:
 				return "1/4";
-				break;
 			default:
 				return "2";
-				break;
 		}
 	}
 	public void SetGearedDownFromDisplay(string gearedUpStr) 
