@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -83,7 +83,7 @@ public abstract class EncoderCapture
 	protected bool capturingFirstPhase;
 
 	//capture is simulated (a signal file is readed)
-	private static bool simulated;
+	private static bool simulated = false;
 	private int [] simulatedInts;
 	private int simulatedCount;
 
@@ -94,6 +94,7 @@ public abstract class EncoderCapture
 	private bool cancel;
 	private bool finish;
 	
+	/*
 	public static bool CheckPort(string port)
 	{
 		if(File.Exists(UtilAll.GetECapSimSignalFileName())) { //simulatedEncoder
@@ -118,6 +119,7 @@ public abstract class EncoderCapture
 		}
 		return true;
 	}
+	*/
 
 	//if cont (continuous mode), then will not end when too much time passed before start
 	public void InitGlobal (int widthG, int heightG, int time, int timeEnd, bool cont, string eccon, string port)
@@ -451,7 +453,6 @@ public abstract class EncoderCapture
 
 		string filename = Util.ReadFile(UtilAll.GetECapSimSignalFileName(), true);
 		simulatedInts = Util.ReadFileAsInts(filename);
-		int simulatedCount = 0;
 		return true;
 	}
 
