@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -68,29 +68,24 @@ public abstract class EncoderRProc
 		if(p == null) {
 			LogB.Debug("p == null");
 			return false;
+		} else {
+			if(isRunningThisProcess(p))
+				return true;
 		}
-
-		/*	
-		LogB.Debug("print processes");	
-		Process [] pids = Process.GetProcesses();
-		foreach (Process myPid in pids)
-			LogB.Information(myPid.ToString());
-		*/
-		
-		LogB.Debug(string.Format("last pid id {0}", p.Id));
-
-
-		//if(isRunningThisProcess("Rscript") || isRunningThisProcess("*R*"))
-		if(isRunningThisProcess(p.Id))
-			return true;
 	
 		return false;
 	}
 
-	private bool isRunningThisProcess(int id)
+	private bool isRunningThisProcess(Process p)
 	{
+		/*
+		 * Process Id is not valid if the associated process is not running.
+		 * Need to ensure that the process is running before attempting to retrieve the Id property.
+		 */
+		
 		try {
-			Process pid = Process.GetProcessById(id);
+			LogB.Debug(string.Format("last pid id {0}", p.Id));
+			Process pid = Process.GetProcessById(p.Id);
 			if(pid == null)
 				return false;
 		} catch {
@@ -465,9 +460,9 @@ public class EncoderRProcAnalyze : EncoderRProc
 
 
 			if(outputFileCheck2 == "")
-				while ( ! ( fileWritten(outputFileCheck) || CancelRScript) );
+				while ( ! ( Util.FileReadable(outputFileCheck) || CancelRScript) );
 			else
-				while ( ! ( (fileWritten(outputFileCheck) && fileWritten(outputFileCheck2)) || CancelRScript ) );
+				while ( ! ( (Util.FileReadable(outputFileCheck) && Util.FileReadable(outputFileCheck2)) || CancelRScript ) );
 
 			//copy export from temp file to the file that user has selected
 			if(es.Ep.Analysis == "exportCSV" && ! CancelRScript)
@@ -530,9 +525,9 @@ public class EncoderRProcAnalyze : EncoderRProc
 
 		LogB.Debug("waiting files");
 		if(outputFileCheck2 == "")
-			while ( ! ( fileWritten(outputFileCheck) || CancelRScript) );
+			while ( ! ( Util.FileReadable(outputFileCheck) || CancelRScript) );
 		else
-			while ( ! ( (fileWritten(outputFileCheck) && fileWritten(outputFileCheck2)) || CancelRScript ) );
+			while ( ! ( (Util.FileReadable(outputFileCheck) && Util.FileReadable(outputFileCheck2)) || CancelRScript ) );
 			
 		//copy export from temp file to the file that user has selected
 		if(es.Ep.Analysis == "exportCSV" && ! CancelRScript)
@@ -583,17 +578,7 @@ public class EncoderRProcAnalyze : EncoderRProc
 		LogB.Information("Deleting... " + filename);
 		if (File.Exists(filename))
 			File.Delete(filename);
-	}
-
-	private bool fileWritten(string filename)
-	{
-		if(File.Exists(filename)) {
-			FileInfo fi = new FileInfo(filename);
-			if(fi.Length > 0)
-				return true;
-		}
-
-		return false;
+		LogB.Information("Deleted " + filename);
 	}
 
 }
