@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -117,8 +117,6 @@ public class EventExecute
 
 	//for raise a signal and manage it on chronojump.cs
 	protected Gtk.Button fakeButtonUpdateGraph;
-	protected Gtk.Button fakeButtonFinished;
-	protected Gtk.Button fakeButtonEventEnded;
 	//this should be a safer way, because will be called when thread has dyed, then will be the last action in the GTK thread.
 	//suitable for calling sensitiveGuiEventDone without problems
 	//sensitiveGuiEventDone causes problems on changing (or even reading) properties of gtk stuff outside of gtk thread
@@ -127,28 +125,14 @@ public class EventExecute
 	//for cancelling from chronojump.cs
 	protected bool cancel;
 
-	//cancel doesn't finish until platform is touched (after pressing cancel button)
-	//this variable controls that platform has been touched
-	//if not, it will shown a popup from gui/chronojump.cs (on_cancel_clicked)	
-	protected bool totallyCancelled;
-
 	//for finishing earlier from chronojump.cs
 	protected bool finish;
-	protected bool totallyFinished;
 	
 	//if chronopic is disconnected by user, port changes, ...
 	protected bool chronopicDisconnected;
 	
 	// multi Chronopic stuff
 	protected int chronopics; 
-	protected bool totallyFinishedMulti1;
-	protected bool totallyFinishedMulti2;
-	protected bool totallyFinishedMulti3;
-	protected bool totallyFinishedMulti4;
-	protected bool totallyCancelledMulti1;
-	protected bool totallyCancelledMulti2;
-	protected bool totallyCancelledMulti3;
-	protected bool totallyCancelledMulti4;
 
 
 	//for reaction time	
@@ -286,7 +270,6 @@ public class EventExecute
 		//updateTimeProgressBar();
 		if(needEndEvent) {
 			//app1.EventEnded();
-			fakeButtonEventEnded.Click();
 			//needEndEvent = false;
 			if(needUpdateGraphType == eventType.MULTICHRONOPIC && type == Constants.RunAnalysisName && finish) 
 				//app1.RunATouchPlatform();
@@ -352,12 +335,10 @@ public class EventExecute
 	}
 	
 	private void runATouchPlatform() {
-		string message = Catalog.GetString("Always remember to touch platform at ending. If you don't do it, Chronojump will crash at next execution.");
 		UtilGtk.PrintLabelWithTooltip(egd.Label_message, feedbackMessage);
 	}
 
 	public void RunANoStrides() {
-		string message = Catalog.GetString("This Run Analysis is not valid because there are no strides.");
 		UtilGtk.PrintLabelWithTooltip(egd.Label_message, feedbackMessage);
 	}
 	
@@ -497,12 +478,6 @@ public class EventExecute
 	protected void cancel_event_before_start(object o, EventArgs args)
 	{
 		cancel = true;
-		totallyCancelled = true;
-		//app1.EventEnded();
-		fakeButtonEventEnded.Click();
-		
-		//event will be raised, and managed in chronojump.cs
-		fakeButtonFinished.Click();
 			
 		//event will be raised, and managed in chronojump.cs
 		//calls sensitiveGuiEventDone()
@@ -525,19 +500,11 @@ public class EventExecute
 	public virtual void MultiChronopicWrite(bool tempTable) {
 		LogB.Information("at event.cs");
 	}
-			
+
 	public Gtk.Button FakeButtonUpdateGraph {
 		get { return fakeButtonUpdateGraph; }
 	}
 
-	public Gtk.Button FakeButtonFinished {
-		get { return fakeButtonFinished; }
-	}
-
-	public Gtk.Button FakeButtonEventEnded {
-		get { return fakeButtonEventEnded; }
-	}
-	
 	public Gtk.Button FakeButtonThreadDyed {
 		get { return fakeButtonThreadDyed; }
 	}
@@ -552,7 +519,7 @@ public class EventExecute
 		get { return finish; }
 		set { finish = value; }
 	}
-	
+
 	//called from chronojump.cs for cancelling events
 	public bool Cancel
 	{
@@ -560,18 +527,6 @@ public class EventExecute
 		set { cancel = value; }
 	}
 
-	public bool TotallyCancelled
-	{
-		get { return totallyCancelled; }
-		set { totallyCancelled = value; }
-	}
-
-	public bool TotallyFinished
-	{
-		get { return totallyFinished; }
-		set { totallyFinished = value; }
-	}
-
 	public bool ChronopicDisconnected
 	{
 		get { return chronopicDisconnected; }
@@ -584,16 +539,6 @@ public class EventExecute
 	// multi Chronopic stuff
 	public int Chronopics { get { return chronopics; } }
 
-	public bool TotallyFinishedMulti1 { get { return totallyFinishedMulti1; } }
-	public bool TotallyFinishedMulti2 { get { return totallyFinishedMulti2; } }
-	public bool TotallyFinishedMulti3 { get { return totallyFinishedMulti3; } }
-	public bool TotallyFinishedMulti4 { get { return totallyFinishedMulti4; } }
-	
-	public bool TotallyCancelledMulti1 { get { return totallyCancelledMulti1; } }
-	public bool TotallyCancelledMulti2 { get { return totallyCancelledMulti2; } }
-	public bool TotallyCancelledMulti3 { get { return totallyCancelledMulti3; } }
-	public bool TotallyCancelledMulti4 { get { return totallyCancelledMulti4; } }
-
 
 	~EventExecute() {}
 	   
