@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -77,8 +77,6 @@ public class PulseExecute : EventExecute
 		this.egd = egd;
 	
 		fakeButtonUpdateGraph = new Gtk.Button();
-		fakeButtonEventEnded = new Gtk.Button();
-		fakeButtonFinished = new Gtk.Button();
 		fakeButtonThreadDyed = new Gtk.Button();
 
 		simulated = false;
@@ -158,11 +156,9 @@ public class PulseExecute : EventExecute
 
 			//prepare jump for being cancelled if desired
 			cancel = false;
-			totallyCancelled = false;
 
 			//prepare jump for being finished earlier if desired
 			finish = false;
-			totallyFinished= false;
 
 			//mark we haven't started
 			pulsePhase = pulsePhases.WAIT_FIRST_EVENT;
@@ -189,6 +185,10 @@ public class PulseExecute : EventExecute
 
 			bool ok;
 
+			//prepare variables to allow being cancelled or finished
+			if(! simulated)
+				Chronopic.InitCancelAndFinish();
+
 			do {
 				if(simulated) 
 					ok = true;
@@ -296,13 +296,6 @@ public class PulseExecute : EventExecute
 			if (finish) {
 				write();
 				pulsePhase = pulsePhases.DONE;
-				totallyFinished= true;
-			}
-			if(cancel || finish) {
-				//event will be raised, and managed in chronojump.cs
-				fakeButtonFinished.Click();
-			
-				totallyCancelled = true;
 			}
 	}
 
@@ -359,9 +352,6 @@ public class PulseExecute : EventExecute
 		needShowFeedbackMessage = true; 
 				
 	
-		//event will be raised, and managed in chronojump.cs
-		fakeButtonFinished.Click();
-		
 		//app1.PreparePulseGraph(Util.GetLast(timesString), timesString);
 		PrepareEventGraphPulseObject = new PrepareEventGraphPulse(Util.GetLast(timesString), timesString);
 		needUpdateGraphType = eventType.PULSE;
