@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -34,8 +34,6 @@ public class ReactionTimeExecute : EventExecute
 	//protected Chronopic cp;
 	private Chronopic cp;
 
-	private ReactionTime reactionTimeDone;
-				
 	public ReactionTimeExecute() {
 	}
 
@@ -61,8 +59,6 @@ public class ReactionTimeExecute : EventExecute
 		this.description = description;
 	
 		fakeButtonUpdateGraph = new Gtk.Button();
-		fakeButtonEventEnded = new Gtk.Button();
-		fakeButtonFinished = new Gtk.Button();
 		fakeButtonThreadDyed = new Gtk.Button();
 				
 		FakeButtonReactionTimeStart = new Gtk.Button();
@@ -130,7 +126,6 @@ public class ReactionTimeExecute : EventExecute
 
 			//prepare reactionTime for being cancelled if desired
 			cancel = false;
-			totallyCancelled = false;
 
 			//in simulated mode, make the jump start just when we arrive to waitEvent at the first time
 			//mark now that we have leaved platform:
@@ -181,6 +176,10 @@ public class ReactionTimeExecute : EventExecute
 		
 		bool ok;
 	
+		//prepare variables to allow being cancelled or finished
+		if(! simulated)
+			Chronopic.InitCancelAndFinish();
+
 		LogB.Information("Inside waitEvent");	
 		do {
 			if(simulated)
@@ -254,13 +253,6 @@ public class ReactionTimeExecute : EventExecute
 //Log.WriteLine("PREEXIT");
 		} while ( ! success && ! cancel );
 //Log.WriteLine("EXIT");
-		
-		if(cancel) {
-			//event will be raised, and managed in chronojump.cs
-			fakeButtonFinished.Click();
-
-			totallyCancelled = true;
-		}
 	}
 	
 	protected override bool shouldFinishByTime() {
@@ -300,9 +292,6 @@ public class ReactionTimeExecute : EventExecute
 		//define the created object
 		eventDone = new ReactionTime(uniqueID, personID, sessionID, type, time, description, Util.BoolToNegativeInt(simulated)); 
 		
-		//event will be raised, and managed in chronojump.cs
-		fakeButtonFinished.Click();
-		
 		//app1.PrepareJumpSimpleGraph(tv, tc);
 		PrepareEventGraphReactionTimeObject = new PrepareEventGraphReactionTime(time, sessionID, personID, table, type);
 		needUpdateGraphType = eventType.REACTIONTIME;
