@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -201,10 +201,10 @@ public class ExportSession
 		printJumpsRj(true, Catalog.GetString("Reactive jumps") + 
 				" (" + Catalog.GetString("with subjumps") + ")");
 
-		printRuns(Catalog.GetString("Simple runs"));
+		printRuns(Catalog.GetString("Simple races"));
 
-		printRunsInterval(true, Catalog.GetString("interval runs") + 
-				" (" + Catalog.GetString("with tracks") + ")");
+		printRunsInterval(true, Catalog.GetString("interval races") +
+				" (" + Catalog.GetString("with laps") + ")");
 
 		printReactionTimes(Catalog.GetString("Reaction times"));
 		
@@ -547,7 +547,7 @@ public class ExportSession
 			myData.Add( "\n" + 
 					Catalog.GetString("Person ID") + ":" +
 					Catalog.GetString("Person name") + ":" +
-					Catalog.GetString("run ID") + ":" + 
+					Catalog.GetString("Race ID") + ":" +
 					Catalog.GetString("Type") + ":" + 
 					Catalog.GetString("Distance") + ":" + 
 					Catalog.GetString("Time") + ":" + 
@@ -606,7 +606,7 @@ public class ExportSession
 						Catalog.GetString("Time total") + ":" +
 						Catalog.GetString("Average speed") + ":" +
 						Catalog.GetString("Distance interval") + ":" + 
-						Catalog.GetString("Tracks") + ":" + 
+						Catalog.GetString("Laps") + ":" +
 						Catalog.GetString("Limited") + ":" +
 						Catalog.GetString("Description") + ":" +
 						Catalog.GetString("Simulated") + ":" +
@@ -980,8 +980,6 @@ public class ExportSessionCSV : ExportSession
 
 public class ExportSessionXML : ExportSession 
 {
-	private XmlTextWriter xr;
-		
 	public ExportSessionXML(Session mySession, Gtk.Window app1, Preferences preferences) 
 	{
 		this.mySession = mySession;
