@@ -15,10 +15,11 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
+using System.IO;
 using System.Collections;
 using System.Collections.Generic; //List<T>
 using Gtk;
@@ -38,13 +39,8 @@ public class EncoderConfigurationWindow
 	[Widget] Gtk.RadioButton radio_linear;
 	[Widget] Gtk.RadioButton radio_rotary_friction;
 	[Widget] Gtk.RadioButton radio_rotary_axis;
-	
-	[Widget] Gtk.RadioButton radio_gravity;
-	[Widget] Gtk.RadioButton radio_inertia;
-	
+
 	[Widget] Gtk.CheckButton check_rotary_friction_inertia_on_axis;
-	[Widget] Gtk.HBox hbox_encoder_types;
-	[Widget] Gtk.Alignment alignment_options;
 	
 	[Widget] Gtk.Button button_previous;
 	[Widget] Gtk.Button button_next;
@@ -91,36 +87,48 @@ public class EncoderConfigurationWindow
 	[Widget] Gtk.ComboBox combo_gearedUp;
 		
 	[Widget] Gtk.Box vbox_select_encoder;
-	[Widget] Gtk.VSeparator vseparator_im;
-	[Widget] Gtk.Box vbox_calcule_im;
+	[Widget] Gtk.Notebook notebook_side;
+	[Widget] Gtk.TreeView treeview_select;
+	[Widget] Gtk.Image image_import;
+	[Widget] Gtk.Image image_export;
+	[Widget] Gtk.Image image_delete;
+
+	[Widget] Gtk.Entry entry_save_name;
+	[Widget] Gtk.Entry entry_save_description;
+	[Widget] Gtk.Button button_apply;
+
 	[Widget] Gtk.SpinButton spin_im_weight_calcule;
 	[Widget] Gtk.SpinButton spin_im_length_calcule;
 	//[Widget] Gtk.SpinButton spin_im_duration_calcule;
 	[Widget] Gtk.Label label_im_result_disc;
-	[Widget] Gtk.Label label_im_result_weights;
-	[Widget] Gtk.Label label_im_result_total;
 	[Widget] Gtk.Label label_im_feedback;
 	[Widget] Gtk.Button button_encoder_capture_inertial_do;
 	[Widget] Gtk.Button button_encoder_capture_inertial_cancel;
 	//[Widget] Gtk.Button button_encoder_capture_inertial_finish;
-	[Widget] Gtk.Label label_button_encoder_capture_inertial_do;
 
-	[Widget] Gtk.Button button_accept;
+	[Widget] Gtk.Button button_close;
 
 	static EncoderConfigurationWindow EncoderConfigurationWindowBox;
 	
 	ArrayList list;
 	int listCurrent = 0; //current item on list
 	Pixbuf pixbuf;
-	bool definedInConfig;
 
-	EncoderConfigurationWindow (bool definedInConfig) {
+	Constants.EncoderGI encoderGI;
+
+	/*
+	 * this params are used on inertial
+	 * and must be retrieved when this window is closed
+	 */
+	string main_gui_anchorage_str;
+	int main_gui_extraWeightN;
+
+
+	EncoderConfigurationWindow () {
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "encoder_configuration", "chronojump");
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "encoder_configuration.glade", "encoder_configuration", "chronojump");
 		gladeXML.Autoconnect(this);
 		
-		this.definedInConfig = definedInConfig;
-		
 		//three encoder types	
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameEncoderTypeLinear);
 		image_encoder_linear.Pixbuf = pixbuf;
@@ -137,110 +145,82 @@ public class EncoderConfigurationWindow
 		//put an icon to window
 		UtilGtk.IconWindow(encoder_configuration);
 	}
-	
-	static public EncoderConfigurationWindow View (bool gravitatory, EncoderConfiguration ec, bool definedInConfig) 
+
+	static public EncoderConfigurationWindow View (
+			Constants.EncoderGI encoderGI, EncoderConfigurationSQLObject econfSO,
+			string anchorage_str, int extraWeightN)
 	{
-		/*
-		 * if we are on gravitatory but ec is inertial, then put definedInConfig as false
-		 * and create a new ec that suits
-		 */
-		if(ec.has_inertia == gravitatory) {
-			definedInConfig = false;
-			if(gravitatory)
-				ec = new EncoderConfiguration(); //LINEAR, not inertial
-			else {
-				ec = new EncoderConfiguration(Constants.EncoderConfigurationNames.ROTARYAXISINERTIAL);
-				ec.SetInertialDefaultOptions();
-			}
-		}
-
 		if (EncoderConfigurationWindowBox == null) {
-			EncoderConfigurationWindowBox = new EncoderConfigurationWindow (definedInConfig);
+			EncoderConfigurationWindowBox = new EncoderConfigurationWindow ();
 		}
 
-		//activate default radiobutton
-		if(ec.type == Constants.EncoderType.ROTARYFRICTION)
-			EncoderConfigurationWindowBox.radio_rotary_friction.Active = true;
-		else if(ec.type == Constants.EncoderType.ROTARYAXIS)
-			EncoderConfigurationWindowBox.radio_rotary_axis.Active = true;
-		else	//linear
-			EncoderConfigurationWindowBox.radio_linear.Active = true;
+		EncoderConfigurationWindowBox.encoderGI = encoderGI;
+		EncoderConfigurationWindowBox.updateGUIFromEncoderConfiguration(econfSO.encoderConfiguration);
+		EncoderConfigurationWindowBox.main_gui_anchorage_str = anchorage_str;
+		EncoderConfigurationWindowBox.main_gui_extraWeightN = extraWeightN;
 
-		if(! ec.has_inertia)
-			EncoderConfigurationWindowBox.radio_gravity.Active = true;
-		else
-			EncoderConfigurationWindowBox.radio_inertia.Active = true;
-		
-		EncoderConfigurationWindowBox.check_rotary_friction_inertia_on_axis.Active = ec.rotaryFrictionOnAxis;
+		EncoderConfigurationWindowBox.createTreeView();
+		EncoderConfigurationWindowBox.fillTreeView(
+				SqliteEncoderConfiguration.Select(false, encoderGI, ""), //all
+				econfSO);
 
+		//A) side is hidden at start to ensure scr_treeview_select is scrolled and displays correctly the last row
+		EncoderConfigurationWindowBox.notebook_side.Visible = false;
 
-		EncoderConfigurationWindowBox.initializeList(ec.type, ec.has_inertia, ec.rotaryFrictionOnAxis, ec.position);
-	
-		EncoderConfigurationWindowBox.create_list_d_spinbutton();
-		
-		EncoderConfigurationWindowBox.putValuesStoredPreviously(
-				ec.d, ec.list_d, ec.D, ec.anglePush, ec.angleWeight, 
-				ec.inertiaMachine, ec.extraWeightGrams, ec.extraWeightLength, 
-				ec.has_gearedDown, ec.GearedUpDisplay());
-		
-
-		//id definedInConfig then only few things can change
-		if(definedInConfig) {
-			EncoderConfigurationWindowBox.hbox_encoder_types.Visible = false;
-			EncoderConfigurationWindowBox.check_rotary_friction_inertia_on_axis.Visible = false;
-			EncoderConfigurationWindowBox.alignment_options.Visible = false;
-			EncoderConfigurationWindowBox.vbox_inertia_calcule.Visible = false;
-		}
-	
 		EncoderConfigurationWindowBox.encoder_configuration.Show ();
+
+		//B) side is shown now, after showing the window in order to be displayed correctly (see A)
+		EncoderConfigurationWindowBox.notebook_side.Visible = (EncoderConfigurationWindowBox.sideMode != sideModes.HIDDEN);
+
 		return EncoderConfigurationWindowBox;
 	}
-	
+
+	private void updateGUIFromEncoderConfiguration(EncoderConfiguration ec)
+	{
+		//activate default radiobutton
+		if(ec.type == Constants.EncoderType.ROTARYFRICTION)
+			radio_rotary_friction.Active = true;
+		else if(ec.type == Constants.EncoderType.ROTARYAXIS)
+			radio_rotary_axis.Active = true;
+		else	//linear
+			radio_linear.Active = true;
+
+		check_rotary_friction_inertia_on_axis.Active = ec.rotaryFrictionOnAxis;
+
+		initializeList(ec.type, ec.has_inertia, ec.rotaryFrictionOnAxis, ec.position);
+
+		create_list_d_spinbutton();
+
+		putValuesStoredPreviously(
+				ec.d, ec.list_d, ec.D, ec.anglePush, ec.angleWeight,
+				ec.inertiaMachine, ec.extraWeightGrams, ec.extraWeightLength,
+				ec.has_gearedDown, ec.GearedUpDisplay());
+	}
+
 	private void on_radio_encoder_type_linear_toggled (object obj, EventArgs args) {
 		if(radio_linear.Active)
 			initializeList(Constants.EncoderType.LINEAR, 
-					radio_inertia.Active, false, 0);
+					encoderGI == Constants.EncoderGI.INERTIAL, false, 0);
 	}
 	private void on_radio_encoder_type_rotary_friction_toggled (object obj, EventArgs args) {
 		if(radio_rotary_friction.Active)
 			initializeList(Constants.EncoderType.ROTARYFRICTION, 
-					radio_inertia.Active, 
-					(radio_inertia.Active && check_rotary_friction_inertia_on_axis.Active), 
+					encoderGI == Constants.EncoderGI.INERTIAL,
+					(encoderGI == Constants.EncoderGI.INERTIAL && check_rotary_friction_inertia_on_axis.Active),
 					0);
 	}
 	private void on_radio_encoder_type_rotary_axis_toggled (object obj, EventArgs args) {
 		if(radio_rotary_axis.Active)
 			initializeList(Constants.EncoderType.ROTARYAXIS, 
-					radio_inertia.Active, false, 0);
-	}
-	
-	private void on_radio_gravity_toggled (object obj, EventArgs args) {
-		if(radio_gravity.Active) {
-			if(radio_linear.Active)
-				initializeList(Constants.EncoderType.LINEAR, false, false, 0);
-			else if(radio_rotary_friction.Active)
-				initializeList(Constants.EncoderType.ROTARYFRICTION, false, false, 0);
-			else //(radio_rotary_axis.Active)
-				initializeList(Constants.EncoderType.ROTARYAXIS, false, false, 0);
-		}
-	}
-	private void on_radio_inertia_toggled (object obj, EventArgs args) {
-		if(radio_inertia.Active) {
-			if(radio_linear.Active)
-				initializeList(Constants.EncoderType.LINEAR, true, false, 0);
-			else if(radio_rotary_friction.Active)
-				initializeList(Constants.EncoderType.ROTARYFRICTION, true, check_rotary_friction_inertia_on_axis.Active,  0);
-			else //(radio_rotary_axis.Active)
-				initializeList(Constants.EncoderType.ROTARYAXIS, true, false, 0);
-		}
+					encoderGI == Constants.EncoderGI.INERTIAL, false, 0);
 	}
 
 	private void check_rotary_friction_inertia_on_axis_is_visible() {
-		check_rotary_friction_inertia_on_axis.Visible = (radio_rotary_friction.Active && ! radio_gravity.Active);
+		check_rotary_friction_inertia_on_axis.Visible = (radio_rotary_friction.Active && encoderGI == Constants.EncoderGI.INERTIAL);
 	}
 	
 	private void on_check_rotary_friction_inertia_on_axis_toggled (object obj, EventArgs args) {
-		on_radio_inertia_toggled(obj, args);
+		initializeList(Constants.EncoderType.ROTARYFRICTION, true, check_rotary_friction_inertia_on_axis.Active, 0);
 	}
 	
 
@@ -298,7 +278,7 @@ public class EncoderConfigurationWindow
 		hbox_inertia.Visible = ec.has_inertia;
 		hbox_inertia_mass.Visible = ec.has_inertia;
 		hbox_inertia_length.Visible = ec.has_inertia;
-		vbox_inertia_calcule.Visible = (ec.has_inertia && ! definedInConfig);
+		vbox_inertia_calcule.Visible = ec.has_inertia;
 		
 		hbox_gearedUp.Visible = ec.has_gearedDown;
 		if(ec.has_gearedDown)
@@ -307,8 +287,8 @@ public class EncoderConfigurationWindow
 		label_count.Text = (listCurrent + 1).ToString() + " / " + list.Count.ToString();
 	
 		//hide inertia moment calculation options when change mode
-		if(show_calcule_im)
-			on_button_encoder_capture_inertial_show_clicked (new object(), new EventArgs());
+		if(sideMode == sideModes.CAPTUREINERTIAL)
+			showHideSide(sideModes.HIDDEN);
 	}
 	
 	private void putValuesStoredPreviously(double d, List<double> list_d, double D, int anglePush, int angleWeight, 
@@ -431,7 +411,7 @@ public class EncoderConfigurationWindow
 	 * because that is stored in gui/encoder as
 	 * encoderConfigurationCurrent
 	 */
-	public EncoderConfiguration GetAcceptedValues() 
+	public EncoderConfiguration GetAcceptedValues()
 	{
 		EncoderConfiguration ec = (EncoderConfiguration) list[listCurrent];
 		
@@ -443,9 +423,27 @@ public class EncoderConfigurationWindow
 		ec.inertiaMachine = -1;
 		
 		if(ec.has_d) {
-			if(ec.has_inertia) {
+			if(ec.has_inertia)
+			{
 				ec.list_d = get_list_d();
-				ec.d = ec.list_d[0]; //selected value is the first
+
+				bool found = false;
+				if(Util.IsNumber(main_gui_anchorage_str, true))
+				{
+					LogB.Information("main_gui_anchorage = " + main_gui_anchorage_str);
+					double guiAnchorage = Convert.ToDouble(main_gui_anchorage_str);
+					foreach(double d in ec.list_d) {
+						LogB.Information("d = " + d.ToString());
+						if(d == guiAnchorage) {
+							ec.d = guiAnchorage;
+							found = true;
+							break;
+						}
+					}
+				}
+
+				if(! found)
+					ec.d = ec.list_d[0];
 			}
 			else
 				ec.d = (double) spin_d.Value; 
@@ -463,6 +461,7 @@ public class EncoderConfigurationWindow
 		if(ec.has_inertia) {
 			ec.inertiaMachine = (int) spin_inertia_machine.Value; 
 			ec.inertiaTotal = (int) spin_inertia_machine.Value; 
+			ec.extraWeightN = main_gui_extraWeightN;
 			ec.extraWeightGrams = (int) spin_inertia_mass.Value;
 			ec.extraWeightLength = (double) spin_inertia_length.Value;
 		}
@@ -479,18 +478,385 @@ public class EncoderConfigurationWindow
 				Catalog.GetString("Calculation of dynamic variables like power in conical machines is not very accurate because current method is not using the variation of the cone diameter as a variable.") + "\n\n" +
 				Catalog.GetString("Future versions will include a better way to calcule this. Sorry for the inconvenience."));
 	}
-	
-	bool show_calcule_im = false;
-	void on_button_encoder_capture_inertial_show_clicked (object o, EventArgs args) 
-	{
-		show_calcule_im = ! show_calcule_im;
-		vseparator_im.Visible = show_calcule_im;
-		vbox_calcule_im.Visible = show_calcule_im;
 
-		button_encoder_capture_inertial_cancel.Sensitive = ! show_calcule_im;
-		//button_encoder_capture_inertial_finish.Sensitive = ! show_calcule_im;
+
+	/*
+	 * ------------------- side content stuff ----------------->
+	 */
+
+	private enum sideModes { HIDDEN, MANAGE, CAPTUREINERTIAL }
+	private sideModes sideMode = sideModes.HIDDEN;
+
+	void on_button_manage_show_clicked (object o, EventArgs args)
+	{
+		if(sideMode == sideModes.MANAGE)
+			showHideSide(sideModes.HIDDEN);
+		else
+			showHideSide(sideModes.MANAGE);
 	}
-	
+	void on_button_encoder_capture_inertial_show_clicked (object o, EventArgs args)
+	{
+		if(sideMode == sideModes.CAPTUREINERTIAL)
+			showHideSide(sideModes.HIDDEN);
+		else
+			showHideSide(sideModes.CAPTUREINERTIAL);
+	}
+
+	int windowWidth;
+	int windowHeight;
+	void showHideSide (sideModes newSideMode)
+	{
+		/*
+		 * Window size A
+		 * Store window size just before showing side content store gui size.
+		 */
+		if(sideMode == sideModes.HIDDEN)
+			encoder_configuration.GetSize(out windowWidth, out windowHeight);
+
+		//update sideMode value
+		sideMode = newSideMode;
+
+		//change gui
+		if(sideMode == sideModes.MANAGE)
+			notebook_side.CurrentPage = 0;
+		else if(sideMode == sideModes.CAPTUREINERTIAL)
+			notebook_side.CurrentPage = 1;
+
+		notebook_side.Visible = (sideMode != sideModes.HIDDEN);
+
+		button_encoder_capture_inertial_cancel.Sensitive = (sideMode != sideModes.CAPTUREINERTIAL);
+		//button_encoder_capture_inertial_finish.Sensitive = (sideMode != sideModes.CAPTUREINERTIAL);
+
+		/*
+		 * Window size B
+		 * Retrieve window size when side content is hided again
+		 */
+		if(sideMode == sideModes.HIDDEN)
+			encoder_configuration.Resize(windowWidth, windowHeight);
+	}
+
+	/*
+	 * <------------------- end of side content stuff -----------------
+	 */
+
+
+	/*
+	 * <--------------- side content area / load-save ---->
+	 */
+
+	TreeStore store;
+	int colName = 0;
+	int colDescription = 1;
+
+	private void createTreeView()
+	{
+		UtilGtk.RemoveColumns(treeview_select);
+
+		treeview_select.HeadersVisible=true;
+		int count = 0;
+		treeview_select.AppendColumn (Catalog.GetString ("Name"), new CellRendererText(), "text", count++);
+		treeview_select.AppendColumn (Catalog.GetString ("Description"), new CellRendererText(), "text", count++);
+
+		treeview_select.Selection.Changed += onTVSelectionChanged;
+
+		store = getStore();
+		treeview_select.Model = store;
+
+		Pixbuf pixbuf;
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameImport);
+		image_import.Pixbuf = pixbuf;
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameExport);
+		image_export.Pixbuf = pixbuf;
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "stock_delete.png");
+		image_delete.Pixbuf = pixbuf;
+	}
+
+	private void fillTreeView(List<EncoderConfigurationSQLObject> list, EncoderConfigurationSQLObject currentSO)
+	{
+		foreach (EncoderConfigurationSQLObject econfSO in list)
+			store.AppendValues (new string[]{ econfSO.name, econfSO.description });
+
+		UtilGtk.TreeviewSelectRowWithName(treeview_select, store, colName, currentSO.name, true);
+	}
+
+	private TreeStore getStore()
+	{
+		return new TreeStore(typeof (string), typeof (string));
+	}
+
+	private string getSelectedName()
+	{
+		TreeModel model;
+		TreeIter iter;
+
+		if (treeview_select.Selection.GetSelected(out model, out iter))
+			return (string) model.GetValue (iter, colName);
+
+		return "";
+	}
+
+	private void onTVSelectionChanged (object o, EventArgs args)
+	{
+		string selectedName = getSelectedName();
+		if(selectedName == "")
+			return;
+
+		List<EncoderConfigurationSQLObject> list = SqliteEncoderConfiguration.Select(false, encoderGI, selectedName);
+		if(list != null && list.Count == 1)
+		{
+			EncoderConfigurationSQLObject econfSO = list[0];
+			entry_save_name.Text = econfSO.name;
+			entry_save_description.Text = econfSO.description;
+
+			//mark all as unactive
+			SqliteEncoderConfiguration.MarkAllAsUnactive(false, encoderGI);
+			econfSO.active = true;
+			//mark this as active
+			SqliteEncoderConfiguration.Update(false, encoderGI, selectedName, econfSO);
+
+			EncoderConfigurationWindowBox.updateGUIFromEncoderConfiguration(econfSO.encoderConfiguration);
+		}
+	}
+
+	void on_entry_save_name_changed	(object o, EventArgs args)
+	{
+		button_apply.Sensitive = (entry_save_name.Text.ToString().Length > 0);
+
+		//TODO: button delete sensitivity depends on being on the treeview
+	}
+
+	void on_entry_save_description_changed (object o, EventArgs args)
+	{
+	}
+
+	void on_button_import_clicked (object o, EventArgs args)
+	{
+		Gtk.FileChooserDialog fc=
+			new Gtk.FileChooserDialog(Catalog.GetString("Select file to import"),
+					encoder_configuration,
+					FileChooserAction.Open,
+					Catalog.GetString("Cancel"),ResponseType.Cancel,
+					Catalog.GetString("Accept"),ResponseType.Accept
+					);
+
+		fc.Filter = new FileFilter();
+		fc.Filter.AddPattern("*.txt");
+
+		if (fc.Run() == (int)ResponseType.Accept)
+		{
+			try {
+				string contents = Util.ReadFile(fc.Filename, false);
+				if (contents != null && contents != "")
+				{
+					EncoderConfigurationSQLObject econfSO = new EncoderConfigurationSQLObject(contents);
+					if(econfSO.encoderGI != encoderGI)
+					{
+						if(encoderGI == Constants.EncoderGI.GRAVITATORY)
+							new DialogMessage(Constants.MessageTypes.WARNING,
+									Catalog.GetString("Imported configuration must be gravitatory."));
+						else if(encoderGI == Constants.EncoderGI.INERTIAL)
+							new DialogMessage(Constants.MessageTypes.WARNING,
+									Catalog.GetString("Imported configuration must be inertial."));
+					}
+					else if(econfSO.name != null && econfSO.name != "")
+					{
+						//add more suffixes until name is unique
+						econfSO.name = SqliteEncoderConfiguration.IfNameExistsAddSuffix(econfSO.name, Catalog.GetString("copy"));
+
+						SqliteEncoderConfiguration.MarkAllAsUnactive(false, encoderGI);
+						econfSO.active = true;
+						SqliteEncoderConfiguration.Insert(false, econfSO);
+
+						store.AppendValues (new string[]{ econfSO.name, econfSO.description });
+						UtilGtk.TreeviewSelectRowWithName(treeview_select, store, colName, econfSO.name, true);
+					}
+				}
+			}
+			catch {
+				LogB.Warning("Catched! Configuration cannot be imported");
+				new DialogMessage(Constants.MessageTypes.WARNING, Catalog.GetString("Error importing data."));
+			}
+		}
+		//Don't forget to call Destroy() or the FileChooserDialog window won't get closed.
+		fc.Destroy();
+	}
+
+	string exportFileName;
+	void on_button_export_clicked (object o, EventArgs args)
+	{
+		Gtk.FileChooserDialog fc=
+			new Gtk.FileChooserDialog(Catalog.GetString("Export to file"),
+					encoder_configuration,
+					FileChooserAction.Save,
+					Catalog.GetString("Cancel"),ResponseType.Cancel,
+					Catalog.GetString("Accept"),ResponseType.Accept
+					);
+
+		if (fc.Run() == (int)ResponseType.Accept)
+		{
+			exportFileName = fc.Filename;
+			exportFileName = Util.AddTxtIfNeeded(exportFileName);
+
+			try {
+				if (File.Exists(exportFileName)) {
+					LogB.Information(string.Format(
+								"File {0} exists with attributes {1}, created at {2}",
+								exportFileName,
+								File.GetAttributes(exportFileName),
+								File.GetCreationTime(exportFileName)));
+					LogB.Information("Overwrite...");
+					ConfirmWindow confirmWin = ConfirmWindow.Show(Catalog.GetString(
+								"Are you sure you want to overwrite file: "), "",
+							exportFileName);
+
+					confirmWin.Button_accept.Clicked +=
+						new EventHandler(on_overwrite_file_export_accepted);
+				} else {
+					on_file_export_accepted();
+
+					string myString = string.Format(Catalog.GetString("Saved to {0}"),
+							exportFileName);
+					new DialogMessage(Constants.MessageTypes.INFO, myString);
+				}
+			}
+			catch {
+				string myString = string.Format(
+						Catalog.GetString("Cannot save file {0} "), exportFileName);
+				new DialogMessage(Constants.MessageTypes.WARNING, myString);
+			}
+		}
+		else {
+			LogB.Information("cancelled");
+			new DialogMessage(Constants.MessageTypes.INFO, Catalog.GetString("Cancelled."));
+			fc.Hide ();
+			return ;
+		}
+
+		//Don't forget to call Destroy() or the FileChooserDialog window won't get closed.
+		fc.Destroy();
+
+		return;
+	}
+	private void on_overwrite_file_export_accepted(object o, EventArgs args)
+	{
+		on_file_export_accepted();
+
+		string myString = string.Format(Catalog.GetString("Saved to {0}"), exportFileName);
+		new DialogMessage(Constants.MessageTypes.INFO, myString);
+	}
+	private void on_file_export_accepted()
+	{
+		TextWriter writer = File.CreateText(exportFileName);
+
+		EncoderConfiguration econfOnGUI = GetAcceptedValues();
+		EncoderConfigurationSQLObject econfSO = new EncoderConfigurationSQLObject(-1,
+				encoderGI, true, entry_save_name.Text.ToString(),
+				econfOnGUI, entry_save_description.Text.ToString());
+		writer.Write(econfSO.ToFile());
+
+		writer.Close();
+		((IDisposable)writer).Dispose();
+	}
+
+	//TODO: button_apply sensitive only when name != "" && != of the others
+	void on_button_apply_clicked (object o, EventArgs args)
+	{
+		apply(true);
+	}
+
+	private void apply(bool updateGUI)
+	{
+		//useful fo update SQL
+		string selectedOldName = getSelectedName();
+		if(selectedOldName == "")
+			return;
+
+		string newName = entry_save_name.Text;
+		if(newName != selectedOldName)
+		{
+			/*
+			 * if name has changed, then check if newname already exists on database
+			 * if exists add _copy recursively
+			 */
+			newName = SqliteEncoderConfiguration.IfNameExistsAddSuffix(newName, Catalog.GetString("copy"));
+		}
+		//update entry_save_name if needed
+		if(newName != entry_save_name.Text)
+			entry_save_name.Text = newName;
+
+		//update SQL
+		EncoderConfiguration econfOnGUI = GetAcceptedValues();
+		EncoderConfigurationSQLObject econfSO = new EncoderConfigurationSQLObject(-1,
+				encoderGI, true, newName,
+				econfOnGUI, entry_save_description.Text.ToString());
+
+		SqliteEncoderConfiguration.Update(false, encoderGI, selectedOldName, econfSO);
+
+		if(updateGUI)
+		{
+			TreeModel model;
+			TreeIter iter = new TreeIter();
+			treeview_select.Selection.GetSelected (out model, out iter);
+			store.SetValue (iter, colName, newName);
+			store.SetValue (iter, colDescription, entry_save_description.Text);
+		}
+	}
+
+	void on_button_new_clicked (object o, EventArgs args)
+	{
+		string selectedName = getSelectedName();
+		if(selectedName == "")
+			return;
+
+		List<EncoderConfigurationSQLObject> list = SqliteEncoderConfiguration.Select(false, encoderGI, selectedName);
+		if(list != null && list.Count == 1)
+		{
+			EncoderConfigurationSQLObject econfSO = list[0];
+			econfSO.uniqueID = -1; //to be entered as null and not repeat the uniqueID
+
+			//add a suffix
+			econfSO.name += "_"  + Catalog.GetString("copy");
+			//add more suffixes until name is unique
+			econfSO.name = SqliteEncoderConfiguration.IfNameExistsAddSuffix(econfSO.name, Catalog.GetString("copy"));
+
+			SqliteEncoderConfiguration.MarkAllAsUnactive(false, encoderGI);
+			econfSO.active = true;
+			SqliteEncoderConfiguration.Insert(false, econfSO);
+
+			store.AppendValues (new string[]{ econfSO.name, econfSO.description });
+			UtilGtk.TreeviewSelectRowWithName(treeview_select, store, colName, econfSO.name, true);
+		}
+	}
+
+	void on_button_delete_clicked (object o, EventArgs args)
+	{
+		string selectedName = getSelectedName();
+		if(selectedName == "")
+			return;
+
+		if(UtilGtk.CountRows(store) <= 1) {
+			new DialogMessage(Constants.MessageTypes.WARNING,
+					Catalog.GetString("Sorry, cannot delete all rows.") + "\n");
+			return;
+		}
+
+		//treeview
+		UtilGtk.RemoveRow(treeview_select, store); 			//1 delete row
+		UtilGtk.TreeviewSelectFirstRow(treeview_select, store, true); 	//2 selects another row (use first)
+
+		//SQL
+		Sqlite.DeleteFromName(false, Constants.EncoderConfigurationTable, "name", selectedName);
+	}
+
+	/*
+	 * <--------------- end of side content area / load-save ----
+	 */
+
+
+	/*
+	 * ------------------- side content area / capture inertial - ---->
+	 */
+
 	void on_button_encoder_capture_inertial_do_clicked (object o, EventArgs args) 
 	{
 		//signal is raised and managed in gui/encoder.cs
@@ -500,7 +866,6 @@ public class EncoderConfigurationWindow
 	public void Button_encoder_capture_inertial_do_chronopic_ok () 
 	{
 		vbox_select_encoder.Visible = false;
-		vseparator_im.Visible = false;
 		button_encoder_capture_inertial_do.Sensitive = false;
 
 		//adapt capture, cancel and finish	
@@ -518,7 +883,6 @@ public class EncoderConfigurationWindow
 	public void Button_encoder_capture_inertial_do_ended (double imResult, string message) 
 	{
 		vbox_select_encoder.Visible = true;
-		vseparator_im.Visible = true;
 		button_encoder_capture_inertial_do.Sensitive = true;
 		
 		//adapt capture, cancel and finish	
@@ -552,30 +916,38 @@ public class EncoderConfigurationWindow
 	}
 	*/
 	
+	/*
+	 * <--------------- end of side content area / capture inertial ----
+	 */
+
+	/*
 	private void on_button_cancel_clicked (object o, EventArgs args)
 	{
 		EncoderConfigurationWindowBox.encoder_configuration.Hide();
 		EncoderConfigurationWindowBox = null;
 	}
+	*/
 	
-	private void on_button_accept_clicked (object o, EventArgs args)
+	private void on_button_close_clicked (object o, EventArgs args)
 	{
+		apply(false);
+
+		//managed on gui/encoder.cs
 		EncoderConfigurationWindowBox.encoder_configuration.Hide();
 	}
 	
 	protected void on_delete_event (object o, DeleteEventArgs args)
 	{
-		args.RetVal = true;
-	
 		if(capturing)
 			button_encoder_capture_inertial_cancel.Click();
-			
-		EncoderConfigurationWindowBox.encoder_configuration.Hide();
-		EncoderConfigurationWindowBox = null;
+
+		button_close.Click();
+
+		args.RetVal = true;
 	}
 
-	public Button Button_accept {
-		get { return button_accept; }
+	public Button Button_close {
+		get { return button_close; }
 	}
 	
 	public Button Button_encoder_capture_inertial_do {
@@ -588,6 +960,9 @@ public class EncoderConfigurationWindow
 	//	get { return button_encoder_capture_inertial_finish; }
 	//}
 	
+	public string Entry_save_name {
+		get { return entry_save_name.Text; }
+	}
 	
 	public double Spin_im_weight {
 		get { return spin_im_weight_calcule.Value; }
