@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -113,7 +113,6 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Notebook notebook_results_data;
 	
 	[Widget] Gtk.DrawingArea event_execute_drawingarea;
-	[Widget] Box event_execute_hbox_drawingarea;
 	/*
 	[Widget] Gtk.Box hbox_combo_graph_results_width;
 	[Widget] Gtk.Box hbox_combo_graph_results_height;
@@ -121,14 +120,12 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.ComboBox combo_graph_results_height;
 	*/
 
-	[Widget] Gtk.Alignment event_execute_alignment;
 	//[Widget] Gtk.Alignment event_execute_alignment_drawingarea;
 	//static Gdk.Pixmap event_execute_pixmap = null;
 	Gdk.Pixmap event_execute_pixmap = null;
 	
 
 	string event_execute_label_simulated;
-	int event_execute_personID;	
 	//int sessionID;
 	//string event_execute_personName;	
 	string event_execute_tableName;	
@@ -140,8 +137,6 @@ public partial class ChronoJumpWindow
 		UNSTARTED, DOING, DONE
 	}
 	
-	int event_execute_radio = 8; 		//radious of the circles
-	int event_execute_arcSystemCorrection = 0; //on Windows circles are paint just one pixel left, fix it
 	int event_execute_rightMargin = 35; 	//at the right we write text (on windows we change later)
 
 	/*
@@ -151,7 +146,6 @@ public partial class ChronoJumpWindow
 	 * on 0.7.5.2 and before, we always cancel, 
 	 * and this produces and endless loop when event has ended, because there's nothing to cancel
 	 */
-	bool eventHasEnded;
 
 	//ExecutingGraphData executingGraphData;
 
@@ -163,9 +157,11 @@ public partial class ChronoJumpWindow
 
 	static EventGraphConfigureWindow eventGraphConfigureWin;
 	
-	private static string [] comboGraphResultsSize = {
+	/* Used only by commented code
+	   private static string [] comboGraphResultsSize = {
 		"100", "200", "300", "400", "500"
 	};
+	*/
 	
 
 	private void event_execute_initializeVariables (
@@ -182,7 +178,6 @@ public partial class ChronoJumpWindow
 		
 		if(UtilAll.IsWindows()) {
 			event_execute_rightMargin = 55;
-			event_execute_arcSystemCorrection = 1;
 		}
 
 		event_execute_configureColors();
@@ -200,7 +195,6 @@ public partial class ChronoJumpWindow
 		//this.event_execute_personName.Text = event_execute_personName; 	//"Jumps" (rjInterval), "Runs" (runInterval), "Ticks" (pulses), 
 		this.event_execute_label_phases_name.Text = phasesName; 	//"Jumps" (rjInterval), "Runs" (runInterval), "Ticks" (pulses), 
 								//"Phases" (simple jumps, dj, simple runs)
-		this.event_execute_personID = personID;
 		this.event_execute_tableName = tableName;
 
 		this.event_execute_eventType = event_execute_eventType;
@@ -223,8 +217,6 @@ public partial class ChronoJumpWindow
 			showPulseLabels();
 		}
 
-		event_execute_button_cancel.Sensitive = true;
-
 		UtilGtk.ClearDrawingArea(event_execute_drawingarea, event_execute_pixmap);
 
 		clearProgressBars();
@@ -249,8 +241,6 @@ public partial class ChronoJumpWindow
 	}
 	private ExecutingGraphData event_execute_prepareForTest () 
 	{
-		eventHasEnded = false;
-
 		checkbutton_video.Sensitive = false;
 		if(preferences.videoOn) {
 			capturer.ClickRec();
@@ -561,11 +551,11 @@ public partial class ChronoJumpWindow
 	{
 		string [] str;
 		string testName;
-		if(radio_mode_jumps_small.Active) {
+		if(radio_menuitem_mode_jumps_simple.Active) {
 			str = SqliteJump.SelectTestMaxStuff(currentPerson.UniqueID, currentJumpType); 
 			testName = currentJumpType.Name;
 		}
-		else if(radio_mode_runs_small.Active) {
+		else if(radio_menuitem_mode_runs_simple.Active) {
 			str = SqliteRun.SelectTestMaxStuff(currentPerson.UniqueID, currentRunType); 
 			testName = currentRunType.Name;
 		} else
@@ -1123,6 +1113,10 @@ public partial class ChronoJumpWindow
 		int ancho=drawingarea.Allocation.Width;
 		int alto=drawingarea.Allocation.Height;
 		
+		//fix problem on show graph at Chronojump start
+		if(event_execute_drawingarea == null || event_execute_pixmap == null)
+			return;
+
 		UtilGtk.ErasePaint(event_execute_drawingarea, event_execute_pixmap);
 		//writeMarginsText(maxValue, minValue, alto);
 		
@@ -1191,6 +1185,10 @@ public partial class ChronoJumpWindow
 		int ancho=drawingarea.Allocation.Width;
 		int alto=drawingarea.Allocation.Height;
 		
+		//fix problem on show graph at Chronojump start
+		if(event_execute_drawingarea == null || event_execute_pixmap == null)
+			return;
+
 		UtilGtk.ErasePaint(event_execute_drawingarea, event_execute_pixmap);
 		//writeMarginsText(maxValue, minValue, alto);
 		
@@ -1468,9 +1466,6 @@ public partial class ChronoJumpWindow
 
 			string [] myTimesStringFull = timesString.Split(new char[] {'='});
 			int count = 0;
-			int added0Value = 0;
-			if(startIn)
-				added0Value = 1;
 
 			double oldValue = 0;
 			double myTimeDouble = 0;
@@ -1609,6 +1604,9 @@ public partial class ChronoJumpWindow
 		int ancho=drawingarea.Allocation.Width;
 		int alto=drawingarea.Allocation.Height;
 		
+		//fix problem on show graph at Chronojump start
+		if(event_execute_drawingarea == null || event_execute_pixmap == null)
+			return;
 		
 		UtilGtk.ErasePaint(event_execute_drawingarea, event_execute_pixmap);
 		
@@ -2008,9 +2006,9 @@ public partial class ChronoJumpWindow
 
 	}
 	
-	private void on_event_execute_EventEnded(object o, EventArgs args) {
+	private void on_event_execute_EventEnded()
+	{
 		hideButtons();
-		eventHasEnded = true;
 
 		checkbutton_video.Sensitive = true;
 		if(preferences.videoOn) {	
