@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -35,7 +35,6 @@ public class GenericWindow
 	[Widget] Gtk.Label label_header;
 	[Widget] Gtk.Box hbox_error;
 	[Widget] Gtk.Label label_error;
-	[Widget] Gtk.Label label_generic_name;
 	[Widget] Gtk.Entry entry;
 	
 	[Widget] Gtk.Box hbox_spin_int;
@@ -122,13 +121,12 @@ public class GenericWindow
 	public GenericWindow (string textHeader)
 	{
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "generic_window", "chronojump");
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "generic_window.glade", "generic_window", "chronojump");
 		gladeXML.Autoconnect(this);
 	
 		//put an icon to window
 		UtilGtk.IconWindow(generic_window);
 		
-		hideWidgets();
 		generic_window.Resizable = false;
 		label_header.Text = textHeader;
 		
@@ -143,6 +141,8 @@ public class GenericWindow
 			GenericWindowBox = new GenericWindow(textHeader);
 		}
 
+		GenericWindowBox.hideWidgets();
+
 		foreach(ArrayList widgetArray in array)
 			GenericWindowBox.showWidgetsPowerful(widgetArray);
 
