@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -52,21 +52,19 @@ public class JumpTypeAddWindow
 	[Widget] Gtk.SpinButton spin_fixed_num;
 
 	[Widget] Gtk.RadioButton radiobutton_startIn_yes;
-	[Widget] Gtk.RadioButton radiobutton_startIn_no;
 	[Widget] Gtk.RadioButton radiobutton_extra_weight_yes;
 	[Widget] Gtk.RadioButton radiobutton_extra_weight_no;
 	[Widget] Gtk.TextView textview_description;
 
 	static JumpTypeAddWindow JumpTypeAddWindowBox;
-	Gtk.Window parent;
 
 	public bool InsertedSimple;
 
 	JumpTypeAddWindow (Gtk.Window parent, bool simple) {
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "jump_type_add", "chronojump");
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "jump_type_add.glade", "jump_type_add", "chronojump");
 		gladeXML.Autoconnect(this);
-		this.parent =  parent;
+		jump_type_add.Parent = parent;
 		
 		fakeButtonAccept = new Gtk.Button();
 
