@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 
@@ -33,13 +33,7 @@ public partial class ChronoJumpWindow
 	//custom buttons
 	[Widget] Gtk.HBox hbox_encoder_analyze_signal_or_curves;
 			
-	//Auto-detect
-	[Widget] Gtk.RadioButton radio_autodetect_active;
-	[Widget] Gtk.RadioButton radio_autodetect_inactive;
-	[Widget] Gtk.RadioButton radio_autodetect_discard_first;
-	
 	//RFID
-	[Widget] Gtk.Box hbox_rfid;
 	[Widget] Gtk.Label label_rfid;
 	
 	//better raspberry controls
@@ -62,16 +56,10 @@ public partial class ChronoJumpWindow
 
 
 	private bool useVideo = true;
-	private Config.AutodetectPortEnum configAutodetectPort = Config.AutodetectPortEnum.ACTIVE;
 
 	private enum linuxTypeEnum { NOTLINUX, LINUX, RASPBERRY, NETWORKS }
-	private linuxTypeEnum linuxType;
-	private bool encoderConfigurationDefinedFromFile = false;
 	private bool encoderUpdateTreeViewWhileCapturing = true;
 		
-	private bool autodetectSignalEnabled = true;
-
-
 	private void configInit() 
 	{
 		//trying new Config class
@@ -113,28 +101,15 @@ public partial class ChronoJumpWindow
 			alignment_video_encoder.Visible = false;
 		}
 		
-		//Auto-detect stuff
-		configAutodetectPort = config.AutodetectPort;
-
-		autodetectSignalEnabled = false; //do not raise signals that could rewrite the config file (loop)
-		
-		if(configAutodetectPort == Config.AutodetectPortEnum.ACTIVE)
-			radio_autodetect_active.Active = true;
-		else if(configAutodetectPort == Config.AutodetectPortEnum.INACTIVE)
-			radio_autodetect_inactive.Active = true;
-		else // (configAutodetectPort == Config.AutodetectPortEnum.DISCARDFIRST)
-			radio_autodetect_discard_first.Active = true;
-
-		autodetectSignalEnabled = true; //activate signals again
-		
-
 		//show only power
 		if(config.OnlyEncoderGravitatory)
 			select_menuitem_mode_toggled(Constants.Menuitem_modes.POWERGRAVITATORY);
 		else if(config.OnlyEncoderInertial)
 			select_menuitem_mode_toggled(Constants.Menuitem_modes.POWERINERTIAL);
 		
-		if(config.EncoderCaptureShowOnlyBars) {
+		if(config.EncoderCaptureShowOnlyBars)
+		{
+			//attention: this makes encoder_capture_signal_drawingarea == null
 			vpaned_encoder_capture_video_and_set_graph.Visible = false;
 			
 			vpaned_encoder_main.Remove(alignment_treeview_encoder_capture_curves);
@@ -165,14 +140,7 @@ public partial class ChronoJumpWindow
 		if(config.EncoderAnalyzeHide) {
 			hbox_encoder_sup_capture_analyze_two_buttons.Visible = false;
 		}
-		
-		if(config.Econf != null) {
-			encoderConfigurationDefinedFromFile = true;
-			encoderConfigurationCurrent = config.Econf;
-			encoderConfigurationGUIUpdate();
-			//TODO: allow to see full data, but don't allow to change it (Open window content as unsensitive)
-		}
-		
+
 		if(config.SessionMode == Config.SessionModeEnum.UNIQUE)	
 		{
 			main_menu.Visible = false;
@@ -217,31 +185,6 @@ public partial class ChronoJumpWindow
 		*/
 	}
 
-	public void on_radio_autodetect_active_toggled (object obj, EventArgs args) 
-	{
-		if(autodetectSignalEnabled && radio_autodetect_active.Active) 
-		{
-			configAutodetectPort = Config.AutodetectPortEnum.ACTIVE;
-			Config.UpdateField("AutodetectPort", configAutodetectPort.ToString());
-		}
-	}
-	public void on_radio_autodetect_inactive_toggled (object obj, EventArgs args) 
-	{
-		if(autodetectSignalEnabled && radio_autodetect_inactive.Active) 
-		{
-			configAutodetectPort = Config.AutodetectPortEnum.INACTIVE;
-			Config.UpdateField("AutodetectPort", configAutodetectPort.ToString());
-		}
-	}
-	public void on_radio_autodetect_discard_first_toggled (object obj, EventArgs args) 
-	{
-		if(autodetectSignalEnabled && radio_autodetect_discard_first.Active) 
-		{
-			configAutodetectPort = Config.AutodetectPortEnum.DISCARDFIRST;
-			Config.UpdateField("AutodetectPort", configAutodetectPort.ToString());
-		}
-	}
-
 	//rfid
 	private void rfid_test() {
 		Networks networks = new Networks();
