@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -70,7 +70,7 @@ public class PersonRecuperateWindow {
 
 	PersonRecuperateWindow (Gtk.Window parent, Session currentSession) {
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "person_recuperate", null);
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "person_recuperate.glade", "person_recuperate", null);
 		gladeXML.Autoconnect(this);
 		this.parent = parent;
 		
@@ -313,7 +313,7 @@ public class PersonsRecuperateFromOtherSessionWindow : PersonRecuperateWindow
 
 	PersonsRecuperateFromOtherSessionWindow (Gtk.Window parent, Session currentSession) {
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "person_recuperate", null);
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "person_recuperate.glade", "person_recuperate", null);
 		gladeXML.Autoconnect(this);
 		this.parent = parent;
 		
@@ -356,7 +356,7 @@ public class PersonsRecuperateFromOtherSessionWindow : PersonRecuperateWindow
 		treeview_person_recuperate.Selection.Changed += onSelectionEntry;
 	}
 
-	static public new PersonsRecuperateFromOtherSessionWindow Show (
+	static public PersonsRecuperateFromOtherSessionWindow Show (
 			Gtk.Window parent, Session currentSession)
 	{
 		if (PersonsRecuperateFromOtherSessionWindowBox == null) {
@@ -548,8 +548,6 @@ public class PersonsRecuperateFromOtherSessionWindow : PersonRecuperateWindow
 	{
 		Gtk.TreeIter iter;
 		bool val;
-		int count = 0;
-		bool found = false;
 		
 		List <PersonSession> personSessions = new List<PersonSession>();
 		int psID;
@@ -579,7 +577,6 @@ public class PersonsRecuperateFromOtherSessionWindow : PersonRecuperateWindow
 							);
 
 					inserted ++;
-					found = true;
 
 				}
 			} while ( store.IterNext(ref iter) );
@@ -587,7 +584,7 @@ public class PersonsRecuperateFromOtherSessionWindow : PersonRecuperateWindow
 			Sqlite.Close();
 
 			//do the transaction	
-			SqlitePersonSessionTransaction psTr = new SqlitePersonSessionTransaction(personSessions);
+			new SqlitePersonSessionTransaction(personSessions);
 		}
 			
 		updateStoreAndEnd();
@@ -642,11 +639,11 @@ public class PersonNotUploadWindow : PersonsRecuperateFromOtherSessionWindow
 	[Widget] Gtk.Button button_close;
 
 	private int sessionID;
-	public Gtk.Button fakeButtonDone;
+	public new Gtk.Button fakeButtonDone;
 	
 	PersonNotUploadWindow (Gtk.Window parent, int sessionID) {
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "person_recuperate", null);
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "person_recuperate.glade", "person_recuperate", null);
 		gladeXML.Autoconnect(this);
 		this.parent = parent;
 		
@@ -698,7 +695,7 @@ public class PersonNotUploadWindow : PersonsRecuperateFromOtherSessionWindow
 		treeview_person_recuperate.Selection.Changed += onSelectionEntry;
 	}
 
-	static public new PersonNotUploadWindow Show (Gtk.Window parent, int sessionID)
+	static public PersonNotUploadWindow Show (Gtk.Window parent, int sessionID)
 	{
 		if (PersonNotUploadWindowBox == null) {
 			PersonNotUploadWindowBox = 
@@ -784,7 +781,7 @@ public class PersonNotUploadWindow : PersonsRecuperateFromOtherSessionWindow
 		on_button_close_clicked (o, new EventArgs());
 	}
 	
-	public Button FakeButtonDone 
+	public new Button FakeButtonDone 
 	{
 		set { fakeButtonDone = value; }
 		get { return fakeButtonDone; }
@@ -806,13 +803,10 @@ public class PersonAddModifyWindow
 	
 	[Widget] Gtk.Label label_date;
 	//[Widget] Gtk.Button button_change_date;
-	[Widget] Gtk.Button button_calendar;
 	[Widget] Gtk.Image image_calendar;
 
 	[Widget] Gtk.SpinButton spinbutton_height;
 	[Widget] Gtk.SpinButton spinbutton_weight;
-	[Widget] Gtk.Button button_height_metric;
-	[Widget] Gtk.Button button_weight_metric;
 	
 	[Widget] Gtk.Box hbox_combo_sports;
 	[Widget] Gtk.ComboBox combo_sports;
@@ -835,8 +829,7 @@ public class PersonAddModifyWindow
 	[Widget] Gtk.Image image_zoom;
 
 	[Widget] Gtk.Button button_accept;
-	[Widget] Gtk.Button button_cancel;
-	
+
 	//used for connect ok gui/chronojump.cs, PersonRecuperate, PersonRecuperateFromOtherSession,this class, gui/convertWeight.cs
 	public Gtk.Button fakeButtonAccept;
 	
@@ -844,14 +837,11 @@ public class PersonAddModifyWindow
 	
 	static PersonAddModifyWindow PersonAddModifyWindowBox;
 	
-	Gtk.Window parent;
-	
 	DialogCalendar myDialogCalendar;
 	DateTime dateTime;
 	Sport sport;
 	string [] sports;
 	string [] sportsTranslated;
-	int speciallityID;
 	string [] speciallities;
 	string [] speciallitiesTranslated;
 	//String level;
@@ -881,13 +871,13 @@ public class PersonAddModifyWindow
 	//showPhotoStuff is false on raspberry to not use camera
 	PersonAddModifyWindow (Gtk.Window parent, Session currentSession, Person currentPerson, bool showPhotoStuff) {
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "person_win", null);
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "person_win.glade", "person_win", null);
 		gladeXML.Autoconnect(this);
 		
 		//put an icon to window
 		UtilGtk.IconWindow(person_win);
 	
-		this.parent = parent;
+		person_win.Parent = parent;
 		this.currentSession = currentSession;
 		this.currentPerson = currentPerson;
 
@@ -1045,20 +1035,16 @@ public class PersonAddModifyWindow
 
 	void on_entries_required_changed (object o, EventArgs args)
 	{
-		bool allOk = true;
-		
 		if(entry1.Text.ToString().Length > 0)
 			image_name.Hide();
 		else {
 			image_name.Show();
-			allOk = false;
 		}
 
 		if((double) spinbutton_weight.Value > 0)
 			image_weight.Hide();
 		else {
 			image_weight.Show();
-			allOk = false;
 		}
 	
 		/*		
@@ -1717,7 +1703,6 @@ public class PersonAddMultipleWindow {
 	[Widget] Gtk.Box hbox_csv;
 	[Widget] Gtk.Box hbox_manually;
 	[Widget] Gtk.SpinButton spin_manually;
-	[Widget] Gtk.Button button_manually_created;
 	
 	[Widget] Gtk.Image image_csv_headers;
 	[Widget] Gtk.Image image_csv_noheaders;
@@ -1736,8 +1721,6 @@ public class PersonAddMultipleWindow {
 	
 	[Widget] Gtk.CheckButton check_headers;
 	[Widget] Gtk.CheckButton check_name_1_column;
-	[Widget] Gtk.Button button_csv_load;
-	[Widget] Gtk.Button button_csv_help;
 	
 	[Widget] Gtk.Label label_csv_help;
 
@@ -1757,7 +1740,6 @@ public class PersonAddMultipleWindow {
 	[Widget] Gtk.Button button_accept;
 	
 	static PersonAddMultipleWindow PersonAddMultipleWindowBox;
-	Gtk.Window parent;
 
 	private Person currentPerson;
 	Session currentSession;
@@ -1770,13 +1752,13 @@ public class PersonAddMultipleWindow {
 	
 	PersonAddMultipleWindow (Gtk.Window parent, Session currentSession) {
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "person_multiple_infinite", null);
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "person_multiple_infinite.glade", "person_multiple_infinite", null);
 		gladeXML.Autoconnect(this);
 		
 		//put an icon to window
 		UtilGtk.IconWindow(person_multiple_infinite);
 	
-		this.parent = parent;
+		person_multiple_infinite.Parent = parent;
 		this.currentSession = currentSession;
 	}
 	
@@ -2265,7 +2247,7 @@ public class PersonAddMultipleWindow {
 			}
 	
 		//do the transaction	
-		SqlitePersonSessionTransaction psTr = new SqlitePersonSessionTransaction(persons, personSessions);
+		new SqlitePersonSessionTransaction(persons, personSessions);
 	}
 
 	public Button Button_accept 
@@ -2306,20 +2288,19 @@ public class PersonShowAllEventsWindow {
 	
 	static PersonShowAllEventsWindow PersonShowAllEventsWindowBox;
 
-	Gtk.Window parent;	
 	protected int sessionID;
 	
 	protected Person currentPerson;
 	
 	PersonShowAllEventsWindow (Gtk.Window parent, int sessionID, Person currentPerson) {
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "person_show_all_events", "chronojump");
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "person_show_all_events.glade", "person_show_all_events", "chronojump");
 		gladeXML.Autoconnect(this);
 		
 		//put an icon to window
 		UtilGtk.IconWindow(person_show_all_events);
 
-		this.parent = parent;
+		person_show_all_events.Parent = parent;
 		this.sessionID = sessionID;
 		this.currentPerson = currentPerson;
 	
@@ -2400,8 +2381,8 @@ public class PersonShowAllEventsWindow {
 		tv.AppendColumn ( Catalog.GetString ("Date\n"), new CellRendererText(), "text", count++);
 		tv.AppendColumn ( Catalog.GetString ("Jumps\nsimple"), new CellRendererText(), "text", count++);
 		tv.AppendColumn ( Catalog.GetString ("Jumps\nreactive"), new CellRendererText(), "text", count++);
-		tv.AppendColumn ( Catalog.GetString ("Runs\nsimple"), new CellRendererText(), "text", count++);
-		tv.AppendColumn ( Catalog.GetString ("Runs\ninterval"), new CellRendererText(), "text", count++);
+		tv.AppendColumn ( Catalog.GetString ("Races\nsimple"), new CellRendererText(), "text", count++);
+		tv.AppendColumn ( Catalog.GetString ("Races\ninterval"), new CellRendererText(), "text", count++);
 		tv.AppendColumn ( Catalog.GetString ("Reaction\ntime"), new CellRendererText(), "text", count++);
 		tv.AppendColumn ( Catalog.GetString ("Pulses"), new CellRendererText(), "text", count++);
 		tv.AppendColumn ( Catalog.GetString ("MultiChronopic"), new CellRendererText(), "text", count++);
