@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -37,7 +37,6 @@ public class PersonSelectWindow
 	[Widget] Gtk.Button button_add;
 	
 	static PersonSelectWindow PersonSelectWindowBox;
-	Gtk.Window parent;
 	
 	private ArrayList persons;
 	public Person SelectedPerson;
@@ -49,11 +48,12 @@ public class PersonSelectWindow
 	
 	PersonSelectWindow (Gtk.Window parent) {
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "person_select_window", "chronojump");
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "person_select_window.glade", "person_select_window", "chronojump");
 		gladeXML.Autoconnect(this);
 		
 		//put an icon to window
 		UtilGtk.IconWindow(person_select_window);
+		person_select_window.Parent = parent;
 		
 		FakeButtonAddPerson = new Gtk.Button();
 		FakeButtonEditPerson = new Gtk.Button();
@@ -66,8 +66,7 @@ public class PersonSelectWindow
 		if (PersonSelectWindowBox == null) {
 			PersonSelectWindowBox = new PersonSelectWindow (parent);
 		}
-		
-		PersonSelectWindowBox.parent = parent;
+
 		PersonSelectWindowBox.persons = persons;
 		
 		PersonSelectWindowBox.createTable();
