@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -89,7 +89,23 @@ public class PreferencesWindow {
 	[Widget] Gtk.RadioButton radio_runs_i_prevent_double_contact_average;
 	[Widget] Gtk.RadioButton radio_runs_i_prevent_double_contact_last;
 	
-	//encoder tab	
+	//encoder capture tab
+	[Widget] Gtk.SpinButton spin_encoder_capture_time;
+	[Widget] Gtk.SpinButton spin_encoder_capture_inactivity_end_time;
+	[Widget] Gtk.Box hbox_combo_main_variable;
+	[Widget] Gtk.ComboBox combo_main_variable;
+	[Widget] Gtk.SpinButton spin_encoder_capture_min_height_gravitatory;
+	[Widget] Gtk.SpinButton spin_encoder_capture_min_height_inertial;
+	[Widget] Gtk.CheckButton checkbutton_encoder_capture_fully_extended;
+	[Widget] Gtk.HBox hbox_encoder_capture_fully_extended;
+	[Widget] Gtk.SpinButton spin_encoder_capture_fully_extended;
+	[Widget] Gtk.RadioButton radio_encoder_auto_save_curve_best;
+	[Widget] Gtk.RadioButton radio_encoder_auto_save_curve_4top;
+	[Widget] Gtk.RadioButton radio_encoder_auto_save_curve_all;
+	[Widget] Gtk.RadioButton radio_encoder_auto_save_curve_none;
+	[Widget] Gtk.CheckButton check_show_start_and_duration;
+	
+	//encoder other tab
 	[Widget] Gtk.CheckButton checkbutton_encoder_propulsive;
 	[Widget] Gtk.SpinButton spin_encoder_smooth_con;
 	[Widget] Gtk.Label label_encoder_con;
@@ -97,12 +113,9 @@ public class PreferencesWindow {
 	[Widget] Gtk.RadioButton radio_encoder_1RM_weighted;
 	[Widget] Gtk.RadioButton radio_encoder_1RM_weighted2;
 	[Widget] Gtk.RadioButton radio_encoder_1RM_weighted3;
-	[Widget] Gtk.RadioButton radio_encoder_auto_save_curve_best;
-	[Widget] Gtk.RadioButton radio_encoder_auto_save_curve_4top;
-	[Widget] Gtk.RadioButton radio_encoder_auto_save_curve_all;
-	[Widget] Gtk.RadioButton radio_encoder_auto_save_curve_none;
 
-	//camera tab
+	//multimedia tab
+	[Widget] Gtk.CheckButton checkbutton_volume;
 	[Widget] Gtk.Box hbox_combo_camera;
 	[Widget] Gtk.ComboBox combo_camera;
 
@@ -121,6 +134,8 @@ public class PreferencesWindow {
 	[Widget] Gtk.RadioButton radio_export_latin;
 	[Widget] Gtk.RadioButton radio_export_non_latin;
 	[Widget] Gtk.Label label_advanced_feedback;
+	[Widget] Gtk.ToggleButton toggle_gc_collect_on_close;
+	[Widget] Gtk.ToggleButton toggle_never_close;
 
 
 	[Widget] Gtk.Button button_accept;
@@ -141,7 +156,7 @@ public class PreferencesWindow {
 
 	PreferencesWindow () {
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "preferences_win", "chronojump");
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "preferences_win.glade", "preferences_win", "chronojump");
 		gladeXML.Autoconnect(this);
 		
 		//put an icon to window
@@ -161,19 +176,28 @@ public class PreferencesWindow {
 			PreferencesWindowBox = new PreferencesWindow ();
 		}
 
-		if(menu_mode !=	Constants.Menuitem_modes.JUMPS)
+		if(menu_mode !=	Constants.Menuitem_modes.JUMPSSIMPLE && menu_mode != Constants.Menuitem_modes.JUMPSREACTIVE)
 			PreferencesWindowBox.notebook.GetNthPage(1).Hide(); 
-		if(menu_mode !=	Constants.Menuitem_modes.RUNS)
+		if(menu_mode !=	Constants.Menuitem_modes.RUNSSIMPLE && menu_mode != Constants.Menuitem_modes.RUNSINTERVALLIC)
 			PreferencesWindowBox.notebook.GetNthPage(2).Hide(); 
-		if(menu_mode !=	Constants.Menuitem_modes.POWERGRAVITATORY && menu_mode != Constants.Menuitem_modes.POWERINERTIAL)
-			PreferencesWindowBox.notebook.GetNthPage(3).Hide(); 
+		if(menu_mode !=	Constants.Menuitem_modes.POWERGRAVITATORY && menu_mode != Constants.Menuitem_modes.POWERINERTIAL) {
+			PreferencesWindowBox.notebook.GetNthPage(3).Hide();
+			PreferencesWindowBox.notebook.GetNthPage(4).Hide();
+		}
 
 		PreferencesWindowBox.preferences = preferences;
 
 		PreferencesWindowBox.createComboLanguage();
 
+		//multimedia tab
+		if(preferences.volumeOn)  
+			PreferencesWindowBox.checkbutton_volume.Active = true; 
+		else 
+			PreferencesWindowBox.checkbutton_volume.Active = false; 
+
 		PreferencesWindowBox.createComboCamera(UtilVideo.GetVideoDevices(), preferences.videoDeviceNum);
-		
+	
+
 		string [] decs = {"1", "2", "3"};
 		PreferencesWindowBox.combo_decimals.Active = UtilGtk.ComboMakeActive(
 				decs, preferences.digitsNumber.ToString());
@@ -280,8 +304,34 @@ public class PreferencesWindow {
 			PreferencesWindowBox.radio_export_non_latin.Active = true; 
 
 	
-		//encoder	
+		//encoder capture -->
+		PreferencesWindowBox.spin_encoder_capture_time.Value = preferences.encoderCaptureTime;
+		PreferencesWindowBox.spin_encoder_capture_inactivity_end_time.Value = preferences.encoderCaptureInactivityEndTime;
+		
+		PreferencesWindowBox.createComboEncoderCaptureMainVariable(
+				Constants.GetEncoderVariablesCapture(preferences.encoderCaptureMainVariable));
+
+		PreferencesWindowBox.spin_encoder_capture_min_height_gravitatory.Value = preferences.encoderCaptureMinHeightGravitatory;
+		PreferencesWindowBox.spin_encoder_capture_min_height_inertial.Value = preferences.encoderCaptureMinHeightInertial;
+		PreferencesWindowBox.checkbutton_encoder_capture_fully_extended.Active = preferences.encoderCaptureCheckFullyExtended;
+		PreferencesWindowBox.spin_encoder_capture_fully_extended.Value = preferences.encoderCaptureCheckFullyExtendedValue;
+		PreferencesWindowBox.hbox_encoder_capture_fully_extended.Visible = preferences.encoderCaptureCheckFullyExtended;
+		
+		if(preferences.encoderAutoSaveCurve == Constants.EncoderAutoSaveCurve.BEST)
+			PreferencesWindowBox.radio_encoder_auto_save_curve_best.Active = true;
+		else if(preferences.encoderAutoSaveCurve == Constants.EncoderAutoSaveCurve.FROM4TOPENULTIMATE)
+			PreferencesWindowBox.radio_encoder_auto_save_curve_4top.Active = true;
+		else if(preferences.encoderAutoSaveCurve == Constants.EncoderAutoSaveCurve.ALL)
+			PreferencesWindowBox.radio_encoder_auto_save_curve_all.Active = true;
+		else
+			PreferencesWindowBox.radio_encoder_auto_save_curve_none.Active = true;
+	
+		PreferencesWindowBox.check_show_start_and_duration.Active = preferences.encoderShowStartAndDuration;
+
+
+		//encoder other -->
 		PreferencesWindowBox.checkbutton_encoder_propulsive.Active = preferences.encoderPropulsive;
+		
 		PreferencesWindowBox.spin_encoder_smooth_con.Value = preferences.encoderSmoothCon;
 
 		if(preferences.encoder1RMMethod == Constants.Encoder1RMMethod.NONWEIGHTED)
@@ -296,6 +346,7 @@ public class PreferencesWindow {
 		//done here and not in glade to be shown with the decimal point of user language	
 		PreferencesWindowBox.label_encoder_con.Text = (0.7).ToString();
 	
+		//language -->
 		if(preferences.language == "")
 			PreferencesWindowBox.radio_language_detected.Active = true;
 		else
@@ -314,20 +365,23 @@ public class PreferencesWindow {
 		else
 			PreferencesWindowBox.radio_do_not_use_heights_on_jump_indexes.Active = true;
 			
-		if(preferences.encoderAutoSaveCurve == Constants.EncoderAutoSaveCurve.BEST)
-			PreferencesWindowBox.radio_encoder_auto_save_curve_best.Active = true;
-		else if(preferences.encoderAutoSaveCurve == Constants.EncoderAutoSaveCurve.FROM4TOPENULTIMATE)
-			PreferencesWindowBox.radio_encoder_auto_save_curve_4top.Active = true;
-		else if(preferences.encoderAutoSaveCurve == Constants.EncoderAutoSaveCurve.ALL)
-			PreferencesWindowBox.radio_encoder_auto_save_curve_all.Active = true;
-		else
-			PreferencesWindowBox.radio_encoder_auto_save_curve_none.Active = true;
-
 
 		PreferencesWindowBox.preferences_win.Show ();
 		return PreferencesWindowBox;
 	}
 	
+	private void createComboEncoderCaptureMainVariable(string v) {
+		combo_main_variable = ComboBox.NewText ();
+		string [] values = Constants.EncoderVariablesCaptureList;
+		UtilGtk.ComboUpdate(combo_main_variable, values, "");
+		combo_main_variable.Active = UtilGtk.ComboMakeActive(combo_main_variable, v.ToString());
+		
+		hbox_combo_main_variable.PackStart(combo_main_variable, false, false, 0);
+		hbox_combo_main_variable.ShowAll();
+		combo_main_variable.Sensitive = true;
+	}
+
+	
 	private void createComboCamera(string [] devices, int current) {
 		combo_camera = ComboBox.NewText ();
 
@@ -345,10 +399,15 @@ public class PreferencesWindow {
 		
 		combo_camera.Active = UtilGtk.ComboMakeActive(devices, devices[current]);
 	}
+		
+	
+	private void on_checkbutton_encoder_capture_fully_extended_toggled(object obj, EventArgs args) {
+		hbox_encoder_capture_fully_extended.Visible = checkbutton_encoder_capture_fully_extended.Active;
+	}
+
 
 	// ---- Language stuff
 	
-	//private void createComboLanguage(string myLanguageCode) {
 	private void createComboLanguage() {
 		
 		combo_language = ComboBox.NewText ();
@@ -734,7 +793,17 @@ public class PreferencesWindow {
 		}
 	}
 	*/
-	
+
+	//encoder
+	private void on_button_inactivity_help_clicked (object o, EventArgs args)
+	{
+		new DialogMessage(Constants.MessageTypes.INFO, 
+				Catalog.GetString("If a repetition has been found, test will end at selected inactivity seconds.") + "\n\n" +
+				Catalog.GetString("If a repetition has not been found, test will end at selected inactivity seconds (x2).") + "\n" +
+				Catalog.GetString("This will let the person to have more time to start movement.")
+				);
+	}
+
 	
 	// ---- start SQL stress tests ---->
 
@@ -788,6 +857,28 @@ public class PreferencesWindow {
 		label_advanced_feedback.Text = "Debug mode on while Chronojump is running.";
 	}
 
+	private void on_toggle_gc_collect_on_close_toggled(object o, EventArgs args)
+	{
+		if(toggle_gc_collect_on_close.Active) {
+			Sqlite.GCCollect = true;
+			new DialogMessage(Constants.MessageTypes.INFO, "GCCollect: ACTIVE!");
+		} else {
+			Sqlite.GCCollect = false;
+			new DialogMessage(Constants.MessageTypes.INFO, "GCCollect: UNACTIVE! (default)");
+		}
+	}
+
+	private void on_toggle_never_close_toggled(object o, EventArgs args)
+	{
+		if(toggle_never_close.Active) {
+			Sqlite.NeverCloseDB = true;
+			new DialogMessage(Constants.MessageTypes.INFO, "Never close: ACTIVE!");
+		} else {
+			Sqlite.NeverCloseDB = false;
+			new DialogMessage(Constants.MessageTypes.INFO, "Never close: UNACTIVE! (default)");
+		}
+	}
+
 	private bool PulseGTK ()
 	{
 		if ( ! thread.IsAlive ) {
@@ -966,19 +1057,104 @@ public class PreferencesWindow {
 
 		//---- end of double contacts stuff
 		
+		//encoder capture ----
+	
+		preferences.encoderCaptureTime = preferencesChange(
+				"encoderCaptureTime",
+				preferences.encoderCaptureTime,
+				(int) PreferencesWindowBox.spin_encoder_capture_time.Value);
+
+		preferences.encoderCaptureInactivityEndTime = preferencesChange(
+				"encoderCaptureInactivityEndTime",
+				preferences.encoderCaptureInactivityEndTime,
+				(int) PreferencesWindowBox.spin_encoder_capture_inactivity_end_time.Value);
+
+	
+		Constants.EncoderVariablesCapture mainVariable = Constants.SetEncoderVariablesCapture(
+				UtilGtk.ComboGetActive(PreferencesWindowBox.combo_main_variable));
+		if( preferences.encoderCaptureMainVariable != mainVariable ) {
+			SqlitePreferences.Update("encoderCaptureMainVariable", mainVariable.ToString(), true);
+			preferences.encoderCaptureMainVariable = mainVariable;
+		}
 		
-		if( preferences.encoderPropulsive != PreferencesWindowBox.checkbutton_encoder_propulsive.Active ) {
-			SqlitePreferences.Update("encoderPropulsive", 
-					PreferencesWindowBox.checkbutton_encoder_propulsive.Active.ToString(), true);
-			preferences.encoderPropulsive = PreferencesWindowBox.checkbutton_encoder_propulsive.Active;
+		preferences.encoderCaptureMinHeightGravitatory = preferencesChange(
+				"encoderCaptureMinHeightGravitatory",
+				preferences.encoderCaptureMinHeightGravitatory,
+				(int) PreferencesWindowBox.spin_encoder_capture_min_height_gravitatory.Value);
+	
+		preferences.encoderCaptureMinHeightInertial = preferencesChange(
+				"encoderCaptureMinHeightInertial",
+				preferences.encoderCaptureMinHeightInertial,
+				(int) PreferencesWindowBox.spin_encoder_capture_min_height_inertial.Value);
+
+		preferences.encoderCaptureCheckFullyExtended = preferencesChange(
+				"encoderCaptureCheckFullyExtended",
+				preferences.encoderCaptureCheckFullyExtended,
+				PreferencesWindowBox.checkbutton_encoder_capture_fully_extended.Active);
+		
+		preferences.encoderCaptureCheckFullyExtendedValue = preferencesChange(
+				"encoderCaptureCheckFullyExtendedValue",
+				preferences.encoderCaptureCheckFullyExtendedValue,
+				(int) PreferencesWindowBox.spin_encoder_capture_fully_extended.Value);
+
+		if(PreferencesWindowBox.radio_encoder_auto_save_curve_best.Active) {
+			SqlitePreferences.Update("encoderAutoSaveCurve", Constants.EncoderAutoSaveCurve.BEST.ToString(), true);
+			preferences.encoderAutoSaveCurve = Constants.EncoderAutoSaveCurve.BEST;
+		}
+		else if(PreferencesWindowBox.radio_encoder_auto_save_curve_4top.Active) {
+			SqlitePreferences.Update("encoderAutoSaveCurve", Constants.EncoderAutoSaveCurve.FROM4TOPENULTIMATE.ToString(), true);
+			preferences.encoderAutoSaveCurve = Constants.EncoderAutoSaveCurve.FROM4TOPENULTIMATE;
+		}
+		else if(PreferencesWindowBox.radio_encoder_auto_save_curve_all.Active) {
+			SqlitePreferences.Update("encoderAutoSaveCurve", Constants.EncoderAutoSaveCurve.ALL.ToString(), true);
+			preferences.encoderAutoSaveCurve = Constants.EncoderAutoSaveCurve.ALL;
+		}
+		else {
+			SqlitePreferences.Update("encoderAutoSaveCurve", Constants.EncoderAutoSaveCurve.NONE.ToString(), true);
+			preferences.encoderAutoSaveCurve = Constants.EncoderAutoSaveCurve.NONE;
 		}
 
-		if( preferences.encoderSmoothCon != (double) PreferencesWindowBox.spin_encoder_smooth_con.Value ) {
-			SqlitePreferences.Update("encoderSmoothCon", Util.ConvertToPoint( 
-						(double) PreferencesWindowBox.spin_encoder_smooth_con.Value), true);
-			preferences.encoderSmoothCon = (double) PreferencesWindowBox.spin_encoder_smooth_con.Value;
-		}
+		preferences.encoderShowStartAndDuration = preferencesChange(
+				"encoderShowStartAndDuration",
+				preferences.encoderShowStartAndDuration,
+				PreferencesWindowBox.check_show_start_and_duration.Active);
 		
+
+		//---- end of encoder capture
+		
+		//encoder other ----
+		
+		preferences.encoderPropulsive = preferencesChange(
+				"encoderPropulsive",
+				preferences.encoderPropulsive,
+				PreferencesWindowBox.checkbutton_encoder_propulsive.Active);
+		
+		preferences.encoderSmoothCon = preferencesChange(
+				"encoderSmoothCon",
+				preferences.encoderSmoothCon,
+				(double) PreferencesWindowBox.spin_encoder_smooth_con.Value);
+		
+		Constants.Encoder1RMMethod encoder1RMMethod;
+		if(PreferencesWindowBox.radio_encoder_1RM_nonweighted.Active)
+			encoder1RMMethod = Constants.Encoder1RMMethod.NONWEIGHTED;
+		else if(PreferencesWindowBox.radio_encoder_1RM_weighted.Active)
+			encoder1RMMethod = Constants.Encoder1RMMethod.WEIGHTED;
+		else if(PreferencesWindowBox.radio_encoder_1RM_weighted2.Active)
+			encoder1RMMethod = Constants.Encoder1RMMethod.WEIGHTED2;
+		else // (PreferencesWindowBox.radio_encoder_1RM_weighted3.Active)
+			encoder1RMMethod = Constants.Encoder1RMMethod.WEIGHTED3;
+
+		SqlitePreferences.Update("encoder1RMMethod", encoder1RMMethod.ToString(), true);
+		preferences.encoder1RMMethod = encoder1RMMethod;
+		
+		//---- end of encoder other
+		
+		//multimedia ----
+		if( preferences.volumeOn != PreferencesWindowBox.checkbutton_volume.Active ) {
+			SqlitePreferences.Update("volumeOn", PreferencesWindowBox.checkbutton_volume.Active.ToString(), true);
+			preferences.volumeOn = PreferencesWindowBox.checkbutton_volume.Active;
+		}
+
 		if( preferences.videoDeviceNum != UtilGtk.ComboGetActivePos(combo_camera) ) {
 			SqlitePreferences.Update("videoDevice", UtilGtk.ComboGetActivePos(combo_camera).ToString(), true);
 			preferences.videoDeviceNum = UtilGtk.ComboGetActivePos(combo_camera);
@@ -1020,35 +1196,6 @@ public class PreferencesWindow {
 			preferences.useHeightsOnJumpIndexes = PreferencesWindowBox.radio_use_heights_on_jump_indexes.Active;
 		}
 
-		if(PreferencesWindowBox.radio_encoder_auto_save_curve_best.Active) {
-			SqlitePreferences.Update("encoderAutoSaveCurve", Constants.EncoderAutoSaveCurve.BEST.ToString(), true);
-			preferences.encoderAutoSaveCurve = Constants.EncoderAutoSaveCurve.BEST;
-		}
-		else if(PreferencesWindowBox.radio_encoder_auto_save_curve_4top.Active) {
-			SqlitePreferences.Update("encoderAutoSaveCurve", Constants.EncoderAutoSaveCurve.FROM4TOPENULTIMATE.ToString(), true);
-			preferences.encoderAutoSaveCurve = Constants.EncoderAutoSaveCurve.FROM4TOPENULTIMATE;
-		}
-		else if(PreferencesWindowBox.radio_encoder_auto_save_curve_all.Active) {
-			SqlitePreferences.Update("encoderAutoSaveCurve", Constants.EncoderAutoSaveCurve.ALL.ToString(), true);
-			preferences.encoderAutoSaveCurve = Constants.EncoderAutoSaveCurve.ALL;
-		}
-		else {
-			SqlitePreferences.Update("encoderAutoSaveCurve", Constants.EncoderAutoSaveCurve.NONE.ToString(), true);
-			preferences.encoderAutoSaveCurve = Constants.EncoderAutoSaveCurve.NONE;
-		}
-
-		Constants.Encoder1RMMethod encoder1RMMethod;
-		if(PreferencesWindowBox.radio_encoder_1RM_nonweighted.Active)
-			encoder1RMMethod = Constants.Encoder1RMMethod.NONWEIGHTED;
-		else if(PreferencesWindowBox.radio_encoder_1RM_weighted.Active)
-			encoder1RMMethod = Constants.Encoder1RMMethod.WEIGHTED;
-		else if(PreferencesWindowBox.radio_encoder_1RM_weighted2.Active)
-			encoder1RMMethod = Constants.Encoder1RMMethod.WEIGHTED2;
-		else // (PreferencesWindowBox.radio_encoder_1RM_weighted3.Active)
-			encoder1RMMethod = Constants.Encoder1RMMethod.WEIGHTED3;
-
-		SqlitePreferences.Update("encoder1RMMethod", encoder1RMMethod.ToString(), true);
-		preferences.encoder1RMMethod = encoder1RMMethod;
 
 		Sqlite.Close();
 
@@ -1056,6 +1203,28 @@ public class PreferencesWindow {
 		PreferencesWindowBox = null;
 	}
 
+	private bool preferencesChange(string prefName, bool prefValue, bool bNew) 
+	{
+		if(prefValue != bNew)
+			SqlitePreferences.Update(prefName, bNew.ToString(), true);
+		
+		return bNew;
+	}
+	private int preferencesChange(string prefName, int prefValue, int iNew) 
+	{
+		if(prefValue != iNew)
+			SqlitePreferences.Update(prefName, iNew.ToString(), true);
+		
+		return iNew;
+	}
+	private double preferencesChange(string prefName, double prefValue, double dNew) 
+	{
+		if(prefValue != dNew)
+			SqlitePreferences.Update(prefName, Util.ConvertToPoint(dNew), true);
+		
+		return dNew;
+	}
+
 	public Button Button_accept 
 	{
 		set { button_accept = value; }
