@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -163,7 +163,7 @@ public class QueryServerWindow
 	public QueryServerWindow (int newPrefsDigitsNumber, string [] evaluators)
 	{
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "query_server_window", "chronojump");
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "query_server_window.glade", "query_server_window", "chronojump");
 		gladeXML.Autoconnect(this);
 		
 		this.pDN = newPrefsDigitsNumber;
@@ -776,7 +776,7 @@ public class QueryServerWindow
 				testType == Catalog.GetString(Constants.JumpReactiveName))
 			label_results_num_units.Text = Catalog.GetString("jumps");
 		else if (testType == Catalog.GetString(Constants.RunSimpleName))
-			label_results_num_units.Text = Catalog.GetString("runs");
+			label_results_num_units.Text = Catalog.GetString("races");
 
 		string strVariable = UtilGtk.ComboGetActive(combo_variables);
 		if(result == "0")
