@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -109,13 +109,10 @@ public class RepetitiveConditionsWindow
 	[Widget] Gtk.SpinButton spinbutton_encoder_peakpower_higher;
 	[Widget] Gtk.SpinButton spinbutton_encoder_power_lower;
 	[Widget] Gtk.SpinButton spinbutton_encoder_peakpower_lower;
+	[Widget] Gtk.CheckButton checkbutton_inertial_discard_first_three;
 
 
-	/* bell tests*/	
-	[Widget] Gtk.RadioButton radiobutton_test_good;
-	[Widget] Gtk.RadioButton radiobutton_test_bad;
-
-	[Widget] Gtk.Button button_test;
+	[Widget] Gtk.Button button_test_good;
 	[Widget] Gtk.Button button_close;
 
 	//bells good (green)
@@ -164,7 +161,7 @@ public class RepetitiveConditionsWindow
 		
 	RepetitiveConditionsWindow () {
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "repetitive_conditions", "chronojump");
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "repetitive_conditions.glade", "repetitive_conditions", "chronojump");
 		gladeXML.Autoconnect(this);
 		
 		//don't show until View is called
@@ -289,14 +286,13 @@ public class RepetitiveConditionsWindow
 	void on_button_test_clicked (object o, EventArgs args)
 	{
 		if(volumeOn) {
-			if (radiobutton_test_good.Active) 
+			if (o == button_test_good) 
 				Util.PlaySound(Constants.SoundTypes.GOOD, true);
-			else
+			else //button_test_bad
 				Util.PlaySound(Constants.SoundTypes.BAD, true);
 		} else
 			new DialogMessage(Constants.MessageTypes.INFO, 
-					Catalog.GetString("You need to activate sounds in main window") + 
-					" (" + Catalog.GetString("top right") + ")");
+					Catalog.GetString("You need to activate sounds in preferences / multimedia."));
 
 	}
 
@@ -579,6 +575,41 @@ public class RepetitiveConditionsWindow
 		get { return Convert.ToInt32(spinbutton_encoder_automatic_lower.Value); }
 	}
 	
+	public double GetMainVariableHigher(string mainVariable) 
+	{
+		if(mainVariable == Constants.MeanSpeed && EncoderMeanSpeedHigher)
+			return EncoderMeanSpeedHigherValue;
+		else if(mainVariable == Constants.MaxSpeed && EncoderMaxSpeedHigher)
+			return EncoderMaxSpeedHigherValue;
+		else if(mainVariable == Constants.MeanForce && EncoderMeanForceHigher)
+			return EncoderMeanForceHigherValue;
+		else if(mainVariable == Constants.MaxForce && EncoderMaxForceHigher)
+			return EncoderMaxForceHigherValue;
+		else if(mainVariable == Constants.MeanPower && EncoderPowerHigher)
+			return EncoderPowerHigherValue;
+		else if(mainVariable == Constants.PeakPower && EncoderPeakPowerHigher)
+			return EncoderPeakPowerHigherValue;
+
+		return -1;
+	}
+
+	public double GetMainVariableLower(string mainVariable) 
+	{
+		if(mainVariable == Constants.MeanSpeed && EncoderMeanSpeedLower)
+			return EncoderMeanSpeedLowerValue;
+		else if(mainVariable == Constants.MaxSpeed && EncoderMaxSpeedLower)
+			return EncoderMaxSpeedLowerValue;
+		else if(mainVariable == Constants.MeanForce && EncoderMeanForceLower)
+			return EncoderMeanForceLowerValue;
+		else if(mainVariable == Constants.MaxForce && EncoderMaxForceLower)
+			return EncoderMaxForceLowerValue;
+		else if(mainVariable == Constants.MeanPower && EncoderPowerLower)
+			return EncoderPowerLowerValue;
+		else if(mainVariable == Constants.PeakPower && EncoderPeakPowerLower)
+			return EncoderPeakPowerLowerValue;
+			
+		return -1;
+	}
 
 	//height
 	public bool EncoderHeightHigher {
@@ -681,6 +712,10 @@ public class RepetitiveConditionsWindow
 	public int EncoderPeakPowerLowerValue {
 		get { return Convert.ToInt32(spinbutton_encoder_peakpower_lower.Value); }
 	}
+	
+	public bool EncoderInertialDiscardFirstThree {
+		get { return checkbutton_inertial_discard_first_three.Active; }
+	}
 
 }
 
