@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -42,17 +42,17 @@ public class EditRunWindow : EditEventWindow
 
 	public EditRunWindow (Gtk.Window parent) {
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "edit_event", null);
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "edit_event.glade", "edit_event", null);
 		gladeXML.Autoconnect(this);
 		this.parent = parent;
 		
 		//put an icon to window
 		UtilGtk.IconWindow(edit_event);
 	
-		eventBigTypeString = Catalog.GetString("run");
+		eventBigTypeString = Catalog.GetString("race");
 	}
 
-	static new public EditRunWindow Show (Gtk.Window parent, Event myEvent, int pDN, bool metersSecondsPreferred)
+	static public EditRunWindow Show (Gtk.Window parent, Event myEvent, int pDN, bool metersSecondsPreferred)
 	{
 		if (EditRunWindowBox == null) {
 			EditRunWindowBox = new EditRunWindow (parent);
@@ -252,14 +252,14 @@ public class EditRunIntervalWindow : EditRunWindow
 
 	EditRunIntervalWindow (Gtk.Window parent) {
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "edit_event", null);
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "edit_event.glade", "edit_event", null);
 		gladeXML.Autoconnect(this);
 		this.parent = parent;
 		
 		//put an icon to window
 		UtilGtk.IconWindow(edit_event);
 	
-		eventBigTypeString = Catalog.GetString("intervallic run");
+		eventBigTypeString = Catalog.GetString("intervallic race");
 	}
 
 	static new public EditRunIntervalWindow Show (Gtk.Window parent, Event myEvent, int pDN, bool metersSecondsPreferred)
@@ -575,7 +575,6 @@ public class RepairRunIntervalWindow
 	[Widget] Gtk.TextView textview1;
 
 	static RepairRunIntervalWindow RepairRunIntervalWindowBox;
-	Gtk.Window parent;
 
 	RunType type;
 	RunInterval runInterval; //used on button_accept
@@ -583,16 +582,16 @@ public class RepairRunIntervalWindow
 
 	RepairRunIntervalWindow (Gtk.Window parent, RunInterval myRun, int pDN) {
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "repair_sub_event", null);
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "repair_sub_event.glade", "repair_sub_event", null);
 		gladeXML.Autoconnect(this);
-		this.parent = parent;
+		repair_sub_event.Parent = parent;
 		
 		//put an icon to window
 		UtilGtk.IconWindow(repair_sub_event);
 
 		this.runInterval = myRun;
 	
-		repair_sub_event.Title = Catalog.GetString("Repair intervallic run");
+		repair_sub_event.Title = Catalog.GetString("Repair intervallic race");
 		
 		System.Globalization.NumberFormatInfo localeInfo = new System.Globalization.NumberFormatInfo();
 		localeInfo = System.Globalization.NumberFormatInfo.CurrentInfo;
@@ -634,7 +633,7 @@ public class RepairRunIntervalWindow
 	
 	private string createTextForTextView (RunType myRunType) {
 		string runTypeString = string.Format(Catalog.GetString(
-					"RunType: {0}."), myRunType.Name);
+					"RaceType: {0}."), myRunType.Name);
 
 		string fixedString = "";
 		if(myRunType.FixedValue > 0) {
@@ -642,8 +641,8 @@ public class RepairRunIntervalWindow
 				//if it's a run type runsLimited with a fixed value, then don't allow the creation of more runs
 				fixedString = "\n" +  string.Format(
 						Catalog.GetPluralString(
-							"This run type is fixed to one run.", 
-							"This run type is fixed to {0} runs.",
+							"This race type is fixed to one lap.",
+							"This race type is fixed to {0} laps.",
 							myRunType.FixedValue), 
 						myRunType.FixedValue) +
 					Catalog.GetString("You cannot add more.");
@@ -651,8 +650,8 @@ public class RepairRunIntervalWindow
 				//if it's a run type timeLimited with a fixed value, then complain when the total time is higher
 				fixedString = "\n" + string.Format(
 						Catalog.GetPluralString(
-							"This run type is fixed to one second.",
-							"This run type is fixed to {0} seconds.",
+							"This race type is fixed to one second.",
+							"This race type is fixed to {0} seconds.",
 							myRunType.FixedValue),
 						myRunType.FixedValue) +
 					Catalog.GetString("Totaltime cannot be greater.");
@@ -886,7 +885,7 @@ public class RepairRunIntervalWindow
 //---------------- in 0.9.3 included in main gui ---------
 //--------------------------------------------------------
 
-partial class ChronoJumpWindow
+public partial class ChronoJumpWindow
 {
 	//options runs
 	[Widget] Gtk.Label extra_window_runs_label_distance;
@@ -930,7 +929,7 @@ partial class ChronoJumpWindow
 	
 	private void on_extra_window_runs_test_changed(object o, EventArgs args)
 	{
-		string runEnglishName = Util.FindOnArray(':',2,1, UtilGtk.ComboGetActive(combo_select_runs), selectRunsString);
+		string runEnglishName = comboSelectRuns.GetSelectedNameEnglish();
 		currentRunType = createRunType(runEnglishName, true);
 		
 		extra_window_runs_initialize(currentRunType);
@@ -948,7 +947,7 @@ partial class ChronoJumpWindow
 	
 	private void on_extra_window_runs_interval_test_changed(object o, EventArgs args)
 	{
-		string runEnglishName = Util.FindOnArray(':',2,1, UtilGtk.ComboGetActive(combo_select_runs_interval), selectRunsIntervalString);
+		string runEnglishName = comboSelectRunsI.GetSelectedNameEnglish();
 		currentRunIntervalType = createRunType(runEnglishName, false);
 		
 		extra_window_runs_interval_initialize(currentRunIntervalType);
@@ -969,7 +968,7 @@ partial class ChronoJumpWindow
 		currentEventType = myRunType;
 		changeTestImage(EventType.Types.RUN.ToString(), myRunType.Name, myRunType.ImageFileName);
 
-		extra_window_runs_label_distance.Text = Catalog.GetString("Track distance (between platforms)");
+		extra_window_runs_label_distance.Text = Catalog.GetString("Lap distance (between barriers)");
 		extra_window_runs_label_distance_units.Text = Catalog.GetString("meters");
 
 		if(myRunType.Distance > 0) {
@@ -995,7 +994,7 @@ partial class ChronoJumpWindow
 
 		//intializeVariables if not done before
 		event_execute_initializeVariables(
-			! chronopicWin.Connected,	//is simulated
+			! cp2016.StoredCanCaptureContacts, //is simulated
 			currentPerson.UniqueID, 
 			currentPerson.Name, 
 			Catalog.GetString("Phases"),  	  //name of the different moments
@@ -1010,6 +1009,16 @@ partial class ChronoJumpWindow
 		if(eventGraph.personMAXAtSQLAllSessions > 0 || eventGraph.runsAtSQL.Length > 0)
 			PrepareRunSimpleGraph(eventGraph, false); //don't animate
 	}
+	private void updateGraphRunsInterval ()
+	{
+		if(event_execute_drawingarea == null || event_execute_pixmap == null)
+			return;
+
+		UtilGtk.ErasePaint(event_execute_drawingarea, event_execute_pixmap);
+		event_execute_table_run_interval_values.Hide();
+
+		//TODO paint graph of num of intervallic runs
+	}
 	
 	private void extra_window_runs_interval_initialize(RunType myRunType) 
 	{
@@ -1027,7 +1036,7 @@ partial class ChronoJumpWindow
 		}
 
 		if(! myRunType.Unlimited) {
-			string tracksName = Catalog.GetString("tracks");
+			string tracksName = Catalog.GetString("laps");
 			string secondsName = Catalog.GetString("seconds");
 			if(myRunType.TracksLimited) 
 				extra_window_runs_interval_label_limit_units.Text = tracksName;
@@ -1052,18 +1061,16 @@ partial class ChronoJumpWindow
 		}
 	}
 
-	private void on_more_runs_update_test (object o, EventArgs args) {
+	private void on_more_runs_update_test (object o, EventArgs args) 
+	{
 		currentEventType = new RunType(runsMoreWin.SelectedEventName);
-		string runTranslatedName = Util.FindOnArray(':',1,2, runsMoreWin.SelectedEventName, selectRunsString);
-		
-		combo_select_runs.Active = UtilGtk.ComboMakeActive(combo_select_runs, runTranslatedName);	
+		comboSelectRuns.MakeActive(runsMoreWin.SelectedEventName);
 	}
 	
-	private void on_more_runs_interval_update_test (object o, EventArgs args) {
+	private void on_more_runs_interval_update_test (object o, EventArgs args)
+	{
 		currentEventType = new RunType(runsIntervalMoreWin.SelectedEventName);
-		string runTranslatedName = Util.FindOnArray(':',1,2, runsIntervalMoreWin.SelectedEventName, selectRunsIntervalString);
-		
-		combo_select_runs_interval.Active = UtilGtk.ComboMakeActive(combo_select_runs_interval, runTranslatedName);	
+		comboSelectRunsI.MakeActive(runsIntervalMoreWin.SelectedEventName);
 	}
 	
 	
@@ -1151,7 +1158,7 @@ public class RunsMoreWindow : EventMoreWindow
 	
 	RunsMoreWindow (Gtk.Window parent, bool testOrDelete) {
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "jumps_runs_more", null);
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "jumps_runs_more.glade", "jumps_runs_more", null);
 		gladeXML.Autoconnect(this);
 		this.parent = parent;
 		this.testOrDelete = testOrDelete;
@@ -1338,7 +1345,7 @@ public class RunsIntervalMoreWindow : EventMoreWindow
 	RunsIntervalMoreWindow (Gtk.Window parent, bool testOrDelete) {
 		//the glade window is the same as jumps_more
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "jumps_runs_more", "chronojump");
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "jumps_runs_more.glade", "jumps_runs_more", "chronojump");
 		gladeXML.Autoconnect(this);
 		this.parent = parent;
 		this.testOrDelete = testOrDelete;
@@ -1406,7 +1413,7 @@ public class RunsIntervalMoreWindow : EventMoreWindow
 				myLimiter= Catalog.GetString("Unlimited");
 				myLimiterValue = "-";
 			} else {
-				myLimiter = Catalog.GetString("Tracks");
+				myLimiter = Catalog.GetString("Laps");
 				if(myStringFull[3] == "0") {
 					myLimiter = Catalog.GetString("Seconds");
 				}
@@ -1474,7 +1481,7 @@ public class RunsIntervalMoreWindow : EventMoreWindow
 				selectedUnlimited = true;
 			} 
 
-			if( (string) model.GetValue (iter, 2) == Catalog.GetString("Tracks") ) {
+			if( (string) model.GetValue (iter, 2) == Catalog.GetString("Laps") ) {
 				selectedTracksLimited = true;
 			}
 
@@ -1526,7 +1533,7 @@ public class RunsIntervalMoreWindow : EventMoreWindow
 				selectedUnlimited = true;
 			} 
 			
-			if( (string) model.GetValue (iter, 2) == Catalog.GetString("Tracks") ) {
+			if( (string) model.GetValue (iter, 2) == Catalog.GetString("Laps") ) {
 				selectedTracksLimited = true;
 			}
 
