@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -79,15 +79,14 @@ public class RunTypeAddWindow
 	[Widget] Gtk.Entry dd9;
 
 	static RunTypeAddWindow RunTypeAddWindowBox;
-	Gtk.Window parent;
 
 	public bool InsertedSimple;
 
 	RunTypeAddWindow (Gtk.Window parent, bool simple) {
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "run_type_add", "chronojump");
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "run_type_add.glade", "run_type_add", "chronojump");
 		gladeXML.Autoconnect(this);
-		this.parent = parent;
+		run_type_add.Parent = parent;
 		
 		fakeButtonAccept = new Gtk.Button();
 
@@ -173,7 +172,7 @@ public class RunTypeAddWindow
 			runTypeExists = true;
 		
 		if(runTypeExists) {
-			string myString = string.Format(Catalog.GetString("Run type: '{0}' exists. Please, use another name"), name); 
+			string myString = string.Format(Catalog.GetString("Race type: '{0}' exists. Please, use another name"), name);
 			LogB.Information (myString);
 			ErrorWindow.Show(myString);
 		} else {
@@ -249,7 +248,7 @@ public class RunTypeAddWindow
 	
 	void on_radiobutton_interval_toggled (object o, EventArgs args)
 	{
-		label_distance.Text = "Distance\nof each track";
+		label_distance.Text = "Distance\nof each lap";
 		vbox_limited.Sensitive = true;	
 		if( ! radiobutton_unlimited.Active) {
 			hbox_fixed.Sensitive = true;	
@@ -357,14 +356,14 @@ public class RunTypeAddWindow
 	
 	private void on_button_help_rsa_clicked (object o, EventArgs args) {
 		new DialogMessage(Constants.MessageTypes.HELP, 
-				Catalog.GetString("On RSA tests, rest time counts as a \"track\".") + 
+				Catalog.GetString("On RSA tests, rest time counts as a \"lap\".") +
 				"\n" + 	Catalog.GetString("You should write the time in seconds after a capital 'R' (meaning \"Rest\").") + 
 				"\n\n" + 	Catalog.GetString("Eg. Aziz et al. (2000) test repeats 8 times the following sequence:") + 
 				"\n\n\t" + Catalog.GetString("Run 40 meters, rest 30 seconds.") + 
-				"\n\n" + Catalog.GetString("Will be limited by tracks with a fixed value of 16") + 
-				"\n" + Catalog.GetString("because there are 16 tracks:") + 
-				"\n" + Catalog.GetString("2 different tracks: ('Run' and 'rest') x 8 times") + 
-				"\n\n" + Catalog.GetString("And the 'distance' of each different track will be:") + 
+				"\n\n" + Catalog.GetString("Will be limited by laps with a fixed value of 16") +
+				"\n" + Catalog.GetString("because there are 16 laps:") +
+				"\n" + Catalog.GetString("2 different laps: ('Run' and 'rest') x 8 times") +
+				"\n\n" + Catalog.GetString("And the 'distance' of each different lap will be:") +
 				"\n\n\t40, R30"
 				);
 	}
