@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -34,7 +34,6 @@ public class SessionAddEditWindow {
 	[Widget] Gtk.Entry entry_place;
 	
 	[Widget] Gtk.Label label_date;
-	[Widget] Gtk.Button button_change_date;
 	
 	[Widget] Gtk.TextView textview;
 	[Widget] Gtk.Button button_accept;
@@ -65,10 +64,8 @@ public class SessionAddEditWindow {
 	Sport sport;
 	string [] sports;
 	string [] sportsTranslated;
-	int speciallityID;
 	string [] speciallities;
 	string [] speciallitiesTranslated;
-	String level;
 	string [] levels;
 
 	bool addSession;
@@ -78,14 +75,13 @@ public class SessionAddEditWindow {
 	
 	GenericWindow genericWin;
 	static SessionAddEditWindow SessionAddEditWindowBox;
-	Gtk.Window parent;
 	
 	
 	SessionAddEditWindow (Gtk.Window parent, Session currentSession) {
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "session_add_edit", null);
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "session_add_edit.glade", "session_add_edit", null);
 		gladeXML.Autoconnect(this);
-		this.parent = parent;
+		session_add_edit.Parent = parent;
 		
 		//put an icon to window
 		UtilGtk.IconWindow(session_add_edit);
@@ -646,28 +642,51 @@ public class SessionAddEditWindow {
 
 
 public class SessionLoadWindow {
-	
+
+	public enum WindowType
+	{
+		LOAD_SESSION,
+		IMPORT_SESSION
+	};
 	[Widget] Gtk.Window session_load;
 	
 	private TreeStore store;
 	private string selected;
+	private string import_file_path;
 	[Widget] Gtk.TreeView treeview_session_load;
 	[Widget] Gtk.Button button_accept;
 	[Widget] Gtk.Entry entry_search_filter;
 	[Widget] Gtk.CheckButton checkbutton_show_data_jump_run;
 	[Widget] Gtk.CheckButton checkbutton_show_data_encoder;
+	[Widget] Gtk.Label file_path_import;
+	[Widget] Gtk.VBox session_import_box;
+	
+	[Widget] Gtk.RadioButton radio_import_new_session;
+	[Widget] Gtk.RadioButton radio_import_current_session;
 
 	static SessionLoadWindow SessionLoadWindowBox;
-	Gtk.Window parent;
 	
 	private Session currentSession;
-	
-	SessionLoadWindow (Gtk.Window parent) {
+	private WindowType type;
+
+	SessionLoadWindow (Gtk.Window parent, WindowType type) {
+		this.type = type;
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "session_load", null);
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "session_load.glade", "session_load", null);
 		gladeXML.Autoconnect(this);
-		this.parent = parent;
-		
+		session_load.Parent = parent;
+
+		// Hides and shows widgets only needed by some of the functionality
+		session_import_box.Visible = (type == WindowType.IMPORT_SESSION);
+		checkbutton_show_data_encoder.Visible = (type == WindowType.LOAD_SESSION);
+		checkbutton_show_data_jump_run.Visible = (type == WindowType.LOAD_SESSION);
+
+		if (type == WindowType.LOAD_SESSION) {
+			session_load.Title = Catalog.GetString ("Load session");
+		} else {
+			session_load.Title = Catalog.GetString ("Import session");
+		}
+
 		//put an icon to window
 		UtilGtk.IconWindow(session_load);
 		
@@ -680,7 +699,21 @@ public class SessionLoadWindow {
 		entry_search_filter.CanFocus = true;
 		entry_search_filter.IsFocus = true;
 
+		// Leave the state of the Importing Comboboxes as they are by default
+		/*radio_import_new_session.Active = true;
+		radio_import_current_session.Sensitive = false;
+		*/
+
 		treeview_session_load.Selection.Changed += onSelectionEntry;
+
+		/**
+		* Uncomment if we want the session file chooser to be loaded with the dialog.
+		* On Linux at least the placement of the Windows can be strange so at the moment
+		* I leave it disabled until we discuss (to enable or to delete it).
+		if (type == WindowType.IMPORT_SESSION) {
+			chooseDatabaseToImport ();
+		}
+		*/
 	}
 
 	private TreeStore getStore(bool showContacts, bool showEncoder) {
@@ -719,11 +752,13 @@ public class SessionLoadWindow {
 	}
 
 	
-	static public SessionLoadWindow Show (Gtk.Window parent)
+	static public SessionLoadWindow Show (Gtk.Window parent, WindowType type)
 	{
 		if (SessionLoadWindowBox == null) {
-			SessionLoadWindowBox = new SessionLoadWindow (parent);
+			SessionLoadWindowBox = new SessionLoadWindow (parent, type);
 		}
+		SessionLoadWindowBox.recreateTreeView("loaded the dialog");
+
 		SessionLoadWindowBox.session_load.Show ();
 		
 		return SessionLoadWindowBox;
@@ -744,8 +779,8 @@ public class SessionLoadWindow {
 		if(showContacts) {
 			tv.AppendColumn ( Catalog.GetString ("Jumps simple"), new CellRendererText(), "text", count++);
 			tv.AppendColumn ( Catalog.GetString ("Jumps reactive"), new CellRendererText(), "text", count++);
-			tv.AppendColumn ( Catalog.GetString ("Runs simple"), new CellRendererText(), "text", count++);
-			tv.AppendColumn ( Catalog.GetString ("Runs interval"), new CellRendererText(), "text", count++);
+			tv.AppendColumn ( Catalog.GetString ("Races simple"), new CellRendererText(), "text", count++);
+			tv.AppendColumn ( Catalog.GetString ("Races interval"), new CellRendererText(), "text", count++);
 			tv.AppendColumn ( Catalog.GetString ("Reaction time"), new CellRendererText(), "text", count++);
 			tv.AppendColumn ( Catalog.GetString ("Pulses"), new CellRendererText(), "text", count++);
 			tv.AppendColumn ( Catalog.GetString ("MultiChronopic"), new CellRendererText(), "text", count++);
@@ -764,6 +799,30 @@ public class SessionLoadWindow {
 	protected void on_entry_search_filter_changed (object o, EventArgs args) {
 		recreateTreeView("changed search filter");
 	}
+	protected void on_select_file_import_clicked(object o, EventArgs args) {
+		chooseDatabaseToImport ();
+	}
+
+	private void chooseDatabaseToImport()
+	{
+		Gtk.FileChooserDialog filechooser = new Gtk.FileChooserDialog ("Choose ChronoJump database to import from",
+		                                                               session_load, FileChooserAction.Open,
+		                                                               "Cancel",ResponseType.Cancel,
+		                                                               "Open",ResponseType.Accept);
+
+		FileFilter file_filter = new FileFilter();
+		file_filter.AddPattern ("*.db");
+		file_filter.Name = "ChronoJump database";
+		filechooser.AddFilter (file_filter);
+
+		if (filechooser.Run () == (int)ResponseType.Accept) {
+			import_file_path = filechooser.Filename;
+			file_path_import.Text = System.IO.Path.GetFileName (import_file_path);
+			file_path_import.TooltipText = import_file_path;
+		}
+		filechooser.Destroy ();
+		recreateTreeView ("file path changed");
+	}
 	void on_checkbutton_show_data_jump_run_toggled (object o, EventArgs args) {
 		recreateTreeView("jump run " + checkbutton_show_data_jump_run.Active.ToString());
 	}
@@ -796,8 +855,16 @@ public class SessionLoadWindow {
 		string filterName = "";
 		if(entry_search_filter.Text.ToString().Length > 0) 
 			filterName = entry_search_filter.Text.ToString();
+
+		SqliteSessionSwitcher.DatabaseType databaseType;
+		if (type == WindowType.LOAD_SESSION) {
+			databaseType = SqliteSessionSwitcher.DatabaseType.DEFAULT;
+		} else {
+			databaseType = SqliteSessionSwitcher.DatabaseType.SPECIFIC;
+		}
+		SqliteSessionSwitcher sessionSwitcher = new SqliteSessionSwitcher (databaseType, import_file_path);
 		
-		string [] mySessions = SqliteSession.SelectAllSessions(filterName); //returns a string of values separated by ':'
+		string [] mySessions = sessionSwitcher.SelectAllSessions(filterName); //returns a string of values separated by ':'
 		foreach (string session in mySessions) {
 			string [] myStringFull = session.Split(new char[] {':'});
 		
@@ -877,7 +944,7 @@ public class SessionLoadWindow {
 	}
 	
 	//pass 0 for first row
-	public void SelectRow(int rowNumber)
+	public void SelectRowByPos(int rowNumber)
 	{
 		TreeIter iter;
 		bool iterOk = store.GetIterFirst(out iter);
@@ -890,6 +957,12 @@ public class SessionLoadWindow {
 			treeview_session_load.Selection.SelectIter(iter);
 		}
 	}
+
+	public bool SelectRowByID(int searchedID)
+	{
+		return UtilGtk.TreeviewSelectRowWithID(
+				treeview_session_load, store, 0, searchedID, false);
+	}
 	
 	private void onSelectionEntry (object o, EventArgs args)
 	{
@@ -903,7 +976,31 @@ public class SessionLoadWindow {
 		} else
 			button_accept.Sensitive = false;
 	}
-	
+
+	public int CurrentSessionId() {
+		TreeModel model;
+		TreeIter iter;
+
+		if (treeview_session_load.Selection.GetSelected (out model, out iter)) {
+			string selected = (string)model.GetValue (iter, 0);
+			return Convert.ToInt32 (selected.Split (':')[0]);
+		}
+		return -1;
+	}
+
+	public string ImportDatabasePath() {
+		return import_file_path;
+	}
+
+	public bool ImportToNewSession() {
+		return radio_import_new_session.Active;
+	}
+
+	public void DisableImportToCurrentSession() {
+		radio_import_new_session.Active = true;
+		radio_import_current_session.Sensitive = false;
+	}
+
 	void on_row_double_clicked (object o, Gtk.RowActivatedArgs args)
 	{
 		TreeView tv = (TreeView) o;
@@ -964,15 +1061,14 @@ public class SessionSelectStatsWindow {
 	[Widget] Gtk.Button button_accept;
 
 	static SessionSelectStatsWindow SessionSelectStatsWindowBox;
-	Gtk.Window parent;
 	
 	private ArrayList arrayOfSelectedSessions;
 	
 	SessionSelectStatsWindow (Gtk.Window parent, ArrayList oldSelectedSessions) {
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "stats_select_sessions", "chronojump");
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "stats_select_sessions.glade", "stats_select_sessions", "chronojump");
 		gladeXML.Autoconnect(this);
-		this.parent = parent;
+		stats_select_sessions.Parent = parent;
 		
 		//put an icon to window
 		UtilGtk.IconWindow(stats_select_sessions);
@@ -995,7 +1091,6 @@ public class SessionSelectStatsWindow {
 			SessionSelectStatsWindowBox = new SessionSelectStatsWindow (parent, oldSelectedSessions);
 		}
 		SessionSelectStatsWindowBox.stats_select_sessions.Show ();
-		
 		return SessionSelectStatsWindowBox;
 	}
 	
