@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -65,11 +65,8 @@ public partial class ChronoJumpWindow {
 	[Widget] Gtk.CheckButton checkbutton_show_enunciate;
 	
 	[Widget] Gtk.Notebook notebook_stats_win_options;
-	[Widget] Gtk.Box hbox_mark_consecutives;
 	[Widget] Gtk.CheckButton checkbutton_mark_consecutives;
 	[Widget] Gtk.SpinButton spinbutton_mark_consecutives;
-	[Widget] Gtk.Label label_subtraction_between;
-	[Widget] Gtk.Box hbox_subtraction_between;
 	[Widget] Gtk.Box hbox_subtraction_between_1;
 	[Widget] Gtk.Box hbox_subtraction_between_2;
 	[Widget] Gtk.ComboBox combo_subtraction_between_1;
@@ -115,8 +112,6 @@ public partial class ChronoJumpWindow {
 		
 	[Widget] Gtk.Label label_stats_x_axis;
 
-	//bool statsAutomatic = true;
-	bool statsAutomatic = false;
 	bool statsColumnsToRemove = false;
 	//selected sessions
 	ArrayList selectedSessions;
@@ -551,11 +546,16 @@ public partial class ChronoJumpWindow {
 		return Util.AddArrayString(comboCheckboxesOptionsWithoutPersons, Util.ArrayListToString(myStatType.PersonsWithData));
 	}
 
-	private void showUpdateStatsAndHideData(bool show) {
-		button_stats.Sensitive = show;
-		treeview_stats.Sensitive = ! show;
-		hbox_mark_and_enunciate.Sensitive = ! show;
-		frame_graph_and_report.Sensitive = ! show;
+	private void showUpdateStatsAndHideData(bool show)
+	{
+		//as this is called by cancel and finish, check that we are on first thread to not have GTK problems
+		if(UtilGtk.CanTouchGTK())
+		{
+			button_stats.Sensitive = show;
+			treeview_stats.Sensitive = ! show;
+			hbox_mark_and_enunciate.Sensitive = ! show;
+			frame_graph_and_report.Sensitive = ! show;
+		}
 	}
 	
 	private void updateComboStats() {
@@ -598,8 +598,9 @@ public partial class ChronoJumpWindow {
 			
 			//by default show all simple nonTC jumps, but if combo_stats_subtype changed
 			//updateComboStatsSubType() will do the work
-			UtilGtk.ComboUpdate(combo_stats_stat_apply_to, 
-				SqliteJumpType.SelectJumpTypes(false, Constants.AllJumpsName, "nonTC", true), ""); //only select name
+			UtilGtk.ComboUpdate(combo_stats_stat_apply_to,
+					SqliteJumpType.SelectJumpTypes(false, Constants.AllJumpsName, "nonTC", true), ""); //only select name
+
 			combo_stats_stat_apply_to.Sensitive = true;
 			combo_stats_stat_apply_to.Active = 0;
 		} 
