@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -32,9 +32,6 @@ public class JumpsProfileIndex
 	public Cairo.Color Color;
 	public string ErrorMessage;
 	
-	private string jumpHigherName;
-	private string jumpLowerName;
-	
 	public enum Types { FMAX, FEXPL, CELAST, CARMS, FREACT }   
 	public Types type; 
 
@@ -71,9 +68,6 @@ public class JumpsProfileIndex
 				break;
 		}
 		
-		this.jumpHigherName = jumpHigherName;
-		this.jumpLowerName = jumpLowerName;
-		
 		ErrorMessage = "";
 		Result = calculateIndex(type, higher, lower, dja);
 		
