@@ -6,7 +6,7 @@
 //
 // Copyright (C) 2005-2007 Novell, Inc.
 //
-// Minor tweaks by Xavier de Blas <xaviblas@gmail.com> 2014,2016
+// Minor tweaks by Xavier de Blas <xaviblas@gmail.com> 2014,2016-2017
 //
 // Permission is hereby granted, free of charge, to any person obtaining
 // a copy of this software and associated documentation files (the
@@ -58,7 +58,7 @@ public enum LogEntryType
 	Warning,
 	Error,
 	Information,
-	SQL, SQLon, SQLoff,
+	SQL, SQLon, SQLoff, SQLonAlready, //already means: was not opened because it was already opened
 	ThreadStart, ThreadEnding, ThreadEnded,
 	TestStart, TestEnd
 }
@@ -154,6 +154,13 @@ public static class LogB
 	private static Dictionary<uint, DateTime> timers = new Dictionary<uint, DateTime> ();
 	private static uint next_timer_id = 1;
 
+	/*
+	 * Chronojump can be called with a param printAll (chronojump printAll) and then all threads will be printed
+	 * default behaviour is to print only when on GTK thread, and messages from other threads
+	 * will be stored and printed by GTK thread before what it needs to print
+	 */
+	public static bool PrintAllThreads = false;
+
 	private static bool debugging = false;
 	public static bool Debugging {
 		get {
@@ -173,52 +180,8 @@ public static class LogB
 			return;
 		}
 
-		if(type != LogEntryType.Information || (type == LogEntryType.Information && !showUser)) {
-			switch(type) {
-				case LogEntryType.Error:
-					ConsoleCrayon.ForegroundColor = ConsoleColor.Red;
-					break;
-				case LogEntryType.Warning:
-					ConsoleCrayon.ForegroundColor = ConsoleColor.DarkYellow;
-					break;
-				case LogEntryType.Information:
-					ConsoleCrayon.ForegroundColor = ConsoleColor.Green;
-					break;
-				case LogEntryType.Debug:
-					ConsoleCrayon.ForegroundColor = ConsoleColor.Blue;
-					break;
-				case LogEntryType.SQL:
-					ConsoleCrayon.ForegroundColor = ConsoleColor.Cyan;
-					break;
-				case LogEntryType.SQLon:
-					ConsoleCrayon.BackgroundColor = ConsoleColor.DarkCyan;
-					ConsoleCrayon.ForegroundColor = ConsoleColor.White;
-					break;
-				case LogEntryType.SQLoff:
-					ConsoleCrayon.BackgroundColor = ConsoleColor.DarkCyan;
-					ConsoleCrayon.ForegroundColor = ConsoleColor.Black;
-					break;
-				case LogEntryType.ThreadStart:
-					ConsoleCrayon.BackgroundColor = ConsoleColor.Green;
-					ConsoleCrayon.ForegroundColor = ConsoleColor.Black;
-					break;
-				case LogEntryType.ThreadEnding:
-					ConsoleCrayon.BackgroundColor = ConsoleColor.Yellow;
-					ConsoleCrayon.ForegroundColor = ConsoleColor.Black;
-					break;
-				case LogEntryType.ThreadEnded:
-					ConsoleCrayon.BackgroundColor = ConsoleColor.Red;
-					ConsoleCrayon.ForegroundColor = ConsoleColor.Black;
-					break;
-				case LogEntryType.TestStart:
-					ConsoleCrayon.BackgroundColor = ConsoleColor.Blue;
-					ConsoleCrayon.ForegroundColor = ConsoleColor.Black;
-					break;
-				case LogEntryType.TestEnd:
-					ConsoleCrayon.BackgroundColor = ConsoleColor.Blue;
-					ConsoleCrayon.ForegroundColor = ConsoleColor.Black;
-					break;
-			}
+		if(type != LogEntryType.Information || (type == LogEntryType.Information && !showUser))
+		{
 
 			var thread_name = String.Empty;
 			bool printNow = false;
@@ -235,24 +198,90 @@ public static class LogB
 			string lineStart = string.Format("[{5}{0} {1:00}:{2:00}:{3:00}.{4:000}]", TypeString(type), DateTime.Now.Hour,
 					DateTime.Now.Minute, DateTime.Now.Second, DateTime.Now.Millisecond, thread_name);
 
-			if(printNow) {
-				//try {
-					Console.Write(lineStart);
-	
-					ConsoleCrayon.ResetColor();
-	
-					message += LogSync.ReadAndEmpty();
-	
-					if(details != null) {
-						Console.WriteLine(" {0} - {1}", message, details);
-					} else {
-						if(type == LogEntryType.Debug)
-							Console.Write(" {0}", message);
-						else
-							Console.WriteLine(" {0}", message);
+			if(PrintAllThreads || printNow)
+			{
+				/*
+				 * only doing this in main thread now.
+				 * Less buggy and seems to have finished with ^@ and 92M messages
+				 */
+				switch(type) {
+					case LogEntryType.Error:
+						ConsoleCrayon.ForegroundColor = ConsoleColor.Red;
+						break;
+					case LogEntryType.Warning:
+						ConsoleCrayon.ForegroundColor = ConsoleColor.DarkYellow;
+						break;
+					case LogEntryType.Information:
+						ConsoleCrayon.ForegroundColor = ConsoleColor.Green;
+						break;
+					case LogEntryType.Debug:
+						ConsoleCrayon.ForegroundColor = ConsoleColor.Blue;
+						break;
+					case LogEntryType.SQL:
+						ConsoleCrayon.ForegroundColor = ConsoleColor.Cyan;
+						break;
+					case LogEntryType.SQLon:
+						ConsoleCrayon.BackgroundColor = ConsoleColor.DarkCyan;
+						ConsoleCrayon.ForegroundColor = ConsoleColor.White;
+						break;
+					case LogEntryType.SQLoff:
+						ConsoleCrayon.BackgroundColor = ConsoleColor.DarkCyan;
+						ConsoleCrayon.ForegroundColor = ConsoleColor.Black;
+						break;
+					case LogEntryType.SQLonAlready:
+						ConsoleCrayon.BackgroundColor = ConsoleColor.DarkCyan;
+						ConsoleCrayon.ForegroundColor = ConsoleColor.Gray;
+						break;
+					case LogEntryType.ThreadStart:
+						ConsoleCrayon.BackgroundColor = ConsoleColor.Green;
+						ConsoleCrayon.ForegroundColor = ConsoleColor.Black;
+						break;
+					case LogEntryType.ThreadEnding:
+						ConsoleCrayon.BackgroundColor = ConsoleColor.Yellow;
+						ConsoleCrayon.ForegroundColor = ConsoleColor.Black;
+						break;
+					case LogEntryType.ThreadEnded:
+						ConsoleCrayon.BackgroundColor = ConsoleColor.Red;
+						ConsoleCrayon.ForegroundColor = ConsoleColor.Black;
+						break;
+					case LogEntryType.TestStart:
+						ConsoleCrayon.BackgroundColor = ConsoleColor.Blue;
+						ConsoleCrayon.ForegroundColor = ConsoleColor.Black;
+						break;
+					case LogEntryType.TestEnd:
+						ConsoleCrayon.BackgroundColor = ConsoleColor.Blue;
+						ConsoleCrayon.ForegroundColor = ConsoleColor.Black;
+						break;
+				}
+
+				Console.Write(lineStart);
+
+				ConsoleCrayon.ResetColor();
+
+				//print messagesOtherThreads
+				//do not add to "message" because like this is better to find why crashes
+				string messagesOtherThreads = LogSync.ReadAndEmpty();
+				if(messagesOtherThreads != null) {
+					try {
+						Console.Write(messagesOtherThreads);
+					} catch (System.IndexOutOfRangeException) {
+						Console.Write("CATCHED printing messagesOtherThreads");
 					}
-				//} catch (System.IndexOutOfRangeException e) {
-				//}
+				}
+
+				//print messages this thread
+				if(details != null)
+					message += " - " + details;
+
+				try {
+					if(type == LogEntryType.Debug)
+						Console.Write(" {0}", message);
+					else
+						Console.WriteLine(" {0}", message);
+				}
+				catch (System.IndexOutOfRangeException) {
+					Console.Write("CATCHED printing main thread");
+				}
 			} else {
 				LogSync.Add(lineStart + "\n" + message);
 			}
@@ -280,6 +309,8 @@ public static class LogB
 				return "SQL ON";
 			case LogEntryType.SQLoff:
 				return "SQL OFF";
+			case LogEntryType.SQLonAlready:
+				return "SQL ON ALREADY!!!";
 			case LogEntryType.ThreadStart:
 				return "Thread Start -------------------------->";
 			case LogEntryType.ThreadEnding:
@@ -557,6 +588,11 @@ public static class LogB
 		Commit(LogEntryType.SQLoff, null, null, false);
 	}
 
+	public static void SQLonAlready()
+	{
+		Commit(LogEntryType.SQLonAlready, null, null, false);
+	}
+
 #endregion
 
 #region Public Thread Methods
