@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -44,16 +44,32 @@ public class Preferences
 	public int runDoubleContactsMS; //milliseconds
 	public Constants.DoubleContact runIDoubleContactsMode; //default AVERAGE
 	public int runIDoubleContactsMS; //milliseconds
+
+	public int thresholdJumps;
+	public int thresholdRuns;
+	public int thresholdOther;
 	
+	//encoder capture
+	public int encoderCaptureTime;
+	public int encoderCaptureInactivityEndTime;
+	public Constants.EncoderVariablesCapture encoderCaptureMainVariable;
+	public int encoderCaptureMinHeightGravitatory;
+	public int encoderCaptureMinHeightInertial;
+	public bool encoderCaptureCheckFullyExtended;
+	public int encoderCaptureCheckFullyExtendedValue;
+	public Constants.EncoderAutoSaveCurve encoderAutoSaveCurve;
+	public bool encoderShowStartAndDuration;
+	
+	//encoder other
 	public bool encoderPropulsive;
 	public double encoderSmoothCon;
-	public int videoDeviceNum; 		//AKA videoDevice
 	public Constants.Encoder1RMMethod encoder1RMMethod;
+	
+	public int videoDeviceNum; 		//AKA videoDevice
 	public string CSVExportDecimalSeparator;
 	public string language;
 	public bool RGraphsTranslate;
 	public bool useHeightsOnJumpIndexes;
-	public Constants.EncoderAutoSaveCurve encoderAutoSaveCurve;
 	
 	/*
 	 * these are NOT sent to preferences window
@@ -67,6 +83,8 @@ public class Preferences
 	public string machineID;
 	public Constants.MultimediaStorage multimediaStorage;
 	public string databaseVersion;
+				
+	public int encoderCaptureTimeIM = 120; //hardcoded 2 minutes.
 
 	/*
 	 * these are unused on SqlitePreferences.SelectAll
@@ -86,6 +104,33 @@ public class Preferences
 		return SqlitePreferences.SelectAll();
 	}
 	
+	public int EncoderCaptureMinHeight(bool inertial) {
+		if(inertial)
+			return encoderCaptureMinHeightInertial;
+		else
+			return encoderCaptureMinHeightGravitatory;
+	}
+	
+	public bool EncoderChangeMinHeight(bool inertial, int minHeight) 
+	{
+		bool changed = false;
+
+		if(inertial && minHeight != encoderCaptureMinHeightInertial) 
+		{
+			encoderCaptureMinHeightInertial = minHeight;
+			SqlitePreferences.Update("encoderCaptureMinHeightInertial", 
+					minHeight.ToString(), false);
+			changed = true;
+		}
+		else if(! inertial && minHeight != encoderCaptureMinHeightGravitatory)
+		{
+			encoderCaptureMinHeightGravitatory = minHeight;
+			SqlitePreferences.Update("encoderCaptureMinHeightGravitatory", 
+					minHeight.ToString(), false);
+			changed = true;
+		}
+		return changed;
+	}
 
 	~Preferences() {}
 	   
