@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -26,7 +26,7 @@ using Mono.Data.Sqlite;
 
 class SqlitePreferences : Sqlite
 {
-	protected internal static void createTable()
+	protected internal static new void createTable()
 	{
 		dbcmd.CommandText = 
 			"CREATE TABLE " + Constants.PreferencesTable + " ( " +
@@ -77,17 +77,31 @@ class SqlitePreferences : Sqlite
 						Constants.DoubleContact.AVERAGE.ToString(), dbcmdTr); 
 				Insert ("runIDoubleContactsMS", "300", dbcmdTr);
 
+				Insert ("thresholdJumps", "50", dbcmdTr);
+				Insert ("thresholdRuns", "10", dbcmdTr);
+				Insert ("thresholdOther", "50", dbcmdTr);
+
 				Random rnd = new Random();
 				string machineID = rnd.Next().ToString();
 				Insert ("machineID", machineID, dbcmdTr);
 
 				Insert ("multimediaStorage", Constants.MultimediaStorage.BYSESSION.ToString(), dbcmdTr);
 
+				//encoder
+				Insert ("encoderCaptureTime", "60", dbcmdTr);
+				Insert ("encoderCaptureInactivityEndTime", "3", dbcmdTr);
+				Insert ("encoderCaptureMainVariable", Constants.EncoderVariablesCapture.MeanPower.ToString(), dbcmdTr);
+				Insert ("encoderCaptureMinHeightGravitatory", "20", dbcmdTr);
+				Insert ("encoderCaptureMinHeightInertial", "5", dbcmdTr);
+				Insert ("encoderCaptureCheckFullyExtended", "True", dbcmdTr);
+				Insert ("encoderCaptureCheckFullyExtendedValue", "4", dbcmdTr);
+				Insert ("encoderShowStartAndDuration", "False", dbcmdTr);
 				Insert ("encoderPropulsive", "True", dbcmdTr);
 				Insert ("encoderSmoothEccCon", "0.6", dbcmdTr);
 				Insert ("encoderSmoothCon", "0.7", dbcmdTr);
-				Insert ("videoDevice", "0", dbcmdTr); //first
 				Insert ("encoder1RMMethod", Constants.Encoder1RMMethod.WEIGHTED2.ToString(), dbcmdTr);
+
+				Insert ("videoDevice", "0", dbcmdTr); //first
 				Insert ("inertialmomentum", "0.01", dbcmdTr);
 				Insert ("CSVExportDecimalSeparator", Util.GetDecimalSeparatorFromLocale(), dbcmdTr);
 				Insert ("RGraphsTranslate", "True", dbcmdTr);
@@ -95,8 +109,9 @@ class SqlitePreferences : Sqlite
 				Insert ("encoderAutoSaveCurve", Constants.EncoderAutoSaveCurve.BEST.ToString(), dbcmdTr); 
 				Insert ("email", "", dbcmdTr);
 				
-				//last encoderConfiguration, to be used on next session
-				Insert ("encoderConfiguration", new EncoderConfiguration().ToStringOutput(EncoderConfiguration.Outputs.SQL), dbcmdTr);
+				//removed on 1.37
+				//Insert ("encoderConfiguration", new EncoderConfiguration().ToStringOutput(EncoderConfiguration.Outputs.SQL), dbcmdTr);
+
 			}
 			tr.Commit();
 		}
@@ -207,11 +222,37 @@ class SqlitePreferences : Sqlite
 				preferences.heightPreferred = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "metersSecondsPreferred")
 				preferences.metersSecondsPreferred = reader[1].ToString() == "True";
+			//encoder capture
+			else if(reader[0].ToString() == "encoderCaptureTime")
+				preferences.encoderCaptureTime = Convert.ToInt32(reader[1].ToString());
+			else if(reader[0].ToString() == "encoderCaptureInactivityEndTime")
+				preferences.encoderCaptureInactivityEndTime = Convert.ToInt32(reader[1].ToString());
+			else if(reader[0].ToString() == "encoderCaptureMainVariable")
+				preferences.encoderCaptureMainVariable = (Constants.EncoderVariablesCapture) 
+					Enum.Parse(typeof(Constants.EncoderVariablesCapture), reader[1].ToString()); 
+			else if(reader[0].ToString() == "encoderCaptureMinHeightGravitatory")
+				preferences.encoderCaptureMinHeightGravitatory = Convert.ToInt32(reader[1].ToString());
+			else if(reader[0].ToString() == "encoderCaptureMinHeightInertial")
+				preferences.encoderCaptureMinHeightInertial = Convert.ToInt32(reader[1].ToString());
+			else if(reader[0].ToString() == "encoderCaptureCheckFullyExtended")
+				preferences.encoderCaptureCheckFullyExtended = reader[1].ToString() == "True";
+			else if(reader[0].ToString() == "encoderCaptureCheckFullyExtendedValue")
+				preferences.encoderCaptureCheckFullyExtendedValue = Convert.ToInt32(reader[1].ToString());
+			else if(reader[0].ToString() == "encoderAutoSaveCurve")
+				preferences.encoderAutoSaveCurve = (Constants.EncoderAutoSaveCurve) 
+					Enum.Parse(typeof(Constants.EncoderAutoSaveCurve), reader[1].ToString()); 
+			else if(reader[0].ToString() == "encoderShowStartAndDuration")
+				preferences.encoderShowStartAndDuration = reader[1].ToString() == "True";
+			//encoder other
 			else if(reader[0].ToString() == "encoderPropulsive")
 				preferences.encoderPropulsive = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "encoderSmoothCon")
 				preferences.encoderSmoothCon = Convert.ToDouble(
 						Util.ChangeDecimalSeparator(reader[1].ToString()));
+			else if(reader[0].ToString() == "encoder1RMMethod")
+				preferences.encoder1RMMethod = (Constants.Encoder1RMMethod) 
+					Enum.Parse(typeof(Constants.Encoder1RMMethod), reader[1].ToString()); 
+			//video... other
 			else if(reader[0].ToString() == "videoDevice")
 				preferences.videoDeviceNum = Convert.ToInt32(reader[1].ToString());
 			else if(reader[0].ToString() == "CSVExportDecimalSeparator")
@@ -222,12 +263,6 @@ class SqlitePreferences : Sqlite
 				preferences.RGraphsTranslate = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "useHeightsOnJumpIndexes")
 				preferences.useHeightsOnJumpIndexes = reader[1].ToString() == "True";
-			else if(reader[0].ToString() == "encoderAutoSaveCurve")
-				preferences.encoderAutoSaveCurve = (Constants.EncoderAutoSaveCurve) 
-					Enum.Parse(typeof(Constants.EncoderAutoSaveCurve), reader[1].ToString()); 
-			else if(reader[0].ToString() == "encoder1RMMethod")
-				preferences.encoder1RMMethod = (Constants.Encoder1RMMethod) 
-					Enum.Parse(typeof(Constants.Encoder1RMMethod), reader[1].ToString()); 
 	 		//these are NOT sent to preferences window
 			else if(reader[0].ToString() == "allowFinishRjAfterTime")
 				preferences.allowFinishRjAfterTime = reader[1].ToString() == "True";
@@ -252,6 +287,12 @@ class SqlitePreferences : Sqlite
 					Enum.Parse(typeof(Constants.DoubleContact), reader[1].ToString()); 
 			else if(reader[0].ToString() == "runIDoubleContactsMS")
 				preferences.runIDoubleContactsMS = Convert.ToInt32(reader[1].ToString());
+			else if(reader[0].ToString() == "thresholdJumps")
+				preferences.thresholdJumps = Convert.ToInt32(reader[1].ToString());
+			else if(reader[0].ToString() == "thresholdRuns")
+				preferences.thresholdRuns = Convert.ToInt32(reader[1].ToString());
+			else if(reader[0].ToString() == "thresholdOther")
+				preferences.thresholdOther = Convert.ToInt32(reader[1].ToString());
 
 			else if(reader[0].ToString() == "machineID")
 				preferences.machineID = reader[1].ToString();
