@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -24,8 +24,108 @@ using System.IO;
 using System.Collections; //ArrayList
 using Mono.Data.Sqlite;
 using Mono.Unix;
+using System.Collections.Generic;
 
 
+public class SqliteSessionSwitcher
+{
+	/** SqliteSessionSwitcher implements two methods that SqliteSesion class had (SelectAllSessions and Select).
+ 	* These methods are used by SessionLoadWindow and depending on the parameters passed to the
+	* SqliteSessionSwitcher constructor:
+	* -it might use the static methods of SqliteSession (so it will access the main chronojump.db file)
+	* -it might use a specific database (depends on databasePath)
+	* 
+	* Doing this SessionLoadWindow can display sessions from other databases when SessionLoadWindow
+	* is used to import sessions from another Chronojump database instead of displaying sessions of the current
+	* database.
+	*/
+	private string databasePath;
+	private DatabaseType type;
+	public enum DatabaseType
+	{
+		DEFAULT,
+		SPECIFIC
+	};
+	
+	public SqliteSessionSwitcher(DatabaseType type, string databasePath)
+	{
+		this.type = type;
+		this.databasePath = databasePath;
+	}
+
+	public string[] SelectAllSessions(string filterName)
+	{
+		if (type == DatabaseType.DEFAULT)
+		{
+			return SqliteSession.SelectAllSessions (filterName);
+		}
+		else
+		{
+			SqliteGeneral sqliteGeneral = new SqliteGeneral(databasePath);
+			if (! sqliteGeneral.IsOpened) {
+				List<string> emptyResult = new List<string> ();
+				return emptyResult.ToArray ();
+			}
+			SqliteConnection dbcon = sqliteGeneral.connection;
+
+			string[] allSessions = SqliteSession.SelectAllSessions (filterName, dbcon);
+
+			// Filtered sessions will contain all sessions but not the "SIMULATED"
+			List<string> filteredSessions = new List<string> ();
+
+			foreach(string session in allSessions) {
+				if (session.Split (':') [1] != "SIMULATED") {
+					filteredSessions.Add (session);
+				}
+			}
+
+			return filteredSessions.ToArray();
+		}
+	}
+
+	public Session Select(string myUniqueID)
+	{
+		if (type == DatabaseType.DEFAULT)
+		{
+			return SqliteSession.Select (myUniqueID);
+		}
+		else
+		{
+			// This code could be refactored from existing code in SqliteSession::Select()
+
+			SqliteGeneral sqliteGeneral = new SqliteGeneral(databasePath);
+			SqliteCommand dbcommand = sqliteGeneral.command();
+
+			dbcommand.CommandText = "SELECT * FROM Session WHERE uniqueID == @myUniqueID";
+			dbcommand.Parameters.Add (new SqliteParameter ("@myUniqueID", myUniqueID));
+
+			SqliteDataReader reader = dbcommand.ExecuteReader ();
+
+			// Copied from a non-callable (yet) static method: SqliteSession::Select()
+			string [] values = new string[9];
+
+			while(reader.Read()) {
+				values[0] = reader[0].ToString(); 
+				values[1] = reader[1].ToString(); 
+				values[2] = reader[2].ToString();
+				values[3] = reader[3].ToString();
+				values[4] = reader[4].ToString();
+				values[5] = reader[5].ToString();
+				values[6] = reader[6].ToString();
+				values[7] = reader[7].ToString();
+				values[8] = reader[8].ToString();
+			}
+
+			Session mySession = new Session(values[0], 
+			                                values[1], values[2], UtilDate.FromSql(values[3]), 
+			                                Convert.ToInt32(values[4]), Convert.ToInt32(values[5]), Convert.ToInt32(values[6]), 
+			                                values[7], Convert.ToInt32(values[8]) );
+
+			return mySession;
+		}
+	}
+}
+
 class SqliteSession : Sqlite
 {
 	public SqliteSession() {
@@ -226,22 +326,46 @@ class SqliteSession : Sqlite
 		return mySessions;
 	}
 
+	// It's used by chronojump-importer and receives a specific database
+	public static string[] SelectAllSessions(string filterName, SqliteConnection dbcon) 
+	{
+		string [] mySessions = selectAllSessionsDo(filterName, dbcon);
+		return mySessions;
+	}
 
+	// This is the usual chronojump's call (default database)
 	public static string[] SelectAllSessions(string filterName) 
 	{
 		Sqlite.Open();
 
+		// SelectAllSessions is used here and by the Chronojump importer to allow to pass an arbitrary
+		// dbcon.
+		string [] mySessions = selectAllSessionsDo(filterName, dbcon);
+
+		//close database connection
+		Sqlite.Close();
+
+		return mySessions;
+	}
+	private static string[] selectAllSessionsDo(string filterName, SqliteConnection dbcon)
+	{
+		// This method should NOT use Sqlite.open() / Sqlite.close(): it should only use dbcon
+		// to connect to the database. This methos is used by the importer after opening an arbitrary
+		// ChronoJump sqlite database. It needs to be refactored to the new database system.
+
+		dbcmd = dbcon.CreateCommand();
+
 		string filterNameString = "";
 		if(filterName != "")
 			filterNameString = " AND LOWER(session.name) LIKE LOWER (\"%" + filterName  + "%\") ";
 
 		dbcmd.CommandText = 
 			"SELECT session.*, sport.name, speciallity.name" +
-			" FROM session, sport, speciallity " +
-			" WHERE session.personsSportID == sport.uniqueID " + 
-			" AND session.personsSpeciallityID == speciallity.UniqueID " +
-			filterNameString + 
-			" ORDER BY session.uniqueID";
+				" FROM session, sport, speciallity " +
+				" WHERE session.personsSportID == sport.uniqueID " + 
+				" AND session.personsSpeciallityID == speciallity.UniqueID " +
+				filterNameString + 
+				" ORDER BY session.uniqueID";
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 
@@ -258,11 +382,10 @@ class SqliteSession : Sqlite
 			if(reader[10].ToString() != "")
 				speciallityName = Catalog.GetString(reader[10].ToString());
 			string levelName = Catalog.GetString(Util.FindLevelName(Convert.ToInt32(reader[6])));
-
 			myArray.Add (reader[0].ToString() + ":" + reader[1].ToString() + ":" +
-					reader[2].ToString() + ":" + UtilDate.FromSql(reader[3].ToString()).ToShortDateString() + ":" +
-					sportName + ":" + speciallityName + ":" +
-					levelName + ":" + reader[7].ToString() ); //desc
+			             reader[2].ToString() + ":" + UtilDate.FromSql(reader[3].ToString()).ToShortDateString() + ":" +
+			             sportName + ":" + speciallityName + ":" +
+			             levelName + ":" + reader[7].ToString() ); //desc
 			count ++;
 		}
 
@@ -277,7 +400,7 @@ class SqliteSession : Sqlite
 		 * this will open a new window showing this values.
 		 * this solution it's more "lighter" for people who have  abig DB
 		 * */
-		
+
 		//select persons of each session
 		dbcmd.CommandText = "SELECT sessionID, count(*) FROM " + Constants.PersonSessionTable + 
 			" GROUP BY sessionID ORDER BY sessionID";
@@ -287,12 +410,12 @@ class SqliteSession : Sqlite
 		SqliteDataReader reader_persons;
 		reader_persons = dbcmd.ExecuteReader();
 		ArrayList myArray_persons = new ArrayList(2);
-		
+
 		while(reader_persons.Read()) {
 			myArray_persons.Add (reader_persons[0].ToString() + ":" + reader_persons[1].ToString() + ":" );
 		}
 		reader_persons.Close();
-		
+
 		//select jumps of each session
 		dbcmd.CommandText = "SELECT sessionID, count(*) FROM " + Constants.JumpTable + 
 			" GROUP BY sessionID ORDER BY sessionID";
@@ -302,12 +425,12 @@ class SqliteSession : Sqlite
 		SqliteDataReader reader_jumps;
 		reader_jumps = dbcmd.ExecuteReader();
 		ArrayList myArray_jumps = new ArrayList(2);
-		
+
 		while(reader_jumps.Read()) {
 			myArray_jumps.Add (reader_jumps[0].ToString() + ":" + reader_jumps[1].ToString() + ":" );
 		}
 		reader_jumps.Close();
-		
+
 		//select jumpsRj of each session
 		dbcmd.CommandText = "SELECT sessionID, count(*) FROM " + Constants.JumpRjTable + 
 			" GROUP BY sessionID ORDER BY sessionID";
@@ -317,12 +440,12 @@ class SqliteSession : Sqlite
 		SqliteDataReader reader_jumpsRj;
 		reader_jumpsRj = dbcmd.ExecuteReader();
 		ArrayList myArray_jumpsRj = new ArrayList(2);
-		
+
 		while(reader_jumpsRj.Read()) {
 			myArray_jumpsRj.Add (reader_jumpsRj[0].ToString() + ":" + reader_jumpsRj[1].ToString() + ":" );
 		}
 		reader_jumpsRj.Close();
-		
+
 		//select runs of each session
 		dbcmd.CommandText = "SELECT sessionID, count(*) FROM " + Constants.RunTable + 
 			" GROUP BY sessionID ORDER BY sessionID";
@@ -332,12 +455,12 @@ class SqliteSession : Sqlite
 		SqliteDataReader reader_runs;
 		reader_runs = dbcmd.ExecuteReader();
 		ArrayList myArray_runs = new ArrayList(2);
-		
+
 		while(reader_runs.Read()) {
 			myArray_runs.Add (reader_runs[0].ToString() + ":" + reader_runs[1].ToString() + ":" );
 		}
 		reader_runs.Close();
-		
+
 		//select runsInterval of each session
 		dbcmd.CommandText = "SELECT sessionID, count(*) FROM " + Constants.RunIntervalTable + 
 			" GROUP BY sessionID ORDER BY sessionID";
@@ -347,12 +470,12 @@ class SqliteSession : Sqlite
 		SqliteDataReader reader_runs_interval;
 		reader_runs_interval = dbcmd.ExecuteReader();
 		ArrayList myArray_runs_interval = new ArrayList(2);
-		
+
 		while(reader_runs_interval.Read()) {
 			myArray_runs_interval.Add (reader_runs_interval[0].ToString() + ":" + reader_runs_interval[1].ToString() + ":" );
 		}
 		reader_runs_interval.Close();
-	
+
 		//select reaction time of each session
 		dbcmd.CommandText = "SELECT sessionID, count(*) FROM " + Constants.ReactionTimeTable + 
 			" GROUP BY sessionID ORDER BY sessionID";
@@ -362,12 +485,12 @@ class SqliteSession : Sqlite
 		SqliteDataReader reader_rt;
 		reader_rt = dbcmd.ExecuteReader();
 		ArrayList myArray_rt = new ArrayList(2);
-		
+
 		while(reader_rt.Read()) {
 			myArray_rt.Add (reader_rt[0].ToString() + ":" + reader_rt[1].ToString() + ":" );
 		}
 		reader_rt.Close();
-	
+
 		//select pulses of each session
 		dbcmd.CommandText = "SELECT sessionID, count(*) FROM " + Constants.PulseTable + 
 			" GROUP BY sessionID ORDER BY sessionID";
@@ -377,12 +500,12 @@ class SqliteSession : Sqlite
 		SqliteDataReader reader_pulses;
 		reader_pulses = dbcmd.ExecuteReader();
 		ArrayList myArray_pulses = new ArrayList(2);
-		
+
 		while(reader_pulses.Read()) {
 			myArray_pulses.Add (reader_pulses[0].ToString() + ":" + reader_pulses[1].ToString() + ":" );
 		}
 		reader_pulses.Close();
-	
+
 		//select multichronopic of each session
 		dbcmd.CommandText = "SELECT sessionID, count(*) FROM " + Constants.MultiChronopicTable + 
 			" GROUP BY sessionID ORDER BY sessionID";
@@ -392,13 +515,13 @@ class SqliteSession : Sqlite
 		SqliteDataReader reader_mcs;
 		reader_mcs = dbcmd.ExecuteReader();
 		ArrayList myArray_mcs = new ArrayList(2);
-		
+
 		while(reader_mcs.Read()) {
 			myArray_mcs.Add (reader_mcs[0].ToString() + ":" + reader_mcs[1].ToString() + ":" );
 		}
 		reader_mcs.Close();
-	
-	
+
+
 		//select encoder stuff of each session
 		dbcmd.CommandText = "SELECT sessionID, encoderConfiguration, signalOrCurve FROM " + Constants.EncoderTable + " ORDER BY sessionID";
 		LogB.SQL(dbcmd.CommandText.ToString());
@@ -409,7 +532,7 @@ class SqliteSession : Sqlite
 		ArrayList myArray_enc_g_r = new ArrayList(2); //gravitatory repetitions
 		ArrayList myArray_enc_i_s = new ArrayList(2); //inertial sets
 		ArrayList myArray_enc_i_r = new ArrayList(2); //inertial repetitions
-		
+
 		int count_g_s = 0;	
 		int count_g_r = 0;	
 		int count_i_s = 0;
@@ -456,10 +579,7 @@ class SqliteSession : Sqlite
 
 		reader_enc.Close();
 
-		
-		
-		//close database connection
-		Sqlite.Close();
+
 
 		//mix nine arrayLists
 		string [] mySessions = new string[count];
@@ -473,7 +593,7 @@ class SqliteSession : Sqlite
 			//if some sessions are deleted, do not use count=0 to mix arrays, use sessionID of line
 			string [] mixingSessionFull = line.Split(new char[] {':'});
 			string mixingSessionID = mixingSessionFull[0];
-			
+
 			//add persons for each session	
 			found = false;
 			foreach (string line_persons in myArray_persons) {
@@ -484,7 +604,7 @@ class SqliteSession : Sqlite
 				}
 			}
 			if (!found) { lineNotReadOnly  = lineNotReadOnly + ":0"; }
-		
+
 			//add jumps for each session
 			found = false;
 			foreach (string line_jumps in myArray_jumps) {
@@ -495,7 +615,7 @@ class SqliteSession : Sqlite
 				}
 			}
 			if (!found) { lineNotReadOnly  = lineNotReadOnly + ":0"; }
-			
+
 			//add jumpsRj for each session
 			found = false;
 			foreach (string line_jumpsRj in myArray_jumpsRj) {
@@ -506,7 +626,7 @@ class SqliteSession : Sqlite
 				}
 			}
 			if (!found) { lineNotReadOnly  = lineNotReadOnly + ":0"; }
-			
+
 			//add runs for each session
 			found = false;
 			foreach (string line_runs in myArray_runs) {
@@ -517,7 +637,7 @@ class SqliteSession : Sqlite
 				}
 			}
 			if (!found) { lineNotReadOnly  = lineNotReadOnly + ":0"; }
-			
+
 			//add runsInterval for each session
 			found = false;
 			foreach (string line_runs_interval in myArray_runs_interval) {
@@ -528,7 +648,7 @@ class SqliteSession : Sqlite
 				}
 			}
 			if (!found) { lineNotReadOnly  = lineNotReadOnly + ":0"; }
-			
+
 			//add reaction time for each session
 			found = false;
 			foreach (string line_rt in myArray_rt) {
@@ -592,10 +712,15 @@ class SqliteSession : Sqlite
 			}
 			lineNotReadOnly  = lineNotReadOnly + ":" + result_enc_s + " ; " + result_enc_r;
 
-			
+
 			mySessions [count++] = lineNotReadOnly;
 		}
 
+		if (mySessions.Length > 0) {
+			LogB.SQL (mySessions [0]);
+		} else {
+			LogB.Debug ("SelectAllSessions with filter: " + filterName + " is empty");
+		}
 		return mySessions;
 	}
 
