@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -74,7 +74,7 @@ public class GraphRunIntervallic : StatRunIntervallic
 		
 		CurrentGraphData.LabelLeft = translateYesNo("Speed") + "(m/s)";
 		CurrentGraphData.LabelRight = "";
-		CurrentGraphData.LabelBottom = translateYesNo("Runs");
+		CurrentGraphData.LabelBottom = translateYesNo("Races");
 	}
 
 	protected override void printData (string [] statValues) 
