@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -29,17 +29,23 @@ public class TreeViewPersons
 {
 	protected TreeStore store;
 	protected Gtk.TreeView treeview;
+
+	//if 0 don't use it
+	//if > 0 then show in red when >= to this value
+	public int RestSecondsMark;
 	
 	public TreeViewPersons ()
 	{
 	}
 	
-	public TreeViewPersons (Gtk.TreeView treeview)
+	public TreeViewPersons (Gtk.TreeView treeview, int restSeconds)
 	{
 		this.treeview = treeview;
 
-		store = getStore(2); 
-		string [] columnsString = { "ID", Catalog.GetString("person")};
+		RestSecondsMark = restSeconds;
+
+		store = getStore(3);
+		string [] columnsString = { "ID", Catalog.GetString("person"), Catalog.GetString("Rest")};
 		treeview.Model = store;
 		prepareHeaders(columnsString);
 	}
@@ -61,22 +67,71 @@ public class TreeViewPersons
 		int i=0;
 		bool visible = false;
 		foreach(string myCol in columnsString) {
-			UtilGtk.CreateCols(treeview, store, Catalog.GetString(myCol), i++, visible);
+			if(i < 2)
+				UtilGtk.CreateCols(treeview, store, Catalog.GetString(myCol), i++, visible);
+			else {
+				//do it here to use a custom colored Renderer
+				Gtk.TreeViewColumn aColumn = new Gtk.TreeViewColumn ();
+				CellRendererText aCell = new CellRendererText();
+				aColumn.Title = Catalog.GetString(myCol);
+				aColumn.PackStart (aCell, true);
+				aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderRestTime));
+
+				aColumn.SortColumnId = i;
+				aColumn.SortIndicator = true;
+				aColumn.Visible = visible;
+				treeview.AppendColumn ( aColumn );
+			}
+
 			if(i == 1)
 				store.SetSortFunc (0, UtilGtk.IdColumnCompare);
+
 			visible = true;
 		}
 	}
-	
-	public int idColumnCompare (TreeModel model, TreeIter iter1, TreeIter iter2)     {
-		int val1 = 0;
-		int val2 = 0;
-		val1 = Convert.ToInt32(model.GetValue(iter1, 0));
-		val2 = Convert.ToInt32(model.GetValue(iter2, 0));
-		
-		return (val1-val2);
+
+	private void RenderRestTime (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
+	{
+		string restTime = (string) model.GetValue(iter, 2);
+
+		if(RestSecondsMark > 0 && LastTestTime.GetSeconds(restTime) >= RestSecondsMark)
+		{
+			Gtk.TreeModel model2;
+			Gtk.TreeIter iter2;
+			bool selected = false;
+			if (treeview.Selection.GetSelected (out model2, out iter2))
+				if(model.GetValue(iter, 0).ToString() == model2.GetValue(iter2, 0).ToString())
+					selected = true;
+
+			if(selected) {
+				//based on http://stackoverflow.com/a/9548415
+				(cell as Gtk.CellRendererText).Markup = "<span foreground=\"red\" background=\"white\">"+restTime+"</span>";
+			}
+			else {
+				(cell as Gtk.CellRendererText).Foreground = UtilGtk.ColorBad;
+				(cell as Gtk.CellRendererText).Text = restTime;
+			}
+		} else {
+			(cell as Gtk.CellRendererText).Foreground = null;	//will show default color
+			(cell as Gtk.CellRendererText).Text = restTime;
+		}
 	}
 
+	/*
+	 * this method works fine but does not show foreground in color when cell is selected
+	 * above method solves this
+	private void RenderRestTime (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
+	{
+		string restTime = (string) model.GetValue(iter, 2);
+		(cell as Gtk.CellRendererText).Text = restTime;
+
+		if(RestMinutesMark > 0 && LastTestTime.GetMinutes(restTime) >= RestMinutesMark)
+			(cell as Gtk.CellRendererText).Foreground = UtilGtk.ColorBad;
+		else
+			(cell as Gtk.CellRendererText).Foreground = null; 	//will show default color
+	}
+	*/
+
 	public void RemoveColumns() {
 		Gtk.TreeViewColumn [] myColumns = treeview.Columns;
 		foreach (Gtk.TreeViewColumn column in myColumns) {
@@ -84,15 +139,20 @@ public class TreeViewPersons
 		}
 	}
 
-	public void Fill(ArrayList myPersons)
+	public void Fill(ArrayList myPersons, RestTime rt)
 	{
-		foreach (Person person in myPersons) {
-			store.AppendValues (person.IDAndName());
-		}
+		foreach (Person person in myPersons)
+			store.AppendValues ( new String [] {
+					person.UniqueID.ToString(),
+					person.Name.ToString(),
+					rt.RestedTime(person.UniqueID) }
+					);
+
 		//show sorted by column name	
 		store.SetSortColumnId(1, Gtk.SortType.Ascending);
+
+		//TODO: check if sort works after 1h
 		store.ChangeSortColumn();
-			
 	}
 	
 	//pass 0 for first row
@@ -141,6 +201,11 @@ public class TreeViewPersons
 	{
 		SelectRow(FindRow(personID) -1);
 	}
+
+	public int CountRows() {
+		return(store.IterNChildren());
+	}
+
 	
 	//add in the row position by alfabetical order
 	public void Add (string jumperID, string jumperName)
@@ -170,14 +235,30 @@ public class TreeViewPersons
 			//first ID, then Name
 			store.SetValue (iter2, 0, jumperID);
 			store.SetValue (iter2, 1, jumperName);
+			store.SetValue (iter2, 2, ""); //restTime
 		} else {
 			//first ID, then Name
-			iter2 = store.AppendValues (jumperID, jumperName);
+			iter2 = store.AppendValues (jumperID, jumperName, "");
 		}
 			
 		//scroll treeview if needed
 		TreePath path = store.GetPath (iter2);
 		treeview.ScrollToCell (path, null, true, 0, 0);
 	}
+
+	public void UpdateRestTimes(RestTime restTime)
+	{
+		TreeIter iter;
+		bool iterOk = store.GetIterFirst(out iter);
+		if(iterOk) {
+			do {
+				string rested = restTime.RestedTime(
+						Convert.ToInt32(store.GetValue(iter, 0)));
+				if(rested != "")
+					store.SetValue(iter, 2, rested);
+
+			} while (store.IterNext (ref iter));
+		}
+	}
 }
 
