@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -668,7 +668,6 @@ public class Util
 		//Calcule the potential energies before (mass * g * fallHeight) and after the jump (mass * g * tv^2 * 1.226)
 		//and divide by the time during force is applied
 		double g = 9.81;
-		double tt = tc + tf; //totalTime
 		fallHeight = fallHeight / 100.0; //cm -> m
 		
 		return mass * g * ( fallHeight + 1.226 * Math.Pow(tf,2) ) / (Double)tc;
@@ -1062,6 +1061,20 @@ public class Util
 	public static bool FileExists(string fileName){
 		return File.Exists(fileName);
 	}
+	
+	public static bool FileReadable(string filename)
+	{
+		//http://stackoverflow.com/a/17318735
+		try {
+			File.Open(filename, FileMode.Open, FileAccess.Read).Dispose();
+			//LogB.Information("success at Util.FileReadable: " + filename);
+			return true;
+		}
+		catch (IOException) {
+			System.Threading.Thread.Sleep(10);
+			return false;
+		}
+	}
 
 	//not recommended, better use below method. Better for bigger files
 	public static string ReadFile(string fileName, bool removeEOL)
@@ -1305,7 +1318,12 @@ public class Util
 		
 	//do this for showing the Limited with selected decimals and without loosing the end letter: 'J' or 'T'
 	//called by treeview_jump, treeview_run and gui/jump_edit and gui/run_edit?
-	public static string GetLimitedRounded(string limitedString, int pDN) {
+	public static string GetLimitedRounded(string limitedString, int pDN)
+	{
+		LogB.Information("GetLimitedRounded limitedString pdN");
+		LogB.Information(limitedString);
+		LogB.Information(pDN.ToString());
+
 		string myLimitedWithoutLetter = limitedString.Substring(0, limitedString.Length -1);
 		string myLimitedLetter = limitedString.Substring(limitedString.Length -1, 1);
 
@@ -1503,6 +1521,9 @@ public class Util
 	public static string AddPngIfNeeded(string myFile) {
 		return addExtensionIfNeeded(myFile, ".png");
 	}
+	public static string AddTxtIfNeeded(string myFile) {
+		return addExtensionIfNeeded(myFile, ".txt");
+	}
 	private static string addExtensionIfNeeded(string myFile, string extension)
 	{
 		int posOfDot = myFile.LastIndexOf('.');
