@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -30,6 +30,11 @@ using Gdk;
 //only Gtk related methods (not used bu the server) this is the differnece with Util
 public class UtilGtk
 {
+	public static bool CanTouchGTK()
+	{
+		//Only first thread can touch GTK
+		return (System.Threading.Thread.CurrentThread.ManagedThreadId.ToString() == "1");
+	}
 
 	/*
 	 *
@@ -247,7 +252,8 @@ public class UtilGtk
 	}
 
 	//finds the row number (starting at 0) of a cell (usually an uniqueID in col 0)
-	private static int getRowNumOfThisID(Gtk.TreeStore store, int colNum, int searchedID) {
+	private static int getRowNumOfThisID(Gtk.TreeStore store, int colNum, int searchedID)
+	{
 		TreeIter iter;
 		int count = 0;
 		bool iterOk = store.GetIterFirst(out iter);
@@ -262,15 +268,48 @@ public class UtilGtk
 		return -1;
 	}
 
+	//finds the row number (starting at 0) of a cell
+	private static int getRowNumOfThisName(Gtk.TreeStore store, int colNum, string searchedName)
+	{
+		TreeIter iter;
+		int count = 0;
+		bool iterOk = store.GetIterFirst(out iter);
+		while(iterOk) {
+			string thisName = (string) store.GetValue (iter, colNum);
+			if(thisName == searchedName)
+				return count;
+
+			count ++;
+			iterOk = store.IterNext(ref iter);
+		}
+		return -1;
+	}
+
+	public static bool TreeviewSelectFirstRow(Gtk.TreeView tv, Gtk.TreeStore store, bool scrollToRow)
+	{
+		return treeviewSelectRow(tv, store, 0, scrollToRow);
+	}
 	//selects a row that has an uniqueID (usually at col 0)
-	public static void TreeviewSelectRowWithID(Gtk.TreeView tv, Gtk.TreeStore store, int colNum, int id, bool scrollToRow)
+	public static bool TreeviewSelectRowWithID(Gtk.TreeView tv, Gtk.TreeStore store, int colNum, int id, bool scrollToRow)
 	{
 		if(id <= 0)
-			return;
+			return false;
 
 		int rowNum = getRowNumOfThisID(store, colNum, id);
+		return treeviewSelectRow(tv, store, rowNum, scrollToRow);
+	}
+	public static bool TreeviewSelectRowWithName(Gtk.TreeView tv, Gtk.TreeStore store, int colNum, string name, bool scrollToRow)
+	{
+		if(name == null || name == "")
+			return false;
+
+		int rowNum = getRowNumOfThisName(store, colNum, name);
+		return treeviewSelectRow(tv, store, rowNum, scrollToRow);
+	}
+	private static bool treeviewSelectRow(Gtk.TreeView tv, Gtk.TreeStore store, int rowNum, bool scrollToRow)
+	{
 		if(rowNum == -1)
-			return;
+			return false;
 
 		//set the selected
 		int count = 0;
@@ -288,12 +327,13 @@ public class UtilGtk
 					tv.ScrollToCell (path, tv.Columns[0], true, 0, 0);
 				}
 
-				return;
+				return true;
 			}
 			
 			count ++;
 			store.IterNext(ref iter);
 		}
+		return false;
 	}
 
 	public static Gtk.TreeStore RemoveRow (Gtk.TreeView tv, Gtk.TreeStore store) {
@@ -317,7 +357,7 @@ public class UtilGtk
 	//startOrEnd is true at start, false at end
 	public static void TreeviewAddRow(Gtk.TreeView tv, TreeStore store, string [] row, bool startOrEnd) {
 		TreeIter iter = new TreeIter();
-		bool iterOk = store.GetIterFirst(out iter);
+		store.GetIterFirst(out iter);
 		
 		if(startOrEnd)
 			iter = store.InsertWithValues(0,row);
